* {
  padding: 0;
  -GtkToolButton-icon-spacing: 4;
  -GtkTextView-error-underline-color: #cc0000;
  -GtkPaned-handle-size: 1;
  -GtkCheckButton-indicator-size: 16;
  -GtkCheckMenuItem-indicator-size: 16;
  -GtkScrolledWindow-scrollbar-spacing: 0;
  -GtkScrolledWindow-scrollbars-within-bevel: 1;
  -GtkToolItemGroup-expander-size: 11;
  -GtkExpander-expander-size: 16;
  -GtkTreeView-expander-size: 11;
  -GtkTreeView-horizontal-separator: 4;
  -GtkMenu-horizontal-padding: 0;
  -GtkMenu-vertical-padding: 0;
  -GtkWidget-link-color: #4a90d9;
  -GtkWidget-visited-link-color: #2a76c6;
  -GtkWidget-focus-padding: 2;
  -GtkWidget-focus-line-width: 1;
  -GtkDialog-button-spacing: 4;
  -GtkDialog-action-area-border: 0;
  -GtkStatusbar-shadow-type: none;
  outline-color: rgba(238, 238, 236, 0.3);
  outline-style: dashed;
  outline-offset: -3px;
  outline-width: 1px;
  outline-radius: 2px; }

/***************
 * Base States *
 ***************/
.background {
  color: #eeeeec;
  background-color: #393f3f; }

.background:backdrop {
  text-shadow: none;
  icon-shadow: none;
  color: white;
  background-color: #393f3f; }

/*
   These wildcard seems unavoidable, need to investigate.
   Wildcards are bad and troublesome, use them with care,
   or better, just don't.
   Everytime a wildcard is used a kitten dies, painfully.
*/
*:insensitive {
  -gtk-image-effect: dim; }

.gtkstyle-fallback {
  background-color: #393f3f;
  color: #eeeeec; }
  .gtkstyle-fallback:prelight {
    background-color: #515a5a;
    color: #eeeeec; }
  .gtkstyle-fallback:active {
    background-color: #212424;
    color: #eeeeec; }
  .gtkstyle-fallback:insensitive {
    background-color: #323636;
    color: #939695; }
  .gtkstyle-fallback:selected {
    background-color: #215d9c;
    color: #ffffff; }

.view {
  color: #eeeeec;
  background-color: #292929; }
  .view:backdrop {
    color: #c9cbc9;
    background-color: #2c2c2c; }

.rubberband {
  border: 1px solid #215d9c;
  background-color: rgba(33, 93, 156, 0.2); }

.overshoot {
  background-color: rgba(33, 93, 156, 0.2); }

GtkLabel.separator, .sidebar GtkLabel.separator:backdrop,
.sidebar .view GtkLabel.separator:backdrop {
  color: #eeeeec; }
  GtkLabel.separator:backdrop, .sidebar GtkLabel.separator:backdrop,
  .sidebar .view GtkLabel.separator:backdrop {
    color: #c9cbc9; }
GtkLabel:insensitive {
  color: #939695; }
  GtkLabel:insensitive:backdrop {
    color: #5d6767; }

.dim-label, GtkLabel.separator, .sidebar GtkLabel.separator:backdrop,
.sidebar .view GtkLabel.separator:backdrop, .titlebar .subtitle, GtkCalendar.header .subtitle,
.header-bar .subtitle {
  opacity: 0.55;
  text-shadow: none; }

GtkAssistant .sidebar {
  background-color: #292929;
  border-top: 1px solid #1c1f1f; }
  GtkAssistant .sidebar:dir(ltr) {
    border-right: 1px solid #1c1f1f; }
  GtkAssistant .sidebar:dir(rtl) {
    border-left: 1px solid #1c1f1f; }
  GtkAssistant .sidebar:backdrop {
    background-color: #2c2c2c;
    border-color: #1e2222; }
GtkAssistant.csd .sidebar {
  border-top-style: none; }
GtkAssistant .sidebar GtkLabel {
  padding: 6px 12px; }
GtkAssistant .sidebar GtkLabel.highlight {
  background-color: #5d6261; }

GtkTextView {
  background-color: #313434; }
  GtkTextView:backdrop {
    background-color: #323535; }

GtkFlowBox .grid-child {
  padding: 3px;
  border-radius: 3px; }
  GtkFlowBox .grid-child:selected {
    outline-offset: -2px; }

.app-notification,
.app-notification.frame, .osd {
  color: #eeeeec;
  outline-color: rgba(238, 238, 236, 0.3);
  text-shadow: 0 1px black;
  icon-shadow: 0 1px black; }
  .app-notification:backdrop, .osd:backdrop {
    text-shadow: none; }

/*********************
 * Spinner Animation *
 *********************/
@keyframes spin {
  to {
    -gtk-icon-transform: rotate(1turn); } }
.spinner {
  background-image: none;
  background-color: blue;
  opacity: 0;
  -gtk-icon-source: -gtk-icontheme("process-working-symbolic"); }
  .spinner:active {
    opacity: 1;
    animation: spin 1s linear infinite; }
    .spinner:active:insensitive {
      opacity: 0.5; }

/****************
 * Text Entries *
 ****************/
.entry {
  border: 1px solid;
  padding: 5px 8px 6px;
  border-radius: 3px;
  transition: all 200ms ease-out;
  background-color: transparent;
  background-image: linear-gradient(to bottom, #212121, #292929 90%);
  border-color: #1c1f1f;
  box-shadow: inset 0 3px rgba(0, 0, 0, 0.02), inset 0 2px rgba(0, 0, 0, 0.03), inset 0 1px rgba(0, 0, 0, 0.08), inset 0 0 0 1px rgba(33, 93, 156, 0), 0 1px rgba(238, 238, 236, 0.1); }
  .entry.image.left {
    padding-left: 0; }
  .entry.image.right {
    padding-right: 0; }
  .entry.flat, .entry.flat:focus {
    padding: 2px;
    background-color: transparent;
    background-image: linear-gradient(to bottom, #212121, #292929 90%);
    border-color: #1c1f1f;
    box-shadow: inset 0 3px rgba(0, 0, 0, 0.02), inset 0 2px rgba(0, 0, 0, 0.03), inset 0 1px rgba(0, 0, 0, 0.08), inset 0 0 0 1px rgba(33, 93, 156, 0);
    border: none;
    border-radius: 0; }
  .entry:focus {
    background-color: transparent;
    background-image: linear-gradient(to bottom, #212121, #292929 90%);
    box-shadow: inset 0 3px rgba(0, 0, 0, 0.02), inset 0 2px rgba(0, 0, 0, 0.03), inset 0 1px rgba(0, 0, 0, 0.08), inset 0 0 0 1px rgba(33, 93, 156, 0.7), 0 1px rgba(238, 238, 236, 0.1);
    border-color: #0f2b48; }
  .entry:insensitive {
    background-color: transparent;
    background-image: linear-gradient(to bottom, #212121, #292929 90%);
    color: #939695;
    border-color: #1c1f1f;
    background-image: linear-gradient(to bottom, #323636);
    box-shadow: inset 0 3px transparent, inset 0 2px transparent, inset 0 1px transparent, 0 1px rgba(238, 238, 236, 0.1); }
  .entry:backdrop {
    background-color: transparent;
    background-image: linear-gradient(to bottom, #212121, #292929 90%);
    color: #c9cbc9;
    border-color: #1e2222;
    background-image: linear-gradient(to bottom, #2c2c2c);
    box-shadow: inset 0 3px transparent, inset 0 2px transparent, inset 0 1px transparent, 0 1px rgba(238, 238, 236, 0); }
  .entry:backdrop:insensitive {
    background-color: transparent;
    background-image: linear-gradient(to bottom, #212121, #292929 90%);
    color: #5d6767;
    border-color: #1e2222;
    background-image: linear-gradient(to bottom, #323636);
    box-shadow: inset 0 3px transparent, inset 0 2px transparent, inset 0 1px transparent, 0 1px rgba(238, 238, 236, 0); }
  .entry:selected, .entry:backdrop:selected {
    background-color: #215d9c;
    color: #ffffff; }
  .entry.progressbar {
    margin: 1px;
    border-radius: 0;
    border-width: 0 0 2px;
    border-color: #215d9c;
    border-style: solid;
    background-image: none;
    background-color: transparent;
    box-shadow: none; }
    .entry.progressbar:backdrop {
      background-color: transparent; }
  .linked .entry:first-child {
    border-top-right-radius: 0;
    border-bottom-right-radius: 0; }
    .linked .entry:first-child:dir(rtl) {
      border-right-style: none; }
  .linked .entry:last-child {
    border-top-left-radius: 0;
    border-bottom-left-radius: 0;
    border-left-style: none; }
    .linked .entry:last-child:dir(rtl) {
      border-left-style: solid; }
  .entry.error {
    color: #cc0000;
    border-color: #cc0000; }
    .entry.error:focus {
      background-color: transparent;
      background-image: linear-gradient(to bottom, #212121, #292929 90%);
      box-shadow: inset 0 3px rgba(0, 0, 0, 0.02), inset 0 2px rgba(0, 0, 0, 0.03), inset 0 1px rgba(0, 0, 0, 0.08), inset 0 0 0 1px rgba(204, 0, 0, 0.7), 0 1px rgba(238, 238, 236, 0.1);
      border-color: #1a0000; }
    .entry.error:selected, .entry.error:selected:focus {
      background-color: #cc0000; }
    .entry.error:selected:focus {
      color: #292929; }
    .entry.error:selected:backdrop {
      color: #2c2c2c; }
  .entry.warning {
    color: #f57900;
    border-color: #f57900; }
    .entry.warning:focus {
      background-color: transparent;
      background-image: linear-gradient(to bottom, #212121, #292929 90%);
      box-shadow: inset 0 3px rgba(0, 0, 0, 0.02), inset 0 2px rgba(0, 0, 0, 0.03), inset 0 1px rgba(0, 0, 0, 0.08), inset 0 0 0 1px rgba(245, 121, 0, 0.7), 0 1px rgba(238, 238, 236, 0.1);
      border-color: #432100; }
    .entry.warning:selected, .entry.warning:selected:focus {
      background-color: #f57900; }
    .entry.warning:selected:focus {
      color: #292929; }
    .entry.warning:selected:backdrop {
      color: #2c2c2c; }
  .entry.image {
    color: #c6c6c5; }
    .entry.image:hover {
      color: #eeeeec; }
    .entry.image:active {
      color: #215d9c; }
    .entry.image:backdrop {
      color: #a9aba9; }

/***********
 * Buttons *
 ***********/
@keyframes needs_attention {
  from {
    background-image: -gtk-gradient(radial, center center, 0, center center, 0.01, to(#3583d5), to(transparent)); }
  to {
    background-image: -gtk-gradient(radial, center center, 0, center center, 0.5, to(#215d9c), to(transparent)); } }
.button, .header-bar .button.titlebutton,
.titlebar .button.titlebutton,
GtkCalendar.header .button.titlebutton {
  border: 1px solid;
  border-radius: 3px;
  transition: all 200ms ease-out;
  padding: 5px 8px 6px;
  color: #eeeeec;
  outline-color: rgba(238, 238, 236, 0.3);
  border-color: #1c1f1f;
  background-image: linear-gradient(to bottom, #454c4c, #393f3f 40%, #2d3232);
  text-shadow: 0 -1px rgba(0, 0, 0, 0.81176);
  icon-shadow: 0 -1px rgba(0, 0, 0, 0.81176);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.1), 0 1px rgba(238, 238, 236, 0.1); }
  .button.flat, .header-bar .titlebutton.button,
  .titlebar .titlebutton.button,
  GtkCalendar.header .titlebutton.button {
    border-color: transparent;
    background-color: transparent;
    background-image: none;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0), 0 1px rgba(238, 238, 236, 0);
    text-shadow: none;
    icon-shadow: none; }
  .button:hover, .header-bar .button.titlebutton:hover,
  .titlebar .button.titlebutton:hover,
  GtkCalendar.header .button.titlebutton:hover {
    color: #eeeeec;
    outline-color: rgba(238, 238, 236, 0.3);
    border-color: #1c1f1f;
    background-image: linear-gradient(to bottom, #5b6464, #434a4a 40%, #393f3f);
    text-shadow: 0 -1px rgba(0, 0, 0, 0.77976);
    icon-shadow: 0 -1px rgba(0, 0, 0, 0.77976);
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.1), 0 1px rgba(238, 238, 236, 0.1);
    -gtk-image-effect: highlight; }
  .button:active, .header-bar .button.titlebutton:active,
  .titlebar .button.titlebutton:active,
  GtkCalendar.header .button.titlebutton:active, .button:checked, .header-bar .button.titlebutton:checked,
  .titlebar .button.titlebutton:checked,
  GtkCalendar.header .button.titlebutton:checked {
    color: #eeeeec;
    outline-color: rgba(238, 238, 236, 0.3);
    border-color: #1c1f1f;
    background-image: linear-gradient(to bottom, #232727, #2d3232);
    text-shadow: 0 -1px rgba(0, 0, 0, 0.89176);
    icon-shadow: 0 -1px rgba(0, 0, 0, 0.89176);
    box-shadow: inset 0 1px rgba(0, 0, 0, 0.07), inset 0 2px 1px -2px rgba(0, 0, 0, 0.6), 0 1px rgba(238, 238, 236, 0.1);
    transition-duration: 50ms; }
  .button:backdrop, .header-bar .button.titlebutton:backdrop,
  .titlebar .button.titlebutton:backdrop,
  GtkCalendar.header .button.titlebutton:backdrop, .button.flat:backdrop, .header-bar .titlebutton.button:backdrop,
  .titlebar .titlebutton.button:backdrop,
  GtkCalendar.header .titlebutton.button:backdrop {
    color: #c9cbc9;
    border-color: #1e2222;
    background-image: linear-gradient(to bottom, #393f3f);
    text-shadow: none;
    icon-shadow: none;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0), 0 1px rgba(238, 238, 236, 0);
    -gtk-image-effect: none; }
    .button:backdrop:active, .button:backdrop:checked, .button.flat:backdrop:active, .header-bar .titlebutton.button:backdrop:active,
    .titlebar .titlebutton.button:backdrop:active,
    GtkCalendar.header .titlebutton.button:backdrop:active, .button.flat:backdrop:checked, .header-bar .titlebutton.button:backdrop:checked,
    .titlebar .titlebutton.button:backdrop:checked,
    GtkCalendar.header .titlebutton.button:backdrop:checked {
      color: #c9cbc9;
      border-color: #1e2222;
      background-image: linear-gradient(to bottom, #2f3434);
      box-shadow: inset 0 1px rgba(255, 255, 255, 0), 0 1px rgba(238, 238, 236, 0); }
    .button:backdrop:insensitive, .button.flat:backdrop:insensitive, .header-bar .titlebutton.button:backdrop:insensitive,
    .titlebar .titlebutton.button:backdrop:insensitive,
    GtkCalendar.header .titlebutton.button:backdrop:insensitive {
      color: #5d6767;
      border-color: #1e2222;
      background-image: linear-gradient(to bottom, #323636);
      text-shadow: none;
      icon-shadow: none;
      box-shadow: inset 0 1px rgba(255, 255, 255, 0), 0 1px rgba(238, 238, 236, 0); }
      .button:backdrop:insensitive > GtkLabel, .button.flat:backdrop:insensitive > GtkLabel, .header-bar .titlebutton.button:backdrop:insensitive > GtkLabel,
      .titlebar .titlebutton.button:backdrop:insensitive > GtkLabel,
      GtkCalendar.header .titlebutton.button:backdrop:insensitive > GtkLabel {
        color: inherit; }
    .button:backdrop:insensitive:active, .button:backdrop:insensitive:checked, .button.flat:backdrop:insensitive:active, .header-bar .titlebutton.button:backdrop:insensitive:active,
    .titlebar .titlebutton.button:backdrop:insensitive:active,
    GtkCalendar.header .titlebutton.button:backdrop:insensitive:active, .button.flat:backdrop:insensitive:checked, .header-bar .titlebutton.button:backdrop:insensitive:checked,
    .titlebar .titlebutton.button:backdrop:insensitive:checked,
    GtkCalendar.header .titlebutton.button:backdrop:insensitive:checked {
      color: #5d6767;
      border-color: #1e2222;
      background-image: linear-gradient(to bottom, #262929);
      box-shadow: inset 0 1px rgba(255, 255, 255, 0), 0 1px rgba(238, 238, 236, 0); }
      .button:backdrop:insensitive:active > GtkLabel, .button:backdrop:insensitive:checked > GtkLabel, .button.flat:backdrop:insensitive:active > GtkLabel, .header-bar .titlebutton.button:backdrop:insensitive:active > GtkLabel,
      .titlebar .titlebutton.button:backdrop:insensitive:active > GtkLabel,
      GtkCalendar.header .titlebutton.button:backdrop:insensitive:active > GtkLabel, .button.flat:backdrop:insensitive:checked > GtkLabel, .header-bar .titlebutton.button:backdrop:insensitive:checked > GtkLabel,
      .titlebar .titlebutton.button:backdrop:insensitive:checked > GtkLabel,
      GtkCalendar.header .titlebutton.button:backdrop:insensitive:checked > GtkLabel {
        color: inherit; }
  .button.flat:backdrop, .header-bar .titlebutton.button:backdrop,
  .titlebar .titlebutton.button:backdrop,
  GtkCalendar.header .titlebutton.button:backdrop, .button.flat:insensitive, .header-bar .titlebutton.button:insensitive,
  .titlebar .titlebutton.button:insensitive,
  GtkCalendar.header .titlebutton.button:insensitive, .button.flat:backdrop:insensitive, .header-bar .titlebutton.button:backdrop:insensitive,
  .titlebar .titlebutton.button:backdrop:insensitive,
  GtkCalendar.header .titlebutton.button:backdrop:insensitive {
    border-color: transparent;
    background-color: transparent;
    background-image: none;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0), 0 1px rgba(238, 238, 236, 0);
    text-shadow: none;
    icon-shadow: none; }
  .button:insensitive, .header-bar .button.titlebutton:insensitive,
  .titlebar .button.titlebutton:insensitive,
  GtkCalendar.header .button.titlebutton:insensitive {
    color: #939695;
    border-color: #1c1f1f;
    background-image: linear-gradient(to bottom, #323636);
    text-shadow: none;
    icon-shadow: none;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0), 0 1px rgba(238, 238, 236, 0.1); }
    .button:insensitive > GtkLabel, .header-bar .button.titlebutton:insensitive > GtkLabel,
    .titlebar .button.titlebutton:insensitive > GtkLabel,
    GtkCalendar.header .button.titlebutton:insensitive > GtkLabel {
      color: inherit; }
    .button:insensitive:active, .button:insensitive:checked {
      color: #939695;
      border-color: #1c1f1f;
      background-image: linear-gradient(to bottom, #2f3333, #323636);
      box-shadow: inset 0 1px rgba(255, 255, 255, 0), 0 1px rgba(238, 238, 236, 0.1); }
      .button:insensitive:active > GtkLabel, .button:insensitive:checked > GtkLabel {
        color: inherit; }
  .button.osd, .header-bar .osd.button.titlebutton,
  .titlebar .osd.button.titlebutton,
  GtkCalendar.header .osd.button.titlebutton {
    color: #eeeeec;
    border-radius: 6px;
    outline-color: rgba(238, 238, 236, 0.2);
    color: #eeeeec;
    outline-color: rgba(238, 238, 236, 0.2);
    background-color: transparent;
    background-clip: padding-box;
    background-image: linear-gradient(to bottom, rgba(46, 52, 54, 0.7));
    border-color: rgba(0, 0, 0, 0.7);
    box-shadow: inset 0 -1px rgba(0, 0, 0, 0.3), inset 0 1px rgba(255, 255, 255, 0.1);
    text-shadow: 0 1px black;
    icon-shadow: 0 1px black;
    border-color: rgba(255, 255, 255, 0.1);
    box-shadow: none; }
    .button.osd.image-button, .header-bar .osd.titlebutton.button,
    .titlebar .osd.titlebutton.button,
    GtkCalendar.header .osd.titlebutton.button {
      padding: 13px; }
    .button.osd:hover {
      color: white;
      border-color: rgba(0, 0, 0, 0.7);
      background-image: linear-gradient(to bottom, rgba(74, 84, 87, 0.7));
      box-shadow: inset 0 -1px rgba(0, 0, 0, 0.3), inset 0 1px rgba(255, 255, 255, 0.1);
      text-shadow: 0 1px black;
      icon-shadow: 0 1px black;
      border-color: rgba(255, 255, 255, 0.1);
      box-shadow: none; }
    .button.osd:active, .button.osd:checked {
      color: white;
      border-color: rgba(0, 0, 0, 0.7);
      background-image: linear-gradient(to bottom, rgba(0, 0, 0, 0.7));
      box-shadow: none;
      text-shadow: none;
      icon-shadow: none;
      border-color: rgba(255, 255, 255, 0.1);
      box-shadow: none; }
    .button.osd:insensitive, .button.osd:backdrop:insensitive {
      color: #939695;
      border-color: rgba(0, 0, 0, 0.7);
      background-image: linear-gradient(to bottom, rgba(66, 71, 73, 0.7));
      box-shadow: none;
      text-shadow: none;
      icon-shadow: none;
      border-color: rgba(255, 255, 255, 0.1); }
    .button.osd:backdrop {
      color: #eeeeec;
      background-image: linear-gradient(to bottom, rgba(46, 52, 54, 0.7));
      background-clip: padding-box;
      box-shadow: none;
      text-shadow: none;
      icon-shadow: none;
      border-color: rgba(255, 255, 255, 0.1); }
  .osd .button, .osd .header-bar .button.titlebutton, .header-bar .osd .button.titlebutton,
  .osd .titlebar .button.titlebutton,
  .titlebar .osd .button.titlebutton,
  .osd GtkCalendar.header .button.titlebutton,
  GtkCalendar.header .osd .button.titlebutton {
    color: #eeeeec;
    outline-color: rgba(238, 238, 236, 0.2);
    background-color: transparent;
    background-clip: padding-box;
    background-image: linear-gradient(to bottom, rgba(46, 52, 54, 0.7));
    border-color: rgba(0, 0, 0, 0.7);
    box-shadow: inset 0 -1px rgba(0, 0, 0, 0.3), inset 0 1px rgba(255, 255, 255, 0.1);
    text-shadow: 0 1px black;
    icon-shadow: 0 1px black;
    border-radius: 0;
    border-left-style: none; }
    .osd .button:dir(rtl) {
      border-radius: 0;
      border-right-style: none;
      border-left-style: solid; }
    .osd .button:first-child {
      border-radius: 3px 0 0 3px;
      border-left-style: solid; }
    .osd .button:last-child {
      border-radius: 0 3px 3px 0; }
      .osd .button:last-child:dir(rtl) {
        border-right-style: solid; }
    .osd .button:only-child {
      border-radius: 3px;
      border-style: solid; }
    .osd .button:hover {
      color: white;
      border-color: rgba(0, 0, 0, 0.7);
      background-image: linear-gradient(to bottom, rgba(74, 84, 87, 0.7));
      box-shadow: inset 0 -1px rgba(0, 0, 0, 0.3), inset 0 1px rgba(255, 255, 255, 0.1);
      text-shadow: 0 1px black;
      icon-shadow: 0 1px black; }
    .osd .button:active, .osd .button:checked, .osd .button:backdrop:active, .osd .button:backdrop:checked {
      color: white;
      border-color: rgba(0, 0, 0, 0.7);
      background-image: linear-gradient(to bottom, rgba(0, 0, 0, 0.7));
      box-shadow: none;
      text-shadow: none;
      icon-shadow: none; }
    .osd .button:insensitive, .osd .button:backdrop:insensitive {
      color: #939695;
      border-color: rgba(0, 0, 0, 0.7);
      background-image: linear-gradient(to bottom, rgba(66, 71, 73, 0.7));
      box-shadow: none;
      text-shadow: none;
      icon-shadow: none; }
    .osd .button:backdrop {
      color: #eeeeec;
      background-image: linear-gradient(to bottom, rgba(46, 52, 54, 0.7));
      background-clip: padding-box;
      box-shadow: none;
      text-shadow: none;
      icon-shadow: none; }
  .button.suggested-action, .header-bar .suggested-action.button.titlebutton,
  .titlebar .suggested-action.button.titlebutton,
  GtkCalendar.header .suggested-action.button.titlebutton {
    color: white;
    outline-color: rgba(255, 255, 255, 0.3);
    border-color: #0b1e33;
    background-image: linear-gradient(to bottom, #256ab1, #215d9c 40%, #1c5187);
    text-shadow: 0 -1px rgba(0, 0, 0, 0.70353);
    icon-shadow: 0 -1px rgba(0, 0, 0, 0.70353);
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.1), 0 1px rgba(238, 238, 236, 0.1); }
    .button.suggested-action.flat, .header-bar .suggested-action.titlebutton.button,
    .titlebar .suggested-action.titlebutton.button,
    GtkCalendar.header .suggested-action.titlebutton.button {
      border-color: transparent;
      background-color: transparent;
      background-image: none;
      box-shadow: inset 0 1px rgba(255, 255, 255, 0), 0 1px rgba(238, 238, 236, 0);
      text-shadow: none;
      icon-shadow: none;
      color: #215d9c; }
    .button.suggested-action:hover {
      color: white;
      outline-color: rgba(255, 255, 255, 0.3);
      border-color: #0b1e33;
      background-image: linear-gradient(to bottom, #3180d4, #2467ad 40%, #215d9c);
      text-shadow: 0 -1px rgba(0, 0, 0, 0.67153);
      icon-shadow: 0 -1px rgba(0, 0, 0, 0.67153);
      box-shadow: inset 0 1px rgba(255, 255, 255, 0.1), 0 1px rgba(238, 238, 236, 0.1); }
    .button.suggested-action:active, .button.suggested-action:checked {
      color: white;
      outline-color: rgba(255, 255, 255, 0.3);
      border-color: #0b1e33;
      background-image: linear-gradient(to bottom, #194776, #1c5187);
      text-shadow: 0 -1px rgba(0, 0, 0, 0.78353);
      icon-shadow: 0 -1px rgba(0, 0, 0, 0.78353);
      box-shadow: inset 0 1px rgba(0, 0, 0, 0.07), inset 0 2px 1px -2px rgba(0, 0, 0, 0.6), 0 1px rgba(238, 238, 236, 0.1); }
    .button.suggested-action:backdrop, .button.suggested-action.flat:backdrop, .header-bar .suggested-action.titlebutton.button:backdrop,
    .titlebar .suggested-action.titlebutton.button:backdrop,
    GtkCalendar.header .suggested-action.titlebutton.button:backdrop {
      color: #d2deeb;
      border-color: #0b1e33;
      background-image: linear-gradient(to bottom, #215d9c);
      text-shadow: none;
      icon-shadow: none;
      box-shadow: inset 0 1px rgba(255, 255, 255, 0), 0 1px rgba(238, 238, 236, 0); }
      .button.suggested-action:backdrop:active, .button.suggested-action:backdrop:checked, .button.suggested-action.flat:backdrop:active, .header-bar .suggested-action.titlebutton.button:backdrop:active,
      .titlebar .suggested-action.titlebutton.button:backdrop:active,
      GtkCalendar.header .suggested-action.titlebutton.button:backdrop:active, .button.suggested-action.flat:backdrop:checked, .header-bar .suggested-action.titlebutton.button:backdrop:checked,
      .titlebar .suggested-action.titlebutton.button:backdrop:checked,
      GtkCalendar.header .suggested-action.titlebutton.button:backdrop:checked {
        color: #d0d9e2;
        border-color: #0b1e33;
        background-image: linear-gradient(to bottom, #184472);
        box-shadow: inset 0 1px rgba(255, 255, 255, 0), 0 1px rgba(238, 238, 236, 0); }
      .button.suggested-action:backdrop:insensitive, .button.suggested-action.flat:backdrop:insensitive, .header-bar .suggested-action.titlebutton.button:backdrop:insensitive,
      .titlebar .suggested-action.titlebutton.button:backdrop:insensitive,
      GtkCalendar.header .suggested-action.titlebutton.button:backdrop:insensitive {
        color: #5d6767;
        border-color: #1e2222;
        background-image: linear-gradient(to bottom, #323636);
        text-shadow: none;
        icon-shadow: none;
        box-shadow: inset 0 1px rgba(255, 255, 255, 0), 0 1px rgba(238, 238, 236, 0); }
        .button.suggested-action:backdrop:insensitive > GtkLabel, .button.suggested-action.flat:backdrop:insensitive > GtkLabel, .header-bar .suggested-action.titlebutton.button:backdrop:insensitive > GtkLabel,
        .titlebar .suggested-action.titlebutton.button:backdrop:insensitive > GtkLabel,
        GtkCalendar.header .suggested-action.titlebutton.button:backdrop:insensitive > GtkLabel {
          color: inherit; }
        .button.suggested-action:backdrop:insensitive:active, .button.suggested-action:backdrop:insensitive:checked, .button.suggested-action.flat:backdrop:insensitive:active, .header-bar .suggested-action.titlebutton.button:backdrop:insensitive:active,
        .titlebar .suggested-action.titlebutton.button:backdrop:insensitive:active,
        GtkCalendar.header .suggested-action.titlebutton.button:backdrop:insensitive:active, .button.suggested-action.flat:backdrop:insensitive:checked, .header-bar .suggested-action.titlebutton.button:backdrop:insensitive:checked,
        .titlebar .suggested-action.titlebutton.button:backdrop:insensitive:checked,
        GtkCalendar.header .suggested-action.titlebutton.button:backdrop:insensitive:checked {
          color: #6c88a5;
          border-color: #0b1e33;
          background-image: linear-gradient(to bottom, #1d4876);
          box-shadow: inset 0 1px rgba(255, 255, 255, 0), 0 1px rgba(238, 238, 236, 0); }
          .button.suggested-action:backdrop:insensitive:active > GtkLabel, .button.suggested-action:backdrop:insensitive:checked > GtkLabel, .button.suggested-action.flat:backdrop:insensitive:active > GtkLabel, .header-bar .suggested-action.titlebutton.button:backdrop:insensitive:active > GtkLabel,
          .titlebar .suggested-action.titlebutton.button:backdrop:insensitive:active > GtkLabel,
          GtkCalendar.header .suggested-action.titlebutton.button:backdrop:insensitive:active > GtkLabel, .button.suggested-action.flat:backdrop:insensitive:checked > GtkLabel, .header-bar .suggested-action.titlebutton.button:backdrop:insensitive:checked > GtkLabel,
          .titlebar .suggested-action.titlebutton.button:backdrop:insensitive:checked > GtkLabel,
          GtkCalendar.header .suggested-action.titlebutton.button:backdrop:insensitive:checked > GtkLabel {
            color: inherit; }
    .button.suggested-action.flat:backdrop, .header-bar .suggested-action.titlebutton.button:backdrop,
    .titlebar .suggested-action.titlebutton.button:backdrop,
    GtkCalendar.header .suggested-action.titlebutton.button:backdrop, .button.suggested-action.flat:insensitive, .header-bar .suggested-action.titlebutton.button:insensitive,
    .titlebar .suggested-action.titlebutton.button:insensitive,
    GtkCalendar.header .suggested-action.titlebutton.button:insensitive, .button.suggested-action.flat:backdrop:insensitive, .header-bar .suggested-action.titlebutton.button:backdrop:insensitive,
    .titlebar .suggested-action.titlebutton.button:backdrop:insensitive,
    GtkCalendar.header .suggested-action.titlebutton.button:backdrop:insensitive {
      border-color: transparent;
      background-color: transparent;
      background-image: none;
      box-shadow: inset 0 1px rgba(255, 255, 255, 0), 0 1px rgba(238, 238, 236, 0);
      text-shadow: none;
      icon-shadow: none;
      color: rgba(33, 93, 156, 0.8); }
    .button.suggested-action:insensitive {
      color: #939695;
      border-color: #1c1f1f;
      background-image: linear-gradient(to bottom, #323636);
      text-shadow: none;
      icon-shadow: none;
      box-shadow: inset 0 1px rgba(255, 255, 255, 0), 0 1px rgba(238, 238, 236, 0.1); }
      .button.suggested-action:insensitive > GtkLabel {
        color: inherit; }
      .button.suggested-action:insensitive:active, .button.suggested-action:insensitive:checked {
        color: #a4b5c8;
        border-color: #0b1e33;
        background-image: linear-gradient(to bottom, #1b436f, #1d4876);
        box-shadow: inset 0 1px rgba(255, 255, 255, 0), 0 1px rgba(238, 238, 236, 0.1); }
        .button.suggested-action:insensitive:active > GtkLabel, .button.suggested-action:insensitive:checked > GtkLabel {
          color: inherit; }
    .osd .button.suggested-action {
      color: #eeeeec;
      outline-color: rgba(238, 238, 236, 0.2);
      background-color: transparent;
      background-clip: padding-box;
      background-image: linear-gradient(to bottom, rgba(33, 93, 156, 0.5));
      border-color: rgba(0, 0, 0, 0.7);
      box-shadow: inset 0 -1px rgba(0, 0, 0, 0.3), inset 0 1px rgba(255, 255, 255, 0.1);
      text-shadow: 0 1px black;
      icon-shadow: 0 1px black; }
      .osd .button.suggested-action:hover {
        color: white;
        border-color: rgba(0, 0, 0, 0.7);
        background-image: linear-gradient(to bottom, rgba(33, 93, 156, 0.7));
        box-shadow: inset 0 -1px rgba(0, 0, 0, 0.3), inset 0 1px rgba(255, 255, 255, 0.1);
        text-shadow: 0 1px black;
        icon-shadow: 0 1px black; }
      .osd .button.suggested-action:active, .osd .button.suggested-action:checked, .osd .button.suggested-action:backdrop:active, .osd .button.suggested-action:backdrop:checked {
        color: white;
        border-color: rgba(0, 0, 0, 0.7);
        background-image: linear-gradient(to bottom, #215d9c);
        box-shadow: none;
        text-shadow: none;
        icon-shadow: none; }
      .osd .button.suggested-action:insensitive, .osd .button.suggested-action:backdrop:insensitive {
        color: #939695;
        border-color: rgba(0, 0, 0, 0.7);
        background-image: linear-gradient(to bottom, rgba(66, 71, 73, 0.7));
        box-shadow: none;
        text-shadow: none;
        icon-shadow: none; }
      .osd .button.suggested-action:backdrop {
        color: #eeeeec;
        background-image: linear-gradient(to bottom, rgba(33, 93, 156, 0.5));
        background-clip: padding-box;
        box-shadow: none;
        text-shadow: none;
        icon-shadow: none; }
  .button.destructive-action, .header-bar .destructive-action.button.titlebutton,
  .titlebar .destructive-action.button.titlebutton,
  GtkCalendar.header .destructive-action.button.titlebutton {
    color: white;
    outline-color: rgba(255, 255, 255, 0.3);
    border-color: #5e0707;
    background-image: linear-gradient(to bottom, #ed1212, #d51010 40%, #bd0e0e);
    text-shadow: 0 -1px rgba(0, 0, 0, 0.64078);
    icon-shadow: 0 -1px rgba(0, 0, 0, 0.64078);
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.3), 0 1px rgba(238, 238, 236, 0.1); }
    .button.destructive-action.flat, .header-bar .destructive-action.titlebutton.button,
    .titlebar .destructive-action.titlebutton.button,
    GtkCalendar.header .destructive-action.titlebutton.button {
      border-color: transparent;
      background-color: transparent;
      background-image: none;
      box-shadow: inset 0 1px rgba(255, 255, 255, 0), 0 1px rgba(238, 238, 236, 0);
      text-shadow: none;
      icon-shadow: none;
      color: #d51010; }
    .button.destructive-action:hover {
      color: white;
      outline-color: rgba(255, 255, 255, 0.3);
      border-color: #5e0707;
      background-image: linear-gradient(to bottom, #f03c3c, #e81111 40%, #d51010);
      text-shadow: 0 -1px rgba(0, 0, 0, 0.60878);
      icon-shadow: 0 -1px rgba(0, 0, 0, 0.60878);
      box-shadow: inset 0 1px rgba(255, 255, 255, 0.3), 0 1px rgba(238, 238, 236, 0.1); }
    .button.destructive-action:active, .button.destructive-action:checked {
      color: white;
      outline-color: rgba(255, 255, 255, 0.3);
      border-color: #5e0707;
      background-image: linear-gradient(to bottom, #aa0d0d, #bd0e0e);
      text-shadow: 0 -1px rgba(0, 0, 0, 0.72078);
      icon-shadow: 0 -1px rgba(0, 0, 0, 0.72078);
      box-shadow: inset 0 1px rgba(0, 0, 0, 0.07), inset 0 2px 1px -2px rgba(0, 0, 0, 0.6), 0 1px rgba(238, 238, 236, 0.1); }
    .button.destructive-action:backdrop, .button.destructive-action.flat:backdrop, .header-bar .destructive-action.titlebutton.button:backdrop,
    .titlebar .destructive-action.titlebutton.button:backdrop,
    GtkCalendar.header .destructive-action.titlebutton.button:backdrop {
      color: #f6cfcf;
      border-color: #5e0707;
      background-image: linear-gradient(to bottom, #d51010);
      text-shadow: none;
      icon-shadow: none;
      box-shadow: inset 0 1px rgba(255, 255, 255, 0), 0 1px rgba(238, 238, 236, 0); }
      .button.destructive-action:backdrop:active, .button.destructive-action:backdrop:checked, .button.destructive-action.flat:backdrop:active, .header-bar .destructive-action.titlebutton.button:backdrop:active,
      .titlebar .destructive-action.titlebutton.button:backdrop:active,
      GtkCalendar.header .destructive-action.titlebutton.button:backdrop:active, .button.destructive-action.flat:backdrop:checked, .header-bar .destructive-action.titlebutton.button:backdrop:checked,
      .titlebar .destructive-action.titlebutton.button:backdrop:checked,
      GtkCalendar.header .destructive-action.titlebutton.button:backdrop:checked {
        color: #edcece;
        border-color: #5e0707;
        background-image: linear-gradient(to bottom, #a60c0c);
        box-shadow: inset 0 1px rgba(255, 255, 255, 0), 0 1px rgba(238, 238, 236, 0); }
      .button.destructive-action:backdrop:insensitive, .button.destructive-action.flat:backdrop:insensitive, .header-bar .destructive-action.titlebutton.button:backdrop:insensitive,
      .titlebar .destructive-action.titlebutton.button:backdrop:insensitive,
      GtkCalendar.header .destructive-action.titlebutton.button:backdrop:insensitive {
        color: #5d6767;
        border-color: #1e2222;
        background-image: linear-gradient(to bottom, #323636);
        text-shadow: none;
        icon-shadow: none;
        box-shadow: inset 0 1px rgba(255, 255, 255, 0), 0 1px rgba(238, 238, 236, 0); }
        .button.destructive-action:backdrop:insensitive > GtkLabel, .button.destructive-action.flat:backdrop:insensitive > GtkLabel, .header-bar .destructive-action.titlebutton.button:backdrop:insensitive > GtkLabel,
        .titlebar .destructive-action.titlebutton.button:backdrop:insensitive > GtkLabel,
        GtkCalendar.header .destructive-action.titlebutton.button:backdrop:insensitive > GtkLabel {
          color: inherit; }
        .button.destructive-action:backdrop:insensitive:active, .button.destructive-action:backdrop:insensitive:checked, .button.destructive-action.flat:backdrop:insensitive:active, .header-bar .destructive-action.titlebutton.button:backdrop:insensitive:active,
        .titlebar .destructive-action.titlebutton.button:backdrop:insensitive:active,
        GtkCalendar.header .destructive-action.titlebutton.button:backdrop:insensitive:active, .button.destructive-action.flat:backdrop:insensitive:checked, .header-bar .destructive-action.titlebutton.button:backdrop:insensitive:checked,
        .titlebar .destructive-action.titlebutton.button:backdrop:insensitive:checked,
        GtkCalendar.header .destructive-action.titlebutton.button:backdrop:insensitive:checked {
          color: #c36464;
          border-color: #5e0707;
          background-image: linear-gradient(to bottom, #a41111);
          box-shadow: inset 0 1px rgba(255, 255, 255, 0), 0 1px rgba(238, 238, 236, 0); }
          .button.destructive-action:backdrop:insensitive:active > GtkLabel, .button.destructive-action:backdrop:insensitive:checked > GtkLabel, .button.destructive-action.flat:backdrop:insensitive:active > GtkLabel, .header-bar .destructive-action.titlebutton.button:backdrop:insensitive:active > GtkLabel,
          .titlebar .destructive-action.titlebutton.button:backdrop:insensitive:active > GtkLabel,
          GtkCalendar.header .destructive-action.titlebutton.button:backdrop:insensitive:active > GtkLabel, .button.destructive-action.flat:backdrop:insensitive:checked > GtkLabel, .header-bar .destructive-action.titlebutton.button:backdrop:insensitive:checked > GtkLabel,
          .titlebar .destructive-action.titlebutton.button:backdrop:insensitive:checked > GtkLabel,
          GtkCalendar.header .destructive-action.titlebutton.button:backdrop:insensitive:checked > GtkLabel {
            color: inherit; }
    .button.destructive-action.flat:backdrop, .header-bar .destructive-action.titlebutton.button:backdrop,
    .titlebar .destructive-action.titlebutton.button:backdrop,
    GtkCalendar.header .destructive-action.titlebutton.button:backdrop, .button.destructive-action.flat:insensitive, .header-bar .destructive-action.titlebutton.button:insensitive,
    .titlebar .destructive-action.titlebutton.button:insensitive,
    GtkCalendar.header .destructive-action.titlebutton.button:insensitive, .button.destructive-action.flat:backdrop:insensitive, .header-bar .destructive-action.titlebutton.button:backdrop:insensitive,
    .titlebar .destructive-action.titlebutton.button:backdrop:insensitive,
    GtkCalendar.header .destructive-action.titlebutton.button:backdrop:insensitive {
      border-color: transparent;
      background-color: transparent;
      background-image: none;
      box-shadow: inset 0 1px rgba(255, 255, 255, 0), 0 1px rgba(238, 238, 236, 0);
      text-shadow: none;
      icon-shadow: none;
      color: rgba(213, 16, 16, 0.8); }
    .button.destructive-action:insensitive {
      color: #939695;
      border-color: #1c1f1f;
      background-image: linear-gradient(to bottom, #323636);
      text-shadow: none;
      icon-shadow: none;
      box-shadow: inset 0 1px rgba(255, 255, 255, 0), 0 1px rgba(238, 238, 236, 0.1); }
      .button.destructive-action:insensitive > GtkLabel {
        color: inherit; }
      .button.destructive-action:insensitive:active, .button.destructive-action:insensitive:checked {
        color: #da9f9f;
        border-color: #5e0707;
        background-image: linear-gradient(to bottom, #9d1010, #a41111);
        box-shadow: inset 0 1px rgba(255, 255, 255, 0), 0 1px rgba(238, 238, 236, 0.1); }
        .button.destructive-action:insensitive:active > GtkLabel, .button.destructive-action:insensitive:checked > GtkLabel {
          color: inherit; }
    .osd .button.destructive-action {
      color: #eeeeec;
      outline-color: rgba(238, 238, 236, 0.2);
      background-color: transparent;
      background-clip: padding-box;
      background-image: linear-gradient(to bottom, rgba(213, 16, 16, 0.5));
      border-color: rgba(0, 0, 0, 0.7);
      box-shadow: inset 0 -1px rgba(0, 0, 0, 0.3), inset 0 1px rgba(255, 255, 255, 0.1);
      text-shadow: 0 1px black;
      icon-shadow: 0 1px black; }
      .osd .button.destructive-action:hover {
        color: white;
        border-color: rgba(0, 0, 0, 0.7);
        background-image: linear-gradient(to bottom, rgba(213, 16, 16, 0.7));
        box-shadow: inset 0 -1px rgba(0, 0, 0, 0.3), inset 0 1px rgba(255, 255, 255, 0.1);
        text-shadow: 0 1px black;
        icon-shadow: 0 1px black; }
      .osd .button.destructive-action:active, .osd .button.destructive-action:checked, .osd .button.destructive-action:backdrop:active, .osd .button.destructive-action:backdrop:checked {
        color: white;
        border-color: rgba(0, 0, 0, 0.7);
        background-image: linear-gradient(to bottom, #d51010);
        box-shadow: none;
        text-shadow: none;
        icon-shadow: none; }
      .osd .button.destructive-action:insensitive, .osd .button.destructive-action:backdrop:insensitive {
        color: #939695;
        border-color: rgba(0, 0, 0, 0.7);
        background-image: linear-gradient(to bottom, rgba(66, 71, 73, 0.7));
        box-shadow: none;
        text-shadow: none;
        icon-shadow: none; }
      .osd .button.destructive-action:backdrop {
        color: #eeeeec;
        background-image: linear-gradient(to bottom, rgba(213, 16, 16, 0.5));
        background-clip: padding-box;
        box-shadow: none;
        text-shadow: none;
        icon-shadow: none; }
  .button.image-button, .header-bar .titlebutton.button,
  .titlebar .titlebutton.button,
  GtkCalendar.header .titlebutton.button {
    padding: 8px; }
  .button.text-button, .header-bar .text-button.button.titlebutton,
  .titlebar .text-button.button.titlebutton,
  GtkCalendar.header .text-button.button.titlebutton {
    padding-left: 16px;
    padding-right: 16px; }
  .button.text-button.image-button, .header-bar .text-button.titlebutton.button,
  .titlebar .text-button.titlebutton.button,
  GtkCalendar.header .text-button.titlebutton.button {
    padding: 5px 8px 6px; }
    .button.text-button.image-button GtkLabel:first-child, .header-bar .text-button.titlebutton.button GtkLabel:first-child,
    .titlebar .text-button.titlebutton.button GtkLabel:first-child,
    GtkCalendar.header .text-button.titlebutton.button GtkLabel:first-child {
      padding-left: 8px; }
    .button.text-button.image-button GtkLabel:last-child, .header-bar .text-button.titlebutton.button GtkLabel:last-child,
    .titlebar .text-button.titlebutton.button GtkLabel:last-child,
    GtkCalendar.header .text-button.titlebutton.button GtkLabel:last-child {
      padding-right: 8px; }
  .stack-switcher > .button > GtkLabel, .header-bar .stack-switcher > .button.titlebutton > GtkLabel,
  .titlebar .stack-switcher > .button.titlebutton > GtkLabel,
  GtkCalendar.header .stack-switcher > .button.titlebutton > GtkLabel {
    padding-left: 6px;
    padding-right: 6px; }
  .stack-switcher > .button > GtkImage, .header-bar .stack-switcher > .button.titlebutton > GtkImage,
  .titlebar .stack-switcher > .button.titlebutton > GtkImage,
  GtkCalendar.header .stack-switcher > .button.titlebutton > GtkImage {
    padding-left: 6px;
    padding-right: 6px;
    padding-top: 3px;
    padding-bottom: 3px; }
  .stack-switcher > .button.text-button {
    padding: 5px 10px 6px; }
  .stack-switcher > .button.image-button, .header-bar .stack-switcher > .titlebutton.button,
  .titlebar .stack-switcher > .titlebutton.button,
  GtkCalendar.header .stack-switcher > .titlebutton.button {
    padding: 5px 2px; }
  .stack-switcher > .button.needs-attention > GtkLabel, .stack-switcher > .button.needs-attention > GtkImage {
    animation: needs_attention 150ms ease-in;
    background-image: -gtk-gradient(radial, center center, 0, center center, 0.5, to(#3583d5), to(transparent)), -gtk-gradient(radial, center center, 0, center center, 0.45, to(rgba(0, 0, 0, 0.81176)), to(transparent));
    background-size: 6px 6px, 6px 6px;
    background-repeat: no-repeat;
    background-position: right 3px, right 2px; }
    .stack-switcher > .button.needs-attention > GtkLabel:backdrop, .stack-switcher > .button.needs-attention > GtkImage:backdrop {
      background-size: 6px 6px, 0 0; }
    .stack-switcher > .button.needs-attention > GtkLabel:dir(rtl), .stack-switcher > .button.needs-attention > GtkImage:dir(rtl) {
      background-position: left 3px, left 2px; }
  .stack-switcher > .button.needs-attention:active > GtkLabel, .stack-switcher > .button.needs-attention:active > GtkImage, .stack-switcher > .button.needs-attention:checked > GtkLabel, .stack-switcher > .button.needs-attention:checked > GtkImage {
    animation: none;
    background-image: none; }
  .inline-toolbar .button, .inline-toolbar .header-bar .button.titlebutton, .header-bar .inline-toolbar .button.titlebutton,
  .inline-toolbar .titlebar .button.titlebutton,
  .titlebar .inline-toolbar .button.titlebutton,
  .inline-toolbar GtkCalendar.header .button.titlebutton,
  GtkCalendar.header .inline-toolbar .button.titlebutton, .inline-toolbar .button:backdrop {
    border-radius: 2px;
    border-width: 1px; }
  .primary-toolbar .button, .primary-toolbar .header-bar .button.titlebutton, .header-bar .primary-toolbar .button.titlebutton,
  .primary-toolbar .titlebar .button.titlebutton,
  .titlebar .primary-toolbar .button.titlebutton,
  .primary-toolbar GtkCalendar.header .button.titlebutton,
  GtkCalendar.header .primary-toolbar .button.titlebutton {
    icon-shadow: none; }

.inline-toolbar GtkToolButton > .button, .inline-toolbar .header-bar GtkToolButton > .button.titlebutton, .header-bar .inline-toolbar GtkToolButton > .button.titlebutton,
.inline-toolbar .titlebar GtkToolButton > .button.titlebutton,
.titlebar .inline-toolbar GtkToolButton > .button.titlebutton,
.inline-toolbar GtkCalendar.header GtkToolButton > .button.titlebutton,
GtkCalendar.header .inline-toolbar GtkToolButton > .button.titlebutton {
  color: #eeeeec;
  outline-color: rgba(238, 238, 236, 0.3);
  border-color: #1c1f1f;
  background-image: linear-gradient(to bottom, #454c4c, #393f3f 40%, #2d3232);
  text-shadow: 0 -1px rgba(0, 0, 0, 0.81176);
  icon-shadow: 0 -1px rgba(0, 0, 0, 0.81176);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.1), 0 1px rgba(238, 238, 236, 0.1); }
  .inline-toolbar GtkToolButton > .button:hover {
    color: #eeeeec;
    outline-color: rgba(238, 238, 236, 0.3);
    border-color: #1c1f1f;
    background-image: linear-gradient(to bottom, #5b6464, #434a4a 40%, #393f3f);
    text-shadow: 0 -1px rgba(0, 0, 0, 0.77976);
    icon-shadow: 0 -1px rgba(0, 0, 0, 0.77976);
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.1), 0 1px rgba(238, 238, 236, 0.1); }
  .inline-toolbar GtkToolButton > .button:active, .inline-toolbar GtkToolButton > .button:checked {
    color: #eeeeec;
    outline-color: rgba(238, 238, 236, 0.3);
    border-color: #1c1f1f;
    background-image: linear-gradient(to bottom, #232727, #2d3232);
    text-shadow: 0 -1px rgba(0, 0, 0, 0.89176);
    icon-shadow: 0 -1px rgba(0, 0, 0, 0.89176);
    box-shadow: inset 0 1px rgba(0, 0, 0, 0.07), inset 0 2px 1px -2px rgba(0, 0, 0, 0.6), 0 1px rgba(238, 238, 236, 0.1); }
  .inline-toolbar GtkToolButton > .button:insensitive {
    color: #939695;
    border-color: #1c1f1f;
    background-image: linear-gradient(to bottom, #323636);
    text-shadow: none;
    icon-shadow: none;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0), 0 1px rgba(238, 238, 236, 0.1); }
    .inline-toolbar GtkToolButton > .button:insensitive > GtkLabel {
      color: inherit; }
  .inline-toolbar GtkToolButton > .button:insensitive:active, .inline-toolbar GtkToolButton > .button:insensitive:checked {
    color: #939695;
    border-color: #1c1f1f;
    background-image: linear-gradient(to bottom, #2f3333, #323636);
    box-shadow: inset 0 1px rgba(255, 255, 255, 0), 0 1px rgba(238, 238, 236, 0.1); }
    .inline-toolbar GtkToolButton > .button:insensitive:active > GtkLabel, .inline-toolbar GtkToolButton > .button:insensitive:checked > GtkLabel {
      color: inherit; }
  .inline-toolbar GtkToolButton > .button:backdrop {
    color: #c9cbc9;
    border-color: #1e2222;
    background-image: linear-gradient(to bottom, #393f3f);
    text-shadow: none;
    icon-shadow: none;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0), 0 1px rgba(238, 238, 236, 0); }
  .inline-toolbar GtkToolButton > .button:backdrop:active, .inline-toolbar GtkToolButton > .button:backdrop:checked {
    color: #c9cbc9;
    border-color: #1e2222;
    background-image: linear-gradient(to bottom, #2f3434);
    box-shadow: inset 0 1px rgba(255, 255, 255, 0), 0 1px rgba(238, 238, 236, 0); }
  .inline-toolbar GtkToolButton > .button:backdrop:insensitive {
    color: #5d6767;
    border-color: #1e2222;
    background-image: linear-gradient(to bottom, #323636);
    text-shadow: none;
    icon-shadow: none;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0), 0 1px rgba(238, 238, 236, 0); }
    .inline-toolbar GtkToolButton > .button:backdrop:insensitive > GtkLabel {
      color: inherit; }
  .inline-toolbar GtkToolButton > .button:backdrop:insensitive:active, .inline-toolbar GtkToolButton > .button:backdrop:insensitive:checked {
    color: #5d6767;
    border-color: #1e2222;
    background-image: linear-gradient(to bottom, #262929);
    box-shadow: inset 0 1px rgba(255, 255, 255, 0), 0 1px rgba(238, 238, 236, 0); }
    .inline-toolbar GtkToolButton > .button:backdrop:insensitive:active > GtkLabel, .inline-toolbar GtkToolButton > .button:backdrop:insensitive:checked > GtkLabel {
      color: inherit; }

.inline-toolbar.toolbar GtkToolButton > .button.flat, .inline-toolbar GtkToolButton > .button.flat, .inline-toolbar.search-bar GtkToolButton > .button.flat, .inline-toolbar.location-bar GtkToolButton > .button.flat, .inline-toolbar .header-bar GtkToolButton > .button.titlebutton, .header-bar .inline-toolbar GtkToolButton > .button.titlebutton,
.inline-toolbar .titlebar GtkToolButton > .button.titlebutton,
.titlebar .inline-toolbar GtkToolButton > .button.titlebutton,
.inline-toolbar.toolbar GtkToolButton:backdrop > .button.flat,
.inline-toolbar GtkToolButton:backdrop > .button.flat,
.inline-toolbar.search-bar GtkToolButton:backdrop > .button.flat,
.inline-toolbar.location-bar GtkToolButton:backdrop > .button.flat,
.inline-toolbar .header-bar GtkToolButton:backdrop > .button.titlebutton,
.header-bar .inline-toolbar GtkToolButton:backdrop > .button.titlebutton,
.inline-toolbar .titlebar GtkToolButton:backdrop > .button.titlebutton,
.titlebar .inline-toolbar GtkToolButton:backdrop > .button.titlebutton,
.inline-toolbar GtkCalendar.header GtkToolButton:backdrop > .button.titlebutton,
GtkCalendar.header .inline-toolbar GtkToolButton:backdrop > .button.titlebutton, .osd .button:hover, .osd .button:active, .osd .button:checked, .osd .button:backdrop:active, .osd .button:backdrop:checked, .osd .button:insensitive, .osd .button:backdrop:insensitive, .osd .button:backdrop, .osd .button.suggested-action, .osd .button.suggested-action:hover, .osd .button.suggested-action:active, .osd .button.suggested-action:checked, .osd .button.suggested-action:backdrop:active, .osd .button.suggested-action:backdrop:checked, .osd .button.suggested-action:insensitive, .osd .button.suggested-action:backdrop:insensitive, .osd .button.suggested-action:backdrop, .osd .button.destructive-action, .osd .button.destructive-action:hover, .osd .button.destructive-action:active, .osd .button.destructive-action:checked, .osd .button.destructive-action:backdrop:active, .osd .button.destructive-action:backdrop:checked, .osd .button.destructive-action:insensitive, .osd .button.destructive-action:backdrop:insensitive, .osd .button.destructive-action:backdrop, .inline-toolbar .button, .inline-toolbar .header-bar .button.titlebutton, .header-bar .inline-toolbar .button.titlebutton,
.inline-toolbar .titlebar .button.titlebutton,
.titlebar .inline-toolbar .button.titlebutton,
.inline-toolbar GtkCalendar.header .button.titlebutton,
GtkCalendar.header .inline-toolbar .button.titlebutton, .inline-toolbar .button:backdrop, .linked .button, .linked .header-bar .button.titlebutton, .header-bar .linked .button.titlebutton,
.linked .titlebar .button.titlebutton,
.titlebar .linked .button.titlebutton,
.linked GtkCalendar.header .button.titlebutton,
GtkCalendar.header .linked .button.titlebutton, .linked .button:hover, .linked .button:active, .linked .button:checked, .linked .button:backdrop, GtkComboBox.combobox-entry .entry, GtkComboBox.combobox-entry .button, GtkComboBox.combobox-entry .header-bar .button.titlebutton, .header-bar GtkComboBox.combobox-entry .button.titlebutton,
GtkComboBox.combobox-entry .titlebar .button.titlebutton,
.titlebar GtkComboBox.combobox-entry .button.titlebutton,
GtkComboBox.combobox-entry GtkCalendar.header .button.titlebutton,
GtkCalendar.header GtkComboBox.combobox-entry .button.titlebutton, GtkComboBox.combobox-entry .button:backdrop, .linked > GtkComboBox > .button:dir(ltr) {
  border-radius: 0;
  border-left-style: none; }
  .inline-toolbar GtkToolButton > .button.flat:dir(rtl), .inline-toolbar .header-bar GtkToolButton > .button.titlebutton:dir(rtl), .header-bar .inline-toolbar GtkToolButton > .button.titlebutton:dir(rtl),
  .inline-toolbar .titlebar GtkToolButton > .button.titlebutton:dir(rtl),
  .titlebar .inline-toolbar GtkToolButton > .button.titlebutton:dir(rtl),
  .inline-toolbar GtkCalendar.header GtkToolButton > .titlebutton.button:dir(rtl),
  GtkCalendar.header .inline-toolbar GtkToolButton > .titlebutton.button:dir(rtl),
  .inline-toolbar GtkToolButton:backdrop > .button.flat:dir(rtl), .inline-toolbar.toolbar GtkToolButton:dir(rtl) > .button.flat, .inline-toolbar GtkToolButton:dir(rtl) > .button.flat, .inline-toolbar.search-bar GtkToolButton:dir(rtl) > .button.flat, .inline-toolbar.location-bar GtkToolButton:dir(rtl) > .button.flat, .inline-toolbar .header-bar GtkToolButton:dir(rtl) > .button.titlebutton, .header-bar .inline-toolbar GtkToolButton:dir(rtl) > .button.titlebutton,
  .inline-toolbar .titlebar GtkToolButton:dir(rtl) > .button.titlebutton,
  .titlebar .inline-toolbar GtkToolButton:dir(rtl) > .button.titlebutton,
  .inline-toolbar GtkCalendar.header GtkToolButton:dir(rtl) > .button.titlebutton,
  GtkCalendar.header .inline-toolbar GtkToolButton:dir(rtl) > .button.titlebutton,
  .inline-toolbar.toolbar GtkToolButton:backdrop:dir(rtl) > .button.flat,
  .inline-toolbar GtkToolButton:backdrop:dir(rtl) > .button.flat,
  .inline-toolbar.search-bar GtkToolButton:backdrop:dir(rtl) > .button.flat,
  .inline-toolbar.location-bar GtkToolButton:backdrop:dir(rtl) > .button.flat,
  .inline-toolbar .header-bar GtkToolButton:backdrop:dir(rtl) > .button.titlebutton,
  .header-bar .inline-toolbar GtkToolButton:backdrop:dir(rtl) > .button.titlebutton,
  .inline-toolbar .titlebar GtkToolButton:backdrop:dir(rtl) > .button.titlebutton,
  .titlebar .inline-toolbar GtkToolButton:backdrop:dir(rtl) > .button.titlebutton,
  .inline-toolbar GtkCalendar.header GtkToolButton:backdrop:dir(rtl) > .button.titlebutton,
  GtkCalendar.header .inline-toolbar GtkToolButton:backdrop:dir(rtl) > .button.titlebutton, .osd .button:dir(rtl):hover, .osd .button:dir(rtl):active, .osd .button:dir(rtl):checked, .osd .button:dir(rtl):insensitive, .osd .button:dir(rtl):backdrop, .osd .button.suggested-action:dir(rtl), .osd .button.destructive-action:dir(rtl), .inline-toolbar .button:dir(rtl), .linked .button:dir(rtl), GtkComboBox.combobox-entry .entry:dir(rtl), GtkComboBox.combobox-entry .button:dir(rtl), .linked > GtkComboBox > .button:dir(rtl) {
    border-radius: 0;
    border-right-style: none;
    border-left-style: solid; }

.osd .button:first-child:hover, .osd .button:first-child:active, .osd .button:first-child:checked, .osd .button:first-child:insensitive, .osd .button:first-child:backdrop, .osd .button.suggested-action:first-child, .osd .button.destructive-action:first-child, .inline-toolbar .button:first-child, .linked .button:first-child, .inline-toolbar.toolbar GtkToolButton:first-child > .button.flat, .inline-toolbar GtkToolButton:first-child > .button.flat, .inline-toolbar.search-bar GtkToolButton:first-child > .button.flat, .inline-toolbar.location-bar GtkToolButton:first-child > .button.flat, .inline-toolbar .header-bar GtkToolButton:first-child > .button.titlebutton, .header-bar .inline-toolbar GtkToolButton:first-child > .button.titlebutton,
.inline-toolbar .titlebar GtkToolButton:first-child > .button.titlebutton,
.titlebar .inline-toolbar GtkToolButton:first-child > .button.titlebutton,
.inline-toolbar GtkCalendar.header GtkToolButton:first-child > .button.titlebutton,
GtkCalendar.header .inline-toolbar GtkToolButton:first-child > .button.titlebutton,
.inline-toolbar.toolbar GtkToolButton:backdrop:first-child > .button.flat,
.inline-toolbar GtkToolButton:backdrop:first-child > .button.flat,
.inline-toolbar.search-bar GtkToolButton:backdrop:first-child > .button.flat,
.inline-toolbar.location-bar GtkToolButton:backdrop:first-child > .button.flat,
.inline-toolbar .header-bar GtkToolButton:backdrop:first-child > .button.titlebutton,
.header-bar .inline-toolbar GtkToolButton:backdrop:first-child > .button.titlebutton,
.inline-toolbar .titlebar GtkToolButton:backdrop:first-child > .button.titlebutton,
.titlebar .inline-toolbar GtkToolButton:backdrop:first-child > .button.titlebutton,
.inline-toolbar GtkCalendar.header GtkToolButton:backdrop:first-child > .button.titlebutton,
GtkCalendar.header .inline-toolbar GtkToolButton:backdrop:first-child > .button.titlebutton, GtkComboBox.combobox-entry .entry:first-child, GtkComboBox.combobox-entry .button:first-child, .linked > GtkComboBox:first-child > .button {
  border-radius: 3px 0 0 3px;
  border-left-style: solid; }
.osd .button:last-child:hover, .osd .button:last-child:active, .osd .button:last-child:checked, .osd .button:last-child:insensitive, .osd .button:last-child:backdrop, .osd .button.suggested-action:last-child, .osd .button.destructive-action:last-child, .inline-toolbar .button:last-child, .linked .button:last-child, .inline-toolbar.toolbar GtkToolButton:last-child > .button.flat, .inline-toolbar GtkToolButton:last-child > .button.flat, .inline-toolbar.search-bar GtkToolButton:last-child > .button.flat, .inline-toolbar.location-bar GtkToolButton:last-child > .button.flat, .inline-toolbar .header-bar GtkToolButton:last-child > .button.titlebutton, .header-bar .inline-toolbar GtkToolButton:last-child > .button.titlebutton,
.inline-toolbar .titlebar GtkToolButton:last-child > .button.titlebutton,
.titlebar .inline-toolbar GtkToolButton:last-child > .button.titlebutton,
.inline-toolbar GtkCalendar.header GtkToolButton:last-child > .button.titlebutton,
GtkCalendar.header .inline-toolbar GtkToolButton:last-child > .button.titlebutton,
.inline-toolbar.toolbar GtkToolButton:backdrop:last-child > .button.flat,
.inline-toolbar GtkToolButton:backdrop:last-child > .button.flat,
.inline-toolbar.search-bar GtkToolButton:backdrop:last-child > .button.flat,
.inline-toolbar.location-bar GtkToolButton:backdrop:last-child > .button.flat,
.inline-toolbar .header-bar GtkToolButton:backdrop:last-child > .button.titlebutton,
.header-bar .inline-toolbar GtkToolButton:backdrop:last-child > .button.titlebutton,
.inline-toolbar .titlebar GtkToolButton:backdrop:last-child > .button.titlebutton,
.titlebar .inline-toolbar GtkToolButton:backdrop:last-child > .button.titlebutton,
.inline-toolbar GtkCalendar.header GtkToolButton:backdrop:last-child > .button.titlebutton,
GtkCalendar.header .inline-toolbar GtkToolButton:backdrop:last-child > .button.titlebutton, GtkComboBox.combobox-entry .entry:last-child, GtkComboBox.combobox-entry .button:last-child, .linked > GtkComboBox:last-child > .button {
  border-radius: 0 3px 3px 0; }
  .osd .button:last-child:dir(rtl):hover, .osd .button:last-child:dir(rtl):active, .osd .button:last-child:dir(rtl):checked, .osd .button:last-child:dir(rtl):insensitive, .osd .button:last-child:dir(rtl):backdrop, .osd .button.suggested-action:last-child:dir(rtl), .osd .button.destructive-action:last-child:dir(rtl), .inline-toolbar .button:last-child:dir(rtl), .linked .button:last-child:dir(rtl), .inline-toolbar GtkToolButton:last-child > .button.flat:dir(rtl), .inline-toolbar .header-bar GtkToolButton:last-child > .button.titlebutton:dir(rtl), .header-bar .inline-toolbar GtkToolButton:last-child > .button.titlebutton:dir(rtl),
  .inline-toolbar .titlebar GtkToolButton:last-child > .button.titlebutton:dir(rtl),
  .titlebar .inline-toolbar GtkToolButton:last-child > .button.titlebutton:dir(rtl),
  .inline-toolbar GtkCalendar.header GtkToolButton:last-child > .button.titlebutton:dir(rtl),
  GtkCalendar.header .inline-toolbar GtkToolButton:last-child > .button.titlebutton:dir(rtl),
  .inline-toolbar GtkToolButton:backdrop:last-child > .button.flat:dir(rtl), .inline-toolbar.toolbar GtkToolButton:last-child:dir(rtl) > .button.flat, .inline-toolbar GtkToolButton:last-child:dir(rtl) > .button.flat, .inline-toolbar.search-bar GtkToolButton:last-child:dir(rtl) > .button.flat, .inline-toolbar.location-bar GtkToolButton:last-child:dir(rtl) > .button.flat, .inline-toolbar .header-bar GtkToolButton:last-child:dir(rtl) > .button.titlebutton, .header-bar .inline-toolbar GtkToolButton:last-child:dir(rtl) > .button.titlebutton,
  .inline-toolbar .titlebar GtkToolButton:last-child:dir(rtl) > .button.titlebutton,
  .titlebar .inline-toolbar GtkToolButton:last-child:dir(rtl) > .button.titlebutton,
  .inline-toolbar GtkCalendar.header GtkToolButton:last-child:dir(rtl) > .button.titlebutton,
  GtkCalendar.header .inline-toolbar GtkToolButton:last-child:dir(rtl) > .button.titlebutton,
  .inline-toolbar.toolbar GtkToolButton:backdrop:last-child:dir(rtl) > .button.flat,
  .inline-toolbar GtkToolButton:backdrop:last-child:dir(rtl) > .button.flat,
  .inline-toolbar.search-bar GtkToolButton:backdrop:last-child:dir(rtl) > .button.flat,
  .inline-toolbar.location-bar GtkToolButton:backdrop:last-child:dir(rtl) > .button.flat,
  .inline-toolbar .header-bar GtkToolButton:backdrop:last-child:dir(rtl) > .button.titlebutton,
  .header-bar .inline-toolbar GtkToolButton:backdrop:last-child:dir(rtl) > .button.titlebutton,
  .inline-toolbar .titlebar GtkToolButton:backdrop:last-child:dir(rtl) > .button.titlebutton,
  .titlebar .inline-toolbar GtkToolButton:backdrop:last-child:dir(rtl) > .button.titlebutton,
  .inline-toolbar GtkCalendar.header GtkToolButton:backdrop:last-child:dir(rtl) > .button.titlebutton,
  GtkCalendar.header .inline-toolbar GtkToolButton:backdrop:last-child:dir(rtl) > .button.titlebutton, GtkComboBox.combobox-entry .entry:last-child:dir(rtl), GtkComboBox.combobox-entry .button:last-child:dir(rtl), .linked > GtkComboBox:last-child > .button:dir(rtl) {
    border-right-style: solid; }
.osd .button:only-child:hover, .osd .button:only-child:active, .osd .button:only-child:checked, .osd .button:only-child:insensitive, .osd .button:only-child:backdrop, .osd .button.suggested-action:only-child, .osd .button.destructive-action:only-child, .inline-toolbar .button:only-child, .linked .button:only-child, .inline-toolbar.toolbar GtkToolButton:only-child > .button.flat, .inline-toolbar GtkToolButton:only-child > .button.flat, .inline-toolbar.search-bar GtkToolButton:only-child > .button.flat, .inline-toolbar.location-bar GtkToolButton:only-child > .button.flat, .inline-toolbar .header-bar GtkToolButton:only-child > .button.titlebutton, .header-bar .inline-toolbar GtkToolButton:only-child > .button.titlebutton,
.inline-toolbar .titlebar GtkToolButton:only-child > .button.titlebutton,
.titlebar .inline-toolbar GtkToolButton:only-child > .button.titlebutton,
.inline-toolbar GtkCalendar.header GtkToolButton:only-child > .button.titlebutton,
GtkCalendar.header .inline-toolbar GtkToolButton:only-child > .button.titlebutton,
.inline-toolbar.toolbar GtkToolButton:backdrop:only-child > .button.flat,
.inline-toolbar GtkToolButton:backdrop:only-child > .button.flat,
.inline-toolbar.search-bar GtkToolButton:backdrop:only-child > .button.flat,
.inline-toolbar.location-bar GtkToolButton:backdrop:only-child > .button.flat,
.inline-toolbar .header-bar GtkToolButton:backdrop:only-child > .button.titlebutton,
.header-bar .inline-toolbar GtkToolButton:backdrop:only-child > .button.titlebutton,
.inline-toolbar .titlebar GtkToolButton:backdrop:only-child > .button.titlebutton,
.titlebar .inline-toolbar GtkToolButton:backdrop:only-child > .button.titlebutton,
.inline-toolbar GtkCalendar.header GtkToolButton:backdrop:only-child > .button.titlebutton,
GtkCalendar.header .inline-toolbar GtkToolButton:backdrop:only-child > .button.titlebutton, GtkComboBox.combobox-entry .entry:only-child, GtkComboBox.combobox-entry .button:only-child, .linked > GtkComboBox:only-child > .button {
  border-radius: 3px;
  border-style: solid; }

.linked.vertical .button, .linked.vertical .button:hover, .linked.vertical .button:active, .linked.vertical .button:checked, .linked.vertical .button:backdrop {
  border-left-style: solid;
  border-top-style: none; }
  .linked.vertical .button:first-child {
    border-style: solid;
    border-radius: 3px 3px 0 0; }
  .linked.vertical .button:last-child {
    border-radius: 0 0 3px 3px; }
  .linked.vertical .button:only-child {
    border-radius: 3px;
    border-style: solid; }

.menuitem.button.flat, .header-bar .menuitem.titlebutton.button,
.titlebar .menuitem.titlebutton.button,
GtkCalendar.header .menuitem.titlebutton.button, .menuitem.button.flat:backdrop, .header-bar .menuitem.titlebutton.button:backdrop,
.titlebar .menuitem.titlebutton.button:backdrop,
GtkCalendar.header .menuitem.titlebutton.button:backdrop, .menuitem.button.flat:backdrop:hover, .header-bar .menuitem.titlebutton.button:backdrop:hover,
.titlebar .menuitem.titlebutton.button:backdrop:hover,
GtkCalendar.header .menuitem.titlebutton.button:backdrop:hover, .button:link, .header-bar .button.titlebutton:link,
.titlebar .button.titlebutton:link,
GtkCalendar.header .button.titlebutton:link, .button:visited, .header-bar .button.titlebutton:visited,
.titlebar .button.titlebutton:visited,
GtkCalendar.header .button.titlebutton:visited, .button:link:hover, .button:link:active, .button:link:checked, .button:visited:hover, .button:visited:active, .button:visited:checked, .button:link:backdrop, .button:visited:backdrop, .notebook tab .button, .notebook tab .header-bar .button.titlebutton, .header-bar .notebook tab .button.titlebutton,
.notebook tab .titlebar .button.titlebutton,
.titlebar .notebook tab .button.titlebutton,
.notebook tab GtkCalendar.header .button.titlebutton,
GtkCalendar.header .notebook tab .button.titlebutton, .list-row.button, .header-bar .list-row.button.titlebutton,
.titlebar .list-row.button.titlebutton,
GtkCalendar.header .list-row.button.titlebutton, .list-row.button:backdrop:hover, .app-notification .button.flat, .app-notification .header-bar .titlebutton.button, .header-bar .app-notification .titlebutton.button,
.app-notification .titlebar .titlebutton.button,
.titlebar .app-notification .titlebutton.button,
.app-notification GtkCalendar.header .titlebutton.button,
GtkCalendar.header .app-notification .titlebutton.button,
.app-notification.frame .button.flat,
.app-notification.frame .header-bar .button.titlebutton,
.header-bar .app-notification.frame .button.titlebutton,
.app-notification.frame .titlebar .button.titlebutton,
.titlebar .app-notification.frame .button.titlebutton,
.app-notification.frame GtkCalendar.header .button.titlebutton,
GtkCalendar.header .app-notification.frame .button.titlebutton, .app-notification .button.flat:backdrop, .app-notification .header-bar .titlebutton.button:backdrop, .header-bar .app-notification .titlebutton.button:backdrop,
.app-notification .titlebar .titlebutton.button:backdrop,
.titlebar .app-notification .titlebutton.button:backdrop,
.app-notification GtkCalendar.header .titlebutton.button:backdrop,
GtkCalendar.header .app-notification .titlebutton.button:backdrop, .app-notification .button.flat:insensitive, .app-notification .header-bar .titlebutton.button:insensitive, .header-bar .app-notification .titlebutton.button:insensitive,
.app-notification .titlebar .titlebutton.button:insensitive,
.titlebar .app-notification .titlebutton.button:insensitive,
.app-notification GtkCalendar.header .titlebutton.button:insensitive,
GtkCalendar.header .app-notification .titlebutton.button:insensitive, .app-notification .button.flat:backdrop:insensitive, .app-notification .header-bar .titlebutton.button:backdrop:insensitive, .header-bar .app-notification .titlebutton.button:backdrop:insensitive,
.app-notification .titlebar .titlebutton.button:backdrop:insensitive,
.titlebar .app-notification .titlebutton.button:backdrop:insensitive,
.app-notification GtkCalendar.header .titlebutton.button:backdrop:insensitive,
GtkCalendar.header .app-notification .titlebutton.button:backdrop:insensitive,
.app-notification.frame .button.flat:backdrop,
.app-notification.frame .header-bar .button.titlebutton:backdrop,
.header-bar .app-notification.frame .button.titlebutton:backdrop,
.app-notification.frame .titlebar .button.titlebutton:backdrop,
.titlebar .app-notification.frame .button.titlebutton:backdrop,
.app-notification.frame GtkCalendar.header .button.titlebutton:backdrop,
GtkCalendar.header .app-notification.frame .button.titlebutton:backdrop,
.app-notification.frame .button.flat:insensitive,
.app-notification.frame .header-bar .button.titlebutton:insensitive,
.header-bar .app-notification.frame .button.titlebutton:insensitive,
.app-notification.frame .titlebar .button.titlebutton:insensitive,
.titlebar .app-notification.frame .button.titlebutton:insensitive,
.app-notification.frame GtkCalendar.header .button.titlebutton:insensitive,
GtkCalendar.header .app-notification.frame .button.titlebutton:insensitive,
.app-notification.frame .button.flat:backdrop:insensitive,
.app-notification.frame .header-bar .button.titlebutton:backdrop:insensitive,
.header-bar .app-notification.frame .button.titlebutton:backdrop:insensitive,
.app-notification.frame .titlebar .button.titlebutton:backdrop:insensitive,
.titlebar .app-notification.frame .button.titlebutton:backdrop:insensitive,
.app-notification.frame GtkCalendar.header .button.titlebutton:backdrop:insensitive,
GtkCalendar.header .app-notification.frame .button.titlebutton:backdrop:insensitive, GtkCalendar.button, .header-bar GtkCalendar.button.titlebutton,
.titlebar GtkCalendar.button.titlebutton,
GtkCalendar.header GtkCalendar.button.titlebutton, GtkCalendar.button:hover, .header-bar GtkCalendar.button.titlebutton:hover,
.titlebar GtkCalendar.button.titlebutton:hover,
GtkCalendar.header GtkCalendar.button.titlebutton:hover, .scale-popup .button:hover, .scale-popup .button:backdrop, .scale-popup .button:backdrop:hover, .scale-popup .button:backdrop:insensitive {
  border-color: transparent;
  background-color: transparent;
  background-image: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0), 0 1px rgba(255, 255, 255, 0);
  text-shadow: none;
  icon-shadow: none; }

/* menu buttons */
.menuitem.button.flat, .header-bar .menuitem.titlebutton.button,
.titlebar .menuitem.titlebutton.button,
GtkCalendar.header .menuitem.titlebutton.button {
  outline-offset: -1px; }
  .menuitem.button.flat:hover, .header-bar .menuitem.titlebutton.button:hover,
  .titlebar .menuitem.titlebutton.button:hover,
  GtkCalendar.header .menuitem.titlebutton.button:hover {
    background-color: #4b5050; }

GtkColorButton.button, .header-bar GtkColorButton.button.titlebutton,
.titlebar GtkColorButton.button.titlebutton,
GtkCalendar.header GtkColorButton.button.titlebutton {
  padding: 4px; }
  GtkColorButton.button GtkColorSwatch, .header-bar GtkColorButton.button.titlebutton GtkColorSwatch,
  .titlebar GtkColorButton.button.titlebutton GtkColorSwatch,
  GtkCalendar.header GtkColorButton.button.titlebutton GtkColorSwatch {
    border-radius: 1.5px;
    box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.2), 0 1px rgba(238, 238, 236, 0.1); }
    GtkColorButton.button GtkColorSwatch:backdrop, .header-bar GtkColorButton.button.titlebutton GtkColorSwatch:backdrop,
    .titlebar GtkColorButton.button.titlebutton GtkColorSwatch:backdrop,
    GtkCalendar.header GtkColorButton.button.titlebutton GtkColorSwatch:backdrop {
      box-shadow: none; }

/*********
 * Links *
 *********/
*:link, .button:link, .header-bar .button.titlebutton:link,
.titlebar .button.titlebutton:link,
GtkCalendar.header .button.titlebutton:link, .button:visited, .header-bar .button.titlebutton:visited,
.titlebar .button.titlebutton:visited,
GtkCalendar.header .button.titlebutton:visited {
  color: #4a90d9; }
  *:link:visited, .button:visited, .header-bar .button.titlebutton:visited,
  .titlebar .button.titlebutton:visited,
  GtkCalendar.header .button.titlebutton:visited {
    color: #2a76c6; }
    *:selected *:link:visited, *:selected .button:visited {
      color: #a6bed7; }
  *:link:hover, .button:hover:link, .button:hover:visited {
    color: #74aae2; }
    *:selected *:link:hover, *:selected .button:hover:link, *:selected .button:hover:visited {
      color: #e8eef5; }
  *:link:active, .button:active:link, .button:active:visited {
    color: #4a90d9; }
    *:selected *:link:active, *:selected .button:active:link, *:selected .button:active:visited {
      color: #d2deeb; }
  *:link:backdrop, .button:backdrop:link, .button:backdrop:visited, *:link:backdrop:hover, .button:backdrop:hover:link, .button:backdrop:hover:visited, *:link:backdrop:hover:selected, .button:backdrop:hover:selected:link, .button:backdrop:hover:selected:visited, .titlebar.selection-mode .subtitle:backdrop:hover:link, GtkCalendar.selection-mode.header .subtitle:backdrop:hover:link,
  .header-bar.selection-mode .subtitle:backdrop:hover:link {
    color: #215d9c; }
  *:link:selected, .button:selected:link, .button:selected:visited, .titlebar.selection-mode .subtitle:link, GtkCalendar.selection-mode.header .subtitle:link,
  .header-bar.selection-mode .subtitle:link, *:selected *:link, *:selected .button:link, *:selected .button:visited {
    color: #d2deeb; }

.button:link, .header-bar .button.titlebutton:link,
.titlebar .button.titlebutton:link,
GtkCalendar.header .button.titlebutton:link, .button:visited, .header-bar .button.titlebutton:visited,
.titlebar .button.titlebutton:visited,
GtkCalendar.header .button.titlebutton:visited {
  text-shadow: none; }
  .button:link:hover, .button:link:active, .button:link:checked, .button:visited:hover, .button:visited:active, .button:visited:checked {
    text-shadow: none; }

/*****************
 * GtkSpinButton *
 *****************/
.spinbutton {
  /* This is to fix spinbuttons in entries, but I feel like hiding code issues
   * hence it's commented atm.
   *  GtkTreeView & {
   *   &.entry, &.entry:focus {
   *     padding: 1px;
   *     border-width: 1px 0;
   *     border-color: $selected_bg_color;
   *     border-radius: 0;
   *     box-shadow: none;
   *   }
   * } */ }
  .spinbutton .button, .spinbutton .header-bar .button.titlebutton, .header-bar .spinbutton .button.titlebutton,
  .spinbutton .titlebar .button.titlebutton,
  .titlebar .spinbutton .button.titlebutton,
  .spinbutton GtkCalendar.header .button.titlebutton,
  GtkCalendar.header .spinbutton .button.titlebutton {
    background-image: none;
    border-style: none none none solid;
    border-color: rgba(28, 31, 31, 0.3);
    color: #e4e4e2;
    border-radius: 0;
    box-shadow: none; }
    .spinbutton .button:dir(rtl) {
      border-style: none solid none none; }
    .spinbutton .button:hover {
      color: #eeeeec;
      background-color: rgba(238, 238, 236, 0.05); }
    .spinbutton .button:insensitive {
      color: rgba(147, 150, 149, 0.3); }
    .spinbutton .button:active {
      box-shadow: inset 0 2px 3px -1px rgba(0, 0, 0, 0.2);
      background-color: rgba(0, 0, 0, 0.1); }
    .spinbutton .button:backdrop {
      border-color: rgba(30, 34, 34, 0.3);
      background-color: transparent; }
    .spinbutton .button:backdrop:insensitive {
      background-image: none;
      color: rgba(93, 103, 103, 0.3);
      border-style: none none none solid; }
      .spinbutton .button:backdrop:insensitive:dir(rtl) {
        border-style: none solid none none; }
  .spinbutton.vertical .button, .spinbutton.vertical:dir(rtl) .button {
    padding-top: 8px;
    padding-bottom: 8px; }
    .spinbutton.vertical .button:first-child, .spinbutton.vertical:dir(rtl) .button:first-child {
      color: #eeeeec;
      outline-color: rgba(238, 238, 236, 0.3);
      border-color: #1c1f1f;
      background-image: linear-gradient(to bottom, #454c4c, #393f3f 40%, #2d3232);
      text-shadow: 0 -1px rgba(0, 0, 0, 0.81176);
      icon-shadow: 0 -1px rgba(0, 0, 0, 0.81176);
      box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); }
      .spinbutton.vertical .button:first-child:active, .spinbutton.vertical:dir(rtl) .button:first-child:active {
        color: #eeeeec;
        outline-color: rgba(238, 238, 236, 0.3);
        border-color: #1c1f1f;
        background-image: linear-gradient(to bottom, #232727, #2d3232);
        text-shadow: 0 -1px rgba(0, 0, 0, 0.89176);
        icon-shadow: 0 -1px rgba(0, 0, 0, 0.89176);
        box-shadow: inset 0 1px rgba(0, 0, 0, 0.07), inset 0 2px 1px -2px rgba(0, 0, 0, 0.6); }
      .spinbutton.vertical .button:first-child:hover, .spinbutton.vertical:dir(rtl) .button:first-child:hover {
        color: #eeeeec;
        outline-color: rgba(238, 238, 236, 0.3);
        border-color: #1c1f1f;
        background-image: linear-gradient(to bottom, #5b6464, #434a4a 40%, #393f3f);
        text-shadow: 0 -1px rgba(0, 0, 0, 0.77976);
        icon-shadow: 0 -1px rgba(0, 0, 0, 0.77976);
        box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); }
      .spinbutton.vertical .button:first-child:insensitive, .spinbutton.vertical:dir(rtl) .button:first-child:insensitive {
        color: #939695;
        border-color: #1c1f1f;
        background-image: linear-gradient(to bottom, #323636);
        text-shadow: none;
        icon-shadow: none;
        box-shadow: inset 0 1px rgba(255, 255, 255, 0); }
        .spinbutton.vertical .button:first-child:insensitive > GtkLabel, .spinbutton.vertical:dir(rtl) .button:first-child:insensitive > GtkLabel {
          color: inherit; }
      .spinbutton.vertical .button:first-child:backdrop, .spinbutton.vertical:dir(rtl) .button:first-child:backdrop {
        color: #c9cbc9;
        border-color: #1e2222;
        background-image: linear-gradient(to bottom, #393f3f);
        text-shadow: none;
        icon-shadow: none;
        box-shadow: inset 0 1px rgba(255, 255, 255, 0); }
    .spinbutton.vertical .button:last-child, .spinbutton.vertical:dir(rtl) .button:last-child {
      color: #eeeeec;
      outline-color: rgba(238, 238, 236, 0.3);
      border-color: #1c1f1f;
      background-image: linear-gradient(to bottom, #454c4c, #393f3f 40%, #2d3232);
      text-shadow: 0 -1px rgba(0, 0, 0, 0.81176);
      icon-shadow: 0 -1px rgba(0, 0, 0, 0.81176);
      box-shadow: inset 0 1px rgba(255, 255, 255, 0.1), 0 1px rgba(238, 238, 236, 0.1); }
      .spinbutton.vertical .button:last-child:active, .spinbutton.vertical:dir(rtl) .button:last-child:active {
        color: #eeeeec;
        outline-color: rgba(238, 238, 236, 0.3);
        border-color: #1c1f1f;
        background-image: linear-gradient(to bottom, #232727, #2d3232);
        text-shadow: 0 -1px rgba(0, 0, 0, 0.89176);
        icon-shadow: 0 -1px rgba(0, 0, 0, 0.89176);
        box-shadow: inset 0 1px rgba(0, 0, 0, 0.07), inset 0 2px 1px -2px rgba(0, 0, 0, 0.6), 0 1px rgba(238, 238, 236, 0.1); }
      .spinbutton.vertical .button:last-child:hover, .spinbutton.vertical:dir(rtl) .button:last-child:hover {
        color: #eeeeec;
        outline-color: rgba(238, 238, 236, 0.3);
        border-color: #1c1f1f;
        background-image: linear-gradient(to bottom, #5b6464, #434a4a 40%, #393f3f);
        text-shadow: 0 -1px rgba(0, 0, 0, 0.77976);
        icon-shadow: 0 -1px rgba(0, 0, 0, 0.77976);
        box-shadow: inset 0 1px rgba(255, 255, 255, 0.1), 0 1px rgba(238, 238, 236, 0.1); }
      .spinbutton.vertical .button:last-child:insensitive, .spinbutton.vertical:dir(rtl) .button:last-child:insensitive {
        color: #939695;
        border-color: #1c1f1f;
        background-image: linear-gradient(to bottom, #323636);
        text-shadow: none;
        icon-shadow: none;
        box-shadow: inset 0 1px rgba(255, 255, 255, 0), 0 1px rgba(238, 238, 236, 0.1); }
        .spinbutton.vertical .button:last-child:insensitive > GtkLabel, .spinbutton.vertical:dir(rtl) .button:last-child:insensitive > GtkLabel {
          color: inherit; }
      .spinbutton.vertical .button:last-child:backdrop, .spinbutton.vertical:dir(rtl) .button:last-child:backdrop {
        color: #c9cbc9;
        border-color: #1e2222;
        background-image: linear-gradient(to bottom, #393f3f);
        text-shadow: none;
        icon-shadow: none;
        box-shadow: inset 0 1px rgba(255, 255, 255, 0), 0 1px rgba(238, 238, 236, 0); }
    .spinbutton.vertical .button:backdrop:insensitive, .spinbutton.vertical:dir(rtl) .button:backdrop:insensitive {
      color: #5d6767;
      border-color: #1e2222;
      background-image: linear-gradient(to bottom, #323636);
      text-shadow: none;
      icon-shadow: none;
      box-shadow: inset 0 1px rgba(255, 255, 255, 0), 0 1px rgba(238, 238, 236, 0); }
      .spinbutton.vertical .button:backdrop:insensitive > GtkLabel, .spinbutton.vertical:dir(rtl) .button:backdrop:insensitive > GtkLabel {
        color: inherit; }
  .spinbutton.vertical.entry, .spinbutton.vertical:dir(rtl).entry {
    border-radius: 0;
    padding-left: 3px;
    padding-right: 3px; }
  .spinbutton.vertical .button:first-child, .spinbutton.vertical:dir(rtl) .button:first-child, .spinbutton.vertical .button:first-child:active, .spinbutton.vertical:dir(rtl) .button:first-child:active, .spinbutton.vertical .button:first-child:hover, .spinbutton.vertical:dir(rtl) .button:first-child:hover, .spinbutton.vertical .button:first-child:insensitive, .spinbutton.vertical:dir(rtl) .button:first-child:insensitive, .spinbutton.vertical .button:first-child:backdrop, .spinbutton.vertical:dir(rtl) .button:first-child:backdrop, .spinbutton.vertical:dir(rtl) .button:first-child, .spinbutton.vertical:dir(rtl) .button:first-child:active, .spinbutton.vertical:dir(rtl) .button:first-child:hover, .spinbutton.vertical:dir(rtl) .button:first-child:insensitive, .spinbutton.vertical:dir(rtl) .button:first-child:backdrop {
    border-radius: 3px 3px 0 0;
    border-style: solid solid none solid; }
  .spinbutton.vertical .button:last-child, .spinbutton.vertical:dir(rtl) .button:last-child, .spinbutton.vertical .button:last-child:active, .spinbutton.vertical:dir(rtl) .button:last-child:active, .spinbutton.vertical .button:last-child:hover, .spinbutton.vertical:dir(rtl) .button:last-child:hover, .spinbutton.vertical .button:last-child:insensitive, .spinbutton.vertical:dir(rtl) .button:last-child:insensitive, .spinbutton.vertical .button:last-child:backdrop, .spinbutton.vertical:dir(rtl) .button:last-child:backdrop, .spinbutton.vertical:dir(rtl) .button:last-child, .spinbutton.vertical:dir(rtl) .button:last-child:active, .spinbutton.vertical:dir(rtl) .button:last-child:hover, .spinbutton.vertical:dir(rtl) .button:last-child:insensitive, .spinbutton.vertical:dir(rtl) .button:last-child:backdrop {
    border-radius: 0 0 3px 3px;
    border-style: none solid solid solid; }

/**************
 * ComboBoxes *
 **************/
GtkComboBox {
  -GtkComboBox-arrow-scaling: 0.5;
  -GtkComboBox-shadow-type: none;
  box-shadow: 0 1px rgba(238, 238, 236, 0.1);
  text-shadow: 0 -1px rgba(0, 0, 0, 0.81176);
  icon-shadow: 0 -1px rgba(0, 0, 0, 0.81176); }
  GtkComboBox > .button, .header-bar GtkComboBox > .button.titlebutton,
  .titlebar GtkComboBox > .button.titlebutton,
  GtkCalendar.header GtkComboBox > .button.titlebutton {
    padding-top: 3px;
    padding-bottom: 4px; }
  GtkComboBox:insensitive {
    color: #939695;
    text-shadow: none;
    icon-shadow: none; }
  GtkComboBox:backdrop {
    color: #c9cbc9;
    text-shadow: none;
    icon-shadow: none; }
  GtkComboBox:backdrop:insensitive {
    color: #5d6767; }
  GtkComboBox .menuitem {
    text-shadow: none; }
  GtkComboBox .separator, GtkComboBox .sidebar .separator:backdrop, .sidebar GtkComboBox .separator:backdrop,
  GtkComboBox .sidebar .view .separator:backdrop,
  .sidebar .view GtkComboBox .separator:backdrop {
    -GtkWidget-wide-separators: true;
    -GtkWidget-horizontal-separator: 0;
    -GtkWidget-vertical-separator: 0; }

/************
 * Toolbars *
 ************/
.toolbar, .inline-toolbar, .search-bar, .location-bar {
  -GtkWidget-window-dragging: true;
  padding: 4px;
  background-color: #393f3f; }
  .osd .toolbar, .osd .inline-toolbar, .osd .search-bar, .osd .location-bar, .toolbar.osd, .osd.inline-toolbar, .osd.search-bar, .osd.location-bar {
    padding: 13px;
    border: rgba(255, 255, 255, 0.1);
    border-radius: 6px;
    background-color: rgba(46, 52, 54, 0.7);
    background-clip: padding-box; }

.inline-toolbar {
  border-width: 0 1px 1px;
  padding: 3px;
  border-radius: 0  0 4px 4px; }

.search-bar, .location-bar {
  border-width: 0 0 1px;
  padding: 3px; }

.inline-toolbar, .search-bar, .location-bar {
  border-style: solid;
  border-color: #1c1f1f;
  background-color: #303535;
  box-shadow: inset 0 2px 3px -1px #242727, 0 1px rgba(238, 238, 236, 0.1); }
  .inline-toolbar:backdrop, .search-bar:backdrop, .location-bar:backdrop {
    border-color: #1e2222;
    background-color: #2f3434;
    box-shadow: none; }

/***************
 * Header bars *
 ***************/
.titlebar, GtkCalendar.header,
.header-bar {
  padding: 6px;
  border-width: 0 0 1px;
  border-style: solid;
  border-color: #1c1f1f;
  border-radius: 7px 7px 0 0;
  background-color: transparent;
  background-image: linear-gradient(to bottom, #434a4a, #393f3f);
  box-shadow: inset 0 -1px #272c2c, inset 0 1px rgba(238, 238, 236, 0.1); }
  .titlebar:backdrop, GtkCalendar.header:backdrop,
  .header-bar:backdrop {
    border-color: #1e2222;
    background-color: #393f3f;
    background-image: none;
    box-shadow: inset 0 1px rgba(238, 238, 236, 0.1); }
  .titlebar .title, GtkCalendar.header .title,
  .header-bar .title {
    font-weight: bold;
    padding: 0px 12px; }
  .titlebar .subtitle, GtkCalendar.header .subtitle,
  .header-bar .subtitle {
    font-size: smaller;
    padding: 0 12px; }
  .titlebar .header-bar-separator, GtkCalendar.header .header-bar-separator, .titlebar > GtkBox > .separator.vertical, GtkCalendar.header > GtkBox > .separator.vertical,
  .sidebar .view .titlebar > GtkBox > .vertical.separator:backdrop,
  .sidebar .view GtkCalendar.header > GtkBox > .vertical.separator:backdrop,
  .header-bar .header-bar-separator,
  .header-bar > GtkBox > .separator.vertical,
  .sidebar .view .header-bar > GtkBox > .vertical.separator:backdrop {
    -GtkWidget-wide-separators: true;
    -GtkWidget-separator-width: 1px;
    border-width: 0 1px;
    border-image: linear-gradient(to bottom, rgba(28, 31, 31, 0), #1c1f1f 30%, #1c1f1f 70%, rgba(28, 31, 31, 0) 100%) 0 1/0 1px stretch; }
    .titlebar .header-bar-separator:backdrop, GtkCalendar.header .header-bar-separator:backdrop, .titlebar > GtkBox > .separator.vertical:backdrop, GtkCalendar.header > GtkBox > .separator.vertical:backdrop,
    .header-bar .header-bar-separator:backdrop,
    .header-bar > GtkBox > .separator.vertical:backdrop {
      border-image: linear-gradient(to bottom, rgba(30, 34, 34, 0.5)) 0 1/1px 1px; }
  .titlebar.selection-mode, GtkCalendar.selection-mode.header,
  .header-bar.selection-mode {
    color: #ffffff;
    text-shadow: 0 -1px rgba(0, 0, 0, 0.5);
    border-color: #0f2b48;
    background-image: linear-gradient(to bottom, #256ab1, #215d9c);
    box-shadow: inset 0 -1px #1a4b7e, inset 0 1px rgba(43, 100, 160, 0.55); }
    .titlebar.selection-mode:backdrop, GtkCalendar.selection-mode.header:backdrop,
    .header-bar.selection-mode:backdrop {
      background-image: linear-gradient(to bottom, #215d9c);
      box-shadow: inset 0 1px rgba(48, 103, 161, 0.46); }
    .titlebar.selection-mode .button, GtkCalendar.selection-mode.header .button,
    .header-bar.selection-mode .button {
      color: #ffffff;
      outline-color: rgba(255, 255, 255, 0.3);
      border-color: #0b1e33;
      background-image: linear-gradient(to bottom, #256ab1, #215d9c 40%, #1c5187);
      text-shadow: 0 -1px rgba(0, 0, 0, 0.70353);
      icon-shadow: 0 -1px rgba(0, 0, 0, 0.70353);
      box-shadow: inset 0 1px rgba(255, 255, 255, 0.1), 0 1px rgba(43, 100, 160, 0.55); }
      .titlebar.selection-mode .button.flat, GtkCalendar.selection-mode.header .button.flat,
      .titlebar.selection-mode .titlebutton.button,
      GtkCalendar.selection-mode.header .titlebutton.button,
      .header-bar.selection-mode .button.flat,
      .header-bar.selection-mode .titlebutton.button {
        border-color: transparent;
        background-color: transparent;
        background-image: none;
        box-shadow: inset 0 1px rgba(255, 255, 255, 0), 0 1px rgba(238, 238, 236, 0);
        text-shadow: none;
        icon-shadow: none; }
      .titlebar.selection-mode .button:hover, GtkCalendar.selection-mode.header .button:hover,
      .header-bar.selection-mode .button:hover {
        color: #ffffff;
        outline-color: rgba(255, 255, 255, 0.3);
        border-color: #0b1e33;
        background-image: linear-gradient(to bottom, #3180d4, #2467ad 40%, #215d9c);
        text-shadow: 0 -1px rgba(0, 0, 0, 0.67153);
        icon-shadow: 0 -1px rgba(0, 0, 0, 0.67153);
        box-shadow: inset 0 1px rgba(255, 255, 255, 0.1), 0 1px rgba(43, 100, 160, 0.55); }
      .titlebar.selection-mode .button:active, GtkCalendar.selection-mode.header .button:active, .titlebar.selection-mode .button:checked, GtkCalendar.selection-mode.header .button:checked,
      .header-bar.selection-mode .button:active,
      .header-bar.selection-mode .button:checked {
        color: #ffffff;
        outline-color: rgba(255, 255, 255, 0.3);
        border-color: #0b1e33;
        background-image: linear-gradient(to bottom, #194776, #1c5187);
        text-shadow: 0 -1px rgba(0, 0, 0, 0.78353);
        icon-shadow: 0 -1px rgba(0, 0, 0, 0.78353);
        box-shadow: inset 0 1px rgba(0, 0, 0, 0.07), inset 0 2px 1px -2px rgba(0, 0, 0, 0.6), 0 1px rgba(43, 100, 160, 0.55); }
      .titlebar.selection-mode .button:backdrop, GtkCalendar.selection-mode.header .button:backdrop, .titlebar.selection-mode .button.flat:backdrop, GtkCalendar.selection-mode.header .button.flat:backdrop,
      .titlebar.selection-mode .titlebutton.button:backdrop,
      GtkCalendar.selection-mode.header .titlebutton.button:backdrop,
      .header-bar.selection-mode .button:backdrop,
      .header-bar.selection-mode .button.flat:backdrop,
      .header-bar.selection-mode .titlebutton.button:backdrop {
        color: #d2deeb;
        border-color: #0b1e33;
        background-image: linear-gradient(to bottom, #215d9c);
        text-shadow: none;
        icon-shadow: none;
        box-shadow: inset 0 1px rgba(255, 255, 255, 0), 0 1px rgba(43, 100, 160, 0);
        -gtk-image-effect: none;
        border-color: #0f2b48; }
        .titlebar.selection-mode .button:backdrop:active, GtkCalendar.selection-mode.header .button:backdrop:active, .titlebar.selection-mode .button:backdrop:checked, GtkCalendar.selection-mode.header .button:backdrop:checked, .titlebar.selection-mode .button.flat:backdrop:active, GtkCalendar.selection-mode.header .button.flat:backdrop:active,
        .titlebar.selection-mode .titlebutton.button:backdrop:active,
        GtkCalendar.selection-mode.header .titlebutton.button:backdrop:active, .titlebar.selection-mode .button.flat:backdrop:checked, GtkCalendar.selection-mode.header .button.flat:backdrop:checked,
        .titlebar.selection-mode .titlebutton.button:backdrop:checked,
        GtkCalendar.selection-mode.header .titlebutton.button:backdrop:checked,
        .header-bar.selection-mode .button:backdrop:active,
        .header-bar.selection-mode .button:backdrop:checked,
        .header-bar.selection-mode .button.flat:backdrop:active,
        .header-bar.selection-mode .titlebutton.button:backdrop:active,
        .header-bar.selection-mode .button.flat:backdrop:checked,
        .header-bar.selection-mode .titlebutton.button:backdrop:checked {
          color: #d0d9e2;
          border-color: #0b1e33;
          background-image: linear-gradient(to bottom, #184472);
          box-shadow: inset 0 1px rgba(255, 255, 255, 0), 0 1px rgba(43, 100, 160, 0);
          border-color: #0f2b48; }
        .titlebar.selection-mode .button:backdrop:insensitive, GtkCalendar.selection-mode.header .button:backdrop:insensitive, .titlebar.selection-mode .button.flat:backdrop:insensitive, GtkCalendar.selection-mode.header .button.flat:backdrop:insensitive,
        .titlebar.selection-mode .titlebutton.button:backdrop:insensitive,
        GtkCalendar.selection-mode.header .titlebutton.button:backdrop:insensitive,
        .header-bar.selection-mode .button:backdrop:insensitive,
        .header-bar.selection-mode .button.flat:backdrop:insensitive,
        .header-bar.selection-mode .titlebutton.button:backdrop:insensitive {
          color: #6f90b2;
          border-color: #0b1e33;
          background-image: linear-gradient(to bottom, #22558a);
          text-shadow: none;
          icon-shadow: none;
          box-shadow: inset 0 1px rgba(255, 255, 255, 0), 0 1px rgba(43, 100, 160, 0);
          border-color: #0f2b48; }
          .titlebar.selection-mode .button:backdrop:insensitive > GtkLabel, GtkCalendar.selection-mode.header .button:backdrop:insensitive > GtkLabel, .titlebar.selection-mode .button.flat:backdrop:insensitive > GtkLabel, GtkCalendar.selection-mode.header .button.flat:backdrop:insensitive > GtkLabel,
          .titlebar.selection-mode .titlebutton.button:backdrop:insensitive > GtkLabel,
          GtkCalendar.selection-mode.header .titlebutton.button:backdrop:insensitive > GtkLabel,
          .header-bar.selection-mode .button:backdrop:insensitive > GtkLabel,
          .header-bar.selection-mode .button.flat:backdrop:insensitive > GtkLabel,
          .header-bar.selection-mode .titlebutton.button:backdrop:insensitive > GtkLabel {
            color: inherit; }
        .titlebar.selection-mode .button:backdrop:insensitive:active, GtkCalendar.selection-mode.header .button:backdrop:insensitive:active, .titlebar.selection-mode .button:backdrop:insensitive:checked, GtkCalendar.selection-mode.header .button:backdrop:insensitive:checked, .titlebar.selection-mode .button.flat:backdrop:insensitive:active, GtkCalendar.selection-mode.header .button.flat:backdrop:insensitive:active,
        .titlebar.selection-mode .titlebutton.button:backdrop:insensitive:active,
        GtkCalendar.selection-mode.header .titlebutton.button:backdrop:insensitive:active, .titlebar.selection-mode .button.flat:backdrop:insensitive:checked, GtkCalendar.selection-mode.header .button.flat:backdrop:insensitive:checked,
        .titlebar.selection-mode .titlebutton.button:backdrop:insensitive:checked,
        GtkCalendar.selection-mode.header .titlebutton.button:backdrop:insensitive:checked,
        .header-bar.selection-mode .button:backdrop:insensitive:active,
        .header-bar.selection-mode .button:backdrop:insensitive:checked,
        .header-bar.selection-mode .button.flat:backdrop:insensitive:active,
        .header-bar.selection-mode .titlebutton.button:backdrop:insensitive:active,
        .header-bar.selection-mode .button.flat:backdrop:insensitive:checked,
        .header-bar.selection-mode .titlebutton.button:backdrop:insensitive:checked {
          color: #6c88a5;
          border-color: #0b1e33;
          background-image: linear-gradient(to bottom, #1d4876);
          box-shadow: inset 0 1px rgba(255, 255, 255, 0), 0 1px rgba(43, 100, 160, 0);
          border-color: #0f2b48; }
          .titlebar.selection-mode .button:backdrop:insensitive:active > GtkLabel, GtkCalendar.selection-mode.header .button:backdrop:insensitive:active > GtkLabel, .titlebar.selection-mode .button:backdrop:insensitive:checked > GtkLabel, GtkCalendar.selection-mode.header .button:backdrop:insensitive:checked > GtkLabel, .titlebar.selection-mode .button.flat:backdrop:insensitive:active > GtkLabel, GtkCalendar.selection-mode.header .button.flat:backdrop:insensitive:active > GtkLabel,
          .titlebar.selection-mode .titlebutton.button:backdrop:insensitive:active > GtkLabel,
          GtkCalendar.selection-mode.header .titlebutton.button:backdrop:insensitive:active > GtkLabel, .titlebar.selection-mode .button.flat:backdrop:insensitive:checked > GtkLabel, GtkCalendar.selection-mode.header .button.flat:backdrop:insensitive:checked > GtkLabel,
          .titlebar.selection-mode .titlebutton.button:backdrop:insensitive:checked > GtkLabel,
          GtkCalendar.selection-mode.header .titlebutton.button:backdrop:insensitive:checked > GtkLabel,
          .header-bar.selection-mode .button:backdrop:insensitive:active > GtkLabel,
          .header-bar.selection-mode .button:backdrop:insensitive:checked > GtkLabel,
          .header-bar.selection-mode .button.flat:backdrop:insensitive:active > GtkLabel,
          .header-bar.selection-mode .titlebutton.button:backdrop:insensitive:active > GtkLabel,
          .header-bar.selection-mode .button.flat:backdrop:insensitive:checked > GtkLabel,
          .header-bar.selection-mode .titlebutton.button:backdrop:insensitive:checked > GtkLabel {
            color: inherit; }
      .titlebar.selection-mode .button.flat:backdrop, GtkCalendar.selection-mode.header .button.flat:backdrop,
      .titlebar.selection-mode .titlebutton.button:backdrop,
      GtkCalendar.selection-mode.header .titlebutton.button:backdrop, .titlebar.selection-mode .button.flat:insensitive, GtkCalendar.selection-mode.header .button.flat:insensitive,
      .titlebar.selection-mode .titlebutton.button:insensitive,
      GtkCalendar.selection-mode.header .titlebutton.button:insensitive, .titlebar.selection-mode .button.flat:insensitive:backdrop, GtkCalendar.selection-mode.header .button.flat:insensitive:backdrop,
      .titlebar.selection-mode .titlebutton.button:insensitive:backdrop,
      GtkCalendar.selection-mode.header .titlebutton.button:insensitive:backdrop,
      .header-bar.selection-mode .button.flat:backdrop,
      .header-bar.selection-mode .titlebutton.button:backdrop,
      .header-bar.selection-mode .button.flat:insensitive,
      .header-bar.selection-mode .titlebutton.button:insensitive,
      .header-bar.selection-mode .button.flat:insensitive:backdrop,
      .header-bar.selection-mode .titlebutton.button:insensitive:backdrop {
        border-color: transparent;
        background-color: transparent;
        background-image: none;
        box-shadow: inset 0 1px rgba(255, 255, 255, 0), 0 1px rgba(238, 238, 236, 0);
        text-shadow: none;
        icon-shadow: none; }
      .titlebar.selection-mode .button:insensitive, GtkCalendar.selection-mode.header .button:insensitive,
      .header-bar.selection-mode .button:insensitive {
        color: #90aac4;
        border-color: #0b1e33;
        background-image: linear-gradient(to bottom, #22558a);
        text-shadow: none;
        icon-shadow: none;
        box-shadow: inset 0 1px rgba(255, 255, 255, 0), 0 1px rgba(43, 100, 160, 0.55); }
        .titlebar.selection-mode .button:insensitive > GtkLabel, GtkCalendar.selection-mode.header .button:insensitive > GtkLabel,
        .header-bar.selection-mode .button:insensitive > GtkLabel {
          color: inherit; }
        .titlebar.selection-mode .button:insensitive:active, GtkCalendar.selection-mode.header .button:insensitive:active, .titlebar.selection-mode .button:insensitive:checked, GtkCalendar.selection-mode.header .button:insensitive:checked,
        .header-bar.selection-mode .button:insensitive:active,
        .header-bar.selection-mode .button:insensitive:checked {
          color: #a4b5c8;
          border-color: #0b1e33;
          background-image: linear-gradient(to bottom, #1b436f, #1d4876);
          box-shadow: inset 0 1px rgba(255, 255, 255, 0), 0 1px rgba(43, 100, 160, 0.55); }
          .titlebar.selection-mode .button:insensitive:active > GtkLabel, GtkCalendar.selection-mode.header .button:insensitive:active > GtkLabel, .titlebar.selection-mode .button:insensitive:checked > GtkLabel, GtkCalendar.selection-mode.header .button:insensitive:checked > GtkLabel,
          .header-bar.selection-mode .button:insensitive:active > GtkLabel,
          .header-bar.selection-mode .button:insensitive:checked > GtkLabel {
            color: inherit; }
      .titlebar.selection-mode .button.suggested-action, GtkCalendar.selection-mode.header .button.suggested-action,
      .header-bar.selection-mode .button.suggested-action {
        color: #eeeeec;
        outline-color: rgba(238, 238, 236, 0.3);
        border-color: #1c1f1f;
        background-image: linear-gradient(to bottom, #454c4c, #393f3f 40%, #2d3232);
        text-shadow: 0 -1px rgba(0, 0, 0, 0.81176);
        icon-shadow: 0 -1px rgba(0, 0, 0, 0.81176);
        box-shadow: inset 0 1px rgba(255, 255, 255, 0.1), 0 1px rgba(43, 100, 160, 0.55);
        border-color: #0f2b48; }
        .titlebar.selection-mode .button.suggested-action:hover, GtkCalendar.selection-mode.header .button.suggested-action:hover,
        .header-bar.selection-mode .button.suggested-action:hover {
          color: #eeeeec;
          outline-color: rgba(238, 238, 236, 0.3);
          border-color: #1c1f1f;
          background-image: linear-gradient(to bottom, #5b6464, #434a4a 40%, #393f3f);
          text-shadow: 0 -1px rgba(0, 0, 0, 0.77976);
          icon-shadow: 0 -1px rgba(0, 0, 0, 0.77976);
          box-shadow: inset 0 1px rgba(255, 255, 255, 0.1), 0 1px rgba(43, 100, 160, 0.55);
          border-color: #0f2b48; }
        .titlebar.selection-mode .button.suggested-action:active, GtkCalendar.selection-mode.header .button.suggested-action:active,
        .header-bar.selection-mode .button.suggested-action:active {
          color: #eeeeec;
          outline-color: rgba(238, 238, 236, 0.3);
          border-color: #1c1f1f;
          background-image: linear-gradient(to bottom, #232727, #2d3232);
          text-shadow: 0 -1px rgba(0, 0, 0, 0.89176);
          icon-shadow: 0 -1px rgba(0, 0, 0, 0.89176);
          box-shadow: inset 0 1px rgba(0, 0, 0, 0.07), inset 0 2px 1px -2px rgba(0, 0, 0, 0.6), 0 1px rgba(43, 100, 160, 0.55);
          border-color: #0f2b48; }
        .titlebar.selection-mode .button.suggested-action:insensitive, GtkCalendar.selection-mode.header .button.suggested-action:insensitive,
        .header-bar.selection-mode .button.suggested-action:insensitive {
          color: #939695;
          border-color: #1c1f1f;
          background-image: linear-gradient(to bottom, #323636);
          text-shadow: none;
          icon-shadow: none;
          box-shadow: inset 0 1px rgba(255, 255, 255, 0), 0 1px rgba(43, 100, 160, 0.55);
          border-color: #0f2b48; }
          .titlebar.selection-mode .button.suggested-action:insensitive > GtkLabel, GtkCalendar.selection-mode.header .button.suggested-action:insensitive > GtkLabel,
          .header-bar.selection-mode .button.suggested-action:insensitive > GtkLabel {
            color: inherit; }
        .titlebar.selection-mode .button.suggested-action:backdrop, GtkCalendar.selection-mode.header .button.suggested-action:backdrop,
        .header-bar.selection-mode .button.suggested-action:backdrop {
          color: #c9cbc9;
          border-color: #1e2222;
          background-image: linear-gradient(to bottom, #393f3f);
          text-shadow: none;
          icon-shadow: none;
          box-shadow: inset 0 1px rgba(255, 255, 255, 0), 0 1px rgba(43, 100, 160, 0);
          border-color: #0f2b48; }
        .titlebar.selection-mode .button.suggested-action:backdrop:insensitive, GtkCalendar.selection-mode.header .button.suggested-action:backdrop:insensitive,
        .header-bar.selection-mode .button.suggested-action:backdrop:insensitive {
          color: #5d6767;
          border-color: #1e2222;
          background-image: linear-gradient(to bottom, #323636);
          text-shadow: none;
          icon-shadow: none;
          box-shadow: inset 0 1px rgba(255, 255, 255, 0), 0 1px rgba(43, 100, 160, 0);
          border-color: #0f2b48; }
          .titlebar.selection-mode .button.suggested-action:backdrop:insensitive > GtkLabel, GtkCalendar.selection-mode.header .button.suggested-action:backdrop:insensitive > GtkLabel,
          .header-bar.selection-mode .button.suggested-action:backdrop:insensitive > GtkLabel {
            color: inherit; }
    .titlebar.selection-mode .selection-menu, GtkCalendar.selection-mode.header .selection-menu, .titlebar.selection-mode .selection-menu:backdrop, GtkCalendar.selection-mode.header .selection-menu:backdrop,
    .header-bar.selection-mode .selection-menu,
    .header-bar.selection-mode .selection-menu:backdrop {
      border-color: rgba(33, 93, 156, 0);
      background-image: linear-gradient(to bottom, rgba(33, 93, 156, 0));
      box-shadow: none;
      padding-left: 10px;
      padding-right: 10px; }
      .titlebar.selection-mode .selection-menu GtkArrow, GtkCalendar.selection-mode.header .selection-menu GtkArrow, .titlebar.selection-mode .selection-menu:backdrop GtkArrow, GtkCalendar.selection-mode.header .selection-menu:backdrop GtkArrow,
      .header-bar.selection-mode .selection-menu GtkArrow,
      .header-bar.selection-mode .selection-menu:backdrop GtkArrow {
        -GtkArrow-arrow-scaling: 1; }
      .titlebar.selection-mode .selection-menu .arrow, GtkCalendar.selection-mode.header .selection-menu .arrow,
      .header-bar.selection-mode .selection-menu .arrow {
        -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
        color: rgba(255, 255, 255, 0.5);
        icon-shadow: none; }
  .tiled .titlebar, .tiled GtkCalendar.header, .maximized .titlebar, .maximized GtkCalendar.header, .tiled
  .header-bar, .maximized
  .header-bar {
    border-radius: 0; }

/************
 * Pathbars *
 ************/
.path-bar .button, .path-bar .header-bar .button.titlebutton, .header-bar .path-bar .button.titlebutton,
.path-bar .titlebar .button.titlebutton,
.titlebar .path-bar .button.titlebutton,
.path-bar GtkCalendar.header .button.titlebutton,
GtkCalendar.header .path-bar .button.titlebutton {
  padding: 5px 6px 6px; }
  .path-bar .button:first-child {
    padding-left: 8px; }
  .path-bar .button:last-child {
    padding-right: 8px; }
  .path-bar .button:only-child {
    padding-left: 12px;
    padding-right: 12px; }
  .path-bar .button GtkLabel:last-child {
    padding-left: 2px; }
  .path-bar .button GtkLabel:first-child {
    padding-right: 2px; }
  .path-bar .button GtkLabel:only-child {
    padding-right: 0;
    padding-left: 0; }
  .path-bar .button GtkImage, .path-bar .header-bar .button.titlebutton GtkImage, .header-bar .path-bar .button.titlebutton GtkImage,
  .path-bar .titlebar .button.titlebutton GtkImage,
  .titlebar .path-bar .button.titlebutton GtkImage,
  .path-bar GtkCalendar.header .button.titlebutton GtkImage,
  GtkCalendar.header .path-bar .button.titlebutton GtkImage {
    padding-top: 1px; }

/**************
 * Tree Views *
 **************/
GtkTreeView.view {
  -GtkTreeView-grid-line-width: 1;
  -GtkTreeView-grid-line-pattern: '';
  -GtkTreeView-tree-line-width: 1;
  -GtkTreeView-tree-line-pattern: '';
  -GtkTreeView-expander-size: 16;
  border-color: #393f3f; }
  GtkTreeView.view:backdrop {
    border-color: #393f3f; }
  GtkTreeView.view.expander {
    -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
    color: #b2b2b1; }
    GtkTreeView.view.expander:dir(rtl) {
      -gtk-icon-source: -gtk-icontheme("pan-end-symbolic-rtl"); }
    GtkTreeView.view.expander:hover {
      color: #eeeeec; }
    GtkTreeView.view.expander:selected {
      color: #bccee1; }
      GtkTreeView.view.expander:selected:hover {
        color: #ffffff; }
      GtkTreeView.view.expander:selected:backdrop {
        color: #283a4d; }
    GtkTreeView.view.expander:checked {
      -gtk-icon-source: -gtk-icontheme("pan-down-symbolic"); }
    GtkTreeView.view.expander:backdrop {
      color: #999b99; }
  GtkTreeView.view.progressbar {
    border-radius: 4px;
    border-color: #0f2b48;
    background-image: linear-gradient(to bottom, #215d9c, #184472);
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.15), 0 1px rgba(0, 0, 0, 0.1); }
    GtkTreeView.view.progressbar:selected {
      box-shadow: inset 0 1px rgba(255, 255, 255, 0.05);
      background-image: linear-gradient(to bottom, #292929, #101010); }
      GtkTreeView.view.progressbar:selected:backdrop {
        border-color: #2c2c2c;
        background-color: #2c2c2c; }
    GtkTreeView.view.progressbar:backdrop {
      border-color: #2c2c2c;
      background-image: none;
      box-shadow: none; }
  GtkTreeView.view.trough {
    background-color: rgba(238, 238, 236, 0.1);
    border-radius: 4px; }
    GtkTreeView.view.trough:selected {
      background-color: #184472; }

column-header .button, column-header .header-bar .button.titlebutton, .header-bar column-header .button.titlebutton,
column-header .titlebar .button.titlebutton,
.titlebar column-header .button.titlebutton,
column-header GtkCalendar.header .button.titlebutton,
GtkCalendar.header column-header .button.titlebutton {
  color: #8b8b8a;
  background-color: #292929;
  font-weight: bold;
  text-shadow: none;
  box-shadow: none; }
  column-header .button:hover, column-header .header-bar .button.titlebutton:hover, .header-bar column-header .button.titlebutton:hover,
  column-header .titlebar .button.titlebutton:hover,
  .titlebar column-header .button.titlebutton:hover,
  column-header GtkCalendar.header .button.titlebutton:hover,
  GtkCalendar.header column-header .button.titlebutton:hover {
    color: #bcbcbb;
    box-shadow: none;
    transition: none; }
  column-header .button:active, column-header .header-bar .button.titlebutton:active, .header-bar column-header .button.titlebutton:active,
  column-header .titlebar .button.titlebutton:active,
  .titlebar column-header .button.titlebutton:active,
  column-header GtkCalendar.header .button.titlebutton:active,
  GtkCalendar.header column-header .button.titlebutton:active {
    color: #eeeeec;
    transition: none; }
column-header:last-child .button, column-header:last-child .header-bar .button.titlebutton, .header-bar column-header:last-child .button.titlebutton,
column-header:last-child .titlebar .button.titlebutton,
.titlebar column-header:last-child .button.titlebutton,
column-header:last-child GtkCalendar.header .button.titlebutton,
GtkCalendar.header column-header:last-child .button.titlebutton, column-header:last-child.button, .header-bar column-header.button.titlebutton:last-child,
.titlebar column-header.button.titlebutton:last-child,
GtkCalendar.header column-header.button.titlebutton:last-child {
  border-right-style: none; }

column-header.button.dnd, column-header .button.dnd, column-header .header-bar .dnd.button.titlebutton, .header-bar column-header .dnd.button.titlebutton,
column-header .titlebar .dnd.button.titlebutton,
.titlebar column-header .dnd.button.titlebutton,
column-header GtkCalendar.header .dnd.button.titlebutton,
GtkCalendar.header column-header .dnd.button.titlebutton, column-header.button.dnd:active, column-header.button.dnd:selected, column-header.button.dnd:hover, .header-bar column-header.dnd.button.titlebutton,
.titlebar column-header.dnd.button.titlebutton,
GtkCalendar.header column-header.dnd.button.titlebutton {
  transition: none;
  color: #215d9c;
  box-shadow: inset 1px 1px 0 1px #215d9c, inset -1px 0 0 1px #215d9c, inset 1px 1px #292929, inset -1px 0 #292929; }

column-header .button, column-header .header-bar .button.titlebutton, .header-bar column-header .button.titlebutton,
column-header .titlebar .button.titlebutton,
.titlebar column-header .button.titlebutton,
column-header GtkCalendar.header .button.titlebutton,
GtkCalendar.header column-header .button.titlebutton, column-header .button:hover, column-header .button:active {
  padding: 3px 6px;
  border-style: none solid solid none;
  border-radius: 0;
  background-image: none;
  border-color: #393f3f;
  text-shadow: none; }
  column-header .button:insensitive, column-header .header-bar .button.titlebutton:insensitive, .header-bar column-header .button.titlebutton:insensitive,
  column-header .titlebar .button.titlebutton:insensitive,
  .titlebar column-header .button.titlebutton:insensitive,
  column-header GtkCalendar.header .button.titlebutton:insensitive,
  GtkCalendar.header column-header .button.titlebutton:insensitive {
    border-color: #393f3f;
    background-image: none; }
  column-header .button:backdrop, column-header .header-bar .button.titlebutton:backdrop, .header-bar column-header .button.titlebutton:backdrop,
  column-header .titlebar .button.titlebutton:backdrop,
  .titlebar column-header .button.titlebutton:backdrop,
  column-header GtkCalendar.header .button.titlebutton:backdrop,
  GtkCalendar.header column-header .button.titlebutton:backdrop {
    border-color: #393f3f;
    border-style: none solid solid none;
    color: #818584;
    background-image: none;
    background-color: #2c2c2c; }
    column-header .button:backdrop:insensitive {
      border-color: #393f3f;
      background-image: none; }

/*********
 * Menus *
 *********/
.menubar {
  -GtkWidget-window-dragging: true;
  padding: 0px;
  box-shadow: inset 0 -1px rgba(0, 0, 0, 0.1); }
  .menubar:backdrop {
    background-color: #393f3f; }
  .menubar > .menuitem {
    padding: 4px 8px; }
    .menubar > .menuitem:hover {
      box-shadow: inset 0 -3px #215d9c;
      color: #4a90d9; }
    .menubar > .menuitem:insensitive {
      color: #939695;
      box-shadow: none; }

.menu {
  margin: 4px;
  padding: 0px;
  background-color: #292929; }
  .menu .menuitem {
    text-shadow: none;
    padding: 4px; }
    .menu .menuitem:hover {
      color: #ffffff;
      background-color: #215d9c; }
    .menu .menuitem:insensitive {
      color: #939695; }
      .menu .menuitem:insensitive:backdrop {
        color: #5d6767; }
    .menu .menuitem:backdrop, .menu .menuitem:backdrop:hover {
      color: #c9cbc9;
      background-color: #2c2c2c; }
    .menu .menuitem.arrow {
      -gtk-icon-source: -gtk-icontheme("pan-end-symbolic"); }
    .menu .menuitem.arrow:dir(rtl) {
      -gtk-icon-source: -gtk-icontheme("pan-end-symbolic-rtl"); }

.menuitem .accelerator {
  color: alpha(currentColor,0.55); }

/***************
 * Popovers   *
 ***************/
.popover {
  margin: 10px;
  padding: 2px;
  border: 1px solid #1c1f1f;
  border-radius: 5px;
  background-color: #393f3f;
  box-shadow: 0 2px 3px rgba(0, 0, 0, 0.5); }
  .popover:backdrop {
    box-shadow: none; }
  .popover > .list, .popover > .view, .popover > .toolbar
  .popover.osd > .toolbar, .popover > .inline-toolbar
  .popover.osd > .toolbar, .popover > .search-bar
  .popover.osd > .toolbar, .popover > .location-bar
  .popover.osd > .toolbar, .popover > .toolbar
  .popover.osd > .inline-toolbar, .popover > .inline-toolbar
  .popover.osd > .inline-toolbar, .popover > .search-bar
  .popover.osd > .inline-toolbar, .popover > .location-bar
  .popover.osd > .inline-toolbar, .popover > .toolbar
  .popover.osd > .search-bar, .popover > .inline-toolbar
  .popover.osd > .search-bar, .popover > .search-bar
  .popover.osd > .search-bar, .popover > .location-bar
  .popover.osd > .search-bar, .popover > .toolbar
  .popover.osd > .location-bar, .popover > .inline-toolbar
  .popover.osd > .location-bar, .popover > .search-bar
  .popover.osd > .location-bar, .popover > .location-bar
  .popover.osd > .location-bar {
    border-style: none;
    background-color: transparent; }
  .popover .button.flat, .popover .header-bar .titlebutton.button, .header-bar .popover .titlebutton.button,
  .popover .titlebar .titlebutton.button,
  .titlebar .popover .titlebutton.button,
  .popover GtkCalendar.header .titlebutton.button,
  GtkCalendar.header .popover .titlebutton.button,
  .popover .button.flat:hover,
  .popover .header-bar .titlebutton.button:hover,
  .header-bar .popover .titlebutton.button:hover,
  .popover .titlebar .titlebutton.button:hover,
  .titlebar .popover .titlebutton.button:hover,
  .popover GtkCalendar.header .titlebutton.button:hover,
  GtkCalendar.header .popover .titlebutton.button:hover {
    text-shadow: none;
    transition: none; }
  .popover.osd {
    background-image: none;
    background-color: #2e3436;
    border: 1px solid #1c1f1f;
    color: #eeeeec; }
    .popover.osd .button {
      color: white;
      text-shadow: none;
      color: #eeeeec;
      outline-color: rgba(238, 238, 236, 0.2);
      background-color: transparent;
      background-clip: padding-box;
      background-image: linear-gradient(to bottom, rgba(46, 52, 54, 0.7));
      border-color: rgba(0, 0, 0, 0.7);
      box-shadow: inset 0 -1px rgba(0, 0, 0, 0.3), inset 0 1px rgba(255, 255, 255, 0.1);
      text-shadow: 0 1px black;
      icon-shadow: 0 1px black; }
      .popover.osd .button:hover {
        color: white;
        border-color: rgba(0, 0, 0, 0.7);
        background-image: linear-gradient(to bottom, rgba(74, 84, 87, 0.7));
        box-shadow: inset 0 -1px rgba(0, 0, 0, 0.3), inset 0 1px rgba(255, 255, 255, 0.1);
        text-shadow: 0 1px black;
        icon-shadow: 0 1px black; }
      .popover.osd .button:active {
        color: white;
        border-color: rgba(0, 0, 0, 0.7);
        background-image: linear-gradient(to bottom, rgba(0, 0, 0, 0.7));
        box-shadow: none;
        text-shadow: none;
        icon-shadow: none; }
      .popover.osd .button:insensitive {
        color: #939695;
        border-color: rgba(0, 0, 0, 0.7);
        background-image: linear-gradient(to bottom, rgba(66, 71, 73, 0.7));
        box-shadow: none;
        text-shadow: none;
        icon-shadow: none; }

.entry.cursor-handle,
.cursor-handle {
  background-color: transparent;
  background-image: none;
  box-shadow: none;
  border-style: none; }
  .entry.cursor-handle.top,
  .cursor-handle.top {
    -gtk-icon-source: -gtk-icontheme("selection-start-symbolic"); }
  .entry.cursor-handle.bottom,
  .cursor-handle.bottom {
    -gtk-icon-source: -gtk-icontheme("selection-end-symbolic"); }

/*****************
 * Notebooks and *
 * Tabs          *
 *****************/
.notebook {
  padding: 0;
  background-color: #292929;
  -GtkNotebook-initial-gap: 10;
  -GtkNotebook-arrow-spacing: 5;
  -GtkNotebook-tab-curvature: 0;
  -GtkNotebook-tab-overlap: -8;
  -GtkNotebook-has-tab-gap: false;
  -GtkWidget-focus-padding: 0;
  -GtkWidget-focus-line-width: 0;
  transition: all 200ms ease-out; }
  .notebook:backdrop {
    background-color: #2c2c2c; }
  .notebook.frame {
    border: 1px solid #1c1f1f; }
    .notebook.frame.top {
      border-top-width: 0; }
    .notebook.frame.bottom {
      border-bottom-width: 0; }
    .notebook.frame.right {
      border-right-width: 0; }
    .notebook.frame.left {
      border-left-width: 0; }
    .notebook.frame:backdrop {
      border-color: #1e2222; }
  .notebook.header {
    background-color: #303535; }
    .notebook.header.frame {
      border: 1px solid #1c1f1f; }
      .notebook.header.frame.top {
        border-bottom-width: 0; }
      .notebook.header.frame.bottom {
        border-top-width: 0; }
      .notebook.header.frame.right {
        border-left-width: 0; }
      .notebook.header.frame.left {
        border-right-width: 0; }
      .notebook.header.frame:backdrop {
        border-color: #1e2222; }
    .notebook.header.top {
      box-shadow: inset 0 2px 3px -1px rgba(0, 0, 0, 0.15), inset 0 -1px #1c1f1f; }
      .notebook.header.top:backdrop {
        box-shadow: inset 0 -1px #1e2222; }
    .notebook.header.bottom {
      box-shadow: inset 0 2px 3px -1px rgba(0, 0, 0, 0.15), inset 0 1px #1c1f1f; }
      .notebook.header.bottom:backdrop {
        box-shadow: inset 0 1px #1e2222; }
    .notebook.header.right {
      box-shadow: inset 0 2px 3px -1px rgba(0, 0, 0, 0.15), inset 1px 0 #1c1f1f; }
      .notebook.header.right:backdrop {
        box-shadow: inset 1px 0 #1e2222; }
    .notebook.header.left {
      box-shadow: inset 0 2px 3px -1px rgba(0, 0, 0, 0.15), inset -1px 0 #1c1f1f; }
      .notebook.header.left:backdrop {
        box-shadow: inset -1px 0 #1e2222; }
    .notebook.header:backdrop {
      background-color: #2f3434;
      box-shadow: none; }
  .notebook tab {
    border-width: 0;
    border-style: solid;
    border-color: transparent;
    background-color: transparent;
    outline-offset: 0;
    /* works for testnotebookdnd, but there's a superfluous border
       in gedit or web, commented out for now, needs gtk fixes
    &.reorderable-page {
      &.top {
        padding-top: ($vt_vpadding - 1px);
        border-top-width: 1px;
        border-left-width: 1px;
        border-right-width: 1px;
      }
      &.bottom {
        padding-bottom: ($vt_vpadding - 1px);
        border-bottom-width: 1px;
        border-left-width: 1px;
        border-right-width: 1px;
      }
      &.left {
        padding-left: ($ht_hpadding - 1px);
        border-left-width: 1px;
        border-top-width: 1px;
        border-bottom-width: 1px;
      }
      &.right {
        padding-right: ($ht_hpadding - 1px);
        border-right-width: 1px;
        border-top-width: 1px;
        border-bottom-width: 1px;
      }
    }
    */ }
    .notebook tab.top, .notebook tab.bottom {
      padding: 8px 20px; }
    .notebook tab.left, .notebook tab.right {
      padding: 5px 20px; }
    .notebook tab.reorderable-page.top, .notebook tab.reorderable-page.bottom {
      padding-left: 12px;
      padding-right: 12px;
      border-left-width: 1px;
      border-right-width: 1px; }
    .notebook tab.reorderable-page.left, .notebook tab.reorderable-page.right {
      border-bottom-width: 1px;
      border-top-width: 1px; }
    .notebook tab.top {
      border-bottom-width: 3px; }
    .notebook tab.bottom {
      border-top-width: 3px; }
    .notebook tab.left {
      border-right-width: 3px; }
    .notebook tab.right {
      border-left-width: 3px; }
    .notebook tab:hover, .notebook tab.prelight-page {
      border-color: #1c1f1f; }
    .notebook tab:active, .notebook tab.active-page, .notebook tab:backdrop:active {
      border-color: #215d9c; }
    .notebook tab:backdrop {
      background-color: transparent;
      border-color: transparent; }
    .notebook tab.reorderable-page.top {
      border-color: transparent; }
      .notebook tab.reorderable-page.top:hover, .notebook tab.reorderable-page.top.prelight-page {
        border-color: rgba(28, 31, 31, 0.3);
        border-bottom-color: #1c1f1f;
        background-color: rgba(57, 63, 63, 0.2); }
      .notebook tab.reorderable-page.top:active, .notebook tab.reorderable-page.top.active-page {
        background-color: rgba(57, 63, 63, 0.5);
        border-color: rgba(28, 31, 31, 0.5);
        border-bottom-color: #215d9c; }
        .notebook tab.reorderable-page.top:active:hover, .notebook tab.reorderable-page.top.active-page:hover {
          background-color: rgba(57, 63, 63, 0.7); }
        .notebook tab.reorderable-page.top:active:backdrop, .notebook tab.reorderable-page.top.active-page:backdrop {
          border-color: #1e2222;
          background-color: #393f3f;
          border-bottom-color: #215d9c; }
      .notebook tab.reorderable-page.top:backdrop {
        border-color: transparent;
        background-color: transparent; }
    .notebook tab.reorderable-page.bottom {
      border-color: transparent; }
      .notebook tab.reorderable-page.bottom:hover, .notebook tab.reorderable-page.bottom.prelight-page {
        border-color: rgba(28, 31, 31, 0.3);
        border-top-color: #1c1f1f;
        background-color: rgba(57, 63, 63, 0.2); }
      .notebook tab.reorderable-page.bottom:active, .notebook tab.reorderable-page.bottom.active-page {
        background-color: rgba(57, 63, 63, 0.5);
        border-color: rgba(28, 31, 31, 0.5);
        border-top-color: #215d9c; }
        .notebook tab.reorderable-page.bottom:active:hover, .notebook tab.reorderable-page.bottom.active-page:hover {
          background-color: rgba(57, 63, 63, 0.7); }
        .notebook tab.reorderable-page.bottom:active:backdrop, .notebook tab.reorderable-page.bottom.active-page:backdrop {
          border-color: #1e2222;
          background-color: #393f3f;
          border-top-color: #215d9c; }
      .notebook tab.reorderable-page.bottom:backdrop {
        border-color: transparent;
        background-color: transparent; }
    .notebook tab.reorderable-page.left {
      border-color: transparent; }
      .notebook tab.reorderable-page.left:hover, .notebook tab.reorderable-page.left.prelight-page {
        border-color: rgba(28, 31, 31, 0.3);
        border-right-color: #1c1f1f;
        background-color: rgba(57, 63, 63, 0.2); }
      .notebook tab.reorderable-page.left:active, .notebook tab.reorderable-page.left.active-page {
        background-color: rgba(57, 63, 63, 0.5);
        border-color: rgba(28, 31, 31, 0.5);
        border-right-color: #215d9c; }
        .notebook tab.reorderable-page.left:active:hover, .notebook tab.reorderable-page.left.active-page:hover {
          background-color: rgba(57, 63, 63, 0.7); }
        .notebook tab.reorderable-page.left:active:backdrop, .notebook tab.reorderable-page.left.active-page:backdrop {
          border-color: #1e2222;
          background-color: #393f3f;
          border-right-color: #215d9c; }
      .notebook tab.reorderable-page.left:backdrop {
        border-color: transparent;
        background-color: transparent; }
    .notebook tab.reorderable-page.right {
      border-color: transparent; }
      .notebook tab.reorderable-page.right:hover, .notebook tab.reorderable-page.right.prelight-page {
        border-color: rgba(28, 31, 31, 0.3);
        border-left-color: #1c1f1f;
        background-color: rgba(57, 63, 63, 0.2); }
      .notebook tab.reorderable-page.right:active, .notebook tab.reorderable-page.right.active-page {
        background-color: rgba(57, 63, 63, 0.5);
        border-color: rgba(28, 31, 31, 0.5);
        border-left-color: #215d9c; }
        .notebook tab.reorderable-page.right:active:hover, .notebook tab.reorderable-page.right.active-page:hover {
          background-color: rgba(57, 63, 63, 0.7); }
        .notebook tab.reorderable-page.right:active:backdrop, .notebook tab.reorderable-page.right.active-page:backdrop {
          border-color: #1e2222;
          background-color: #393f3f;
          border-left-color: #215d9c; }
      .notebook tab.reorderable-page.right:backdrop {
        border-color: transparent;
        background-color: transparent; }
    .notebook tab GtkLabel {
      padding: 0 2px;
      font-weight: bold;
      color: #939695; }
      .notebook tab GtkLabel:backdrop, .notebook tab GtkLabel.prelight-page:backdrop {
        color: #939998; }
    .notebook tab .prelight-page GtkLabel, .notebook tab GtkLabel.prelight-page {
      color: #c0c2c0; }
      .notebook tab .prelight-page GtkLabel:backdrop, .notebook tab GtkLabel.prelight-page:backdrop {
        color: #939998; }
    .notebook tab .active-page GtkLabel, .notebook tab GtkLabel.active-page {
      color: #eeeeec; }
      .notebook tab .active-page GtkLabel:backdrop, .notebook tab GtkLabel.active-page:backdrop {
        color: #c9cbc9; }
    .notebook tab .button, .notebook tab .header-bar .button.titlebutton, .header-bar .notebook tab .button.titlebutton,
    .notebook tab .titlebar .button.titlebutton,
    .titlebar .notebook tab .button.titlebutton,
    .notebook tab GtkCalendar.header .button.titlebutton,
    GtkCalendar.header .notebook tab .button.titlebutton {
      padding: 0;
      border: 1px solid transparent;
      icon-shadow: none;
      transition: none;
      color: rgba(238, 238, 236, 0.3); }
      .notebook tab .button:hover {
        color: #eeeeec;
        color: #eeeeec;
        outline-color: rgba(238, 238, 236, 0.3);
        border-color: #1c1f1f;
        background-image: linear-gradient(to bottom, #5b6464, #434a4a 40%, #393f3f);
        text-shadow: 0 -1px rgba(0, 0, 0, 0.77976);
        icon-shadow: 0 -1px rgba(0, 0, 0, 0.77976);
        box-shadow: inset 0 1px rgba(255, 255, 255, 0.1);
        background-image: none;
        box-shadow: none; }
      .notebook tab .button:active {
        color: #eeeeec;
        outline-color: rgba(238, 238, 236, 0.3);
        border-color: #1c1f1f;
        background-image: linear-gradient(to bottom, #232727, #2d3232);
        text-shadow: 0 -1px rgba(0, 0, 0, 0.89176);
        icon-shadow: 0 -1px rgba(0, 0, 0, 0.89176);
        box-shadow: inset 0 1px rgba(0, 0, 0, 0.07), inset 0 2px 1px -2px rgba(0, 0, 0, 0.6); }
      .notebook tab .button:backdrop {
        color: rgba(201, 203, 201, 0.3);
        border-color: transparent; }
      .notebook tab .button > GtkImage, .notebook tab .header-bar .button.titlebutton > GtkImage, .header-bar .notebook tab .button.titlebutton > GtkImage,
      .notebook tab .titlebar .button.titlebutton > GtkImage,
      .titlebar .notebook tab .button.titlebutton > GtkImage,
      .notebook tab GtkCalendar.header .button.titlebutton > GtkImage,
      GtkCalendar.header .notebook tab .button.titlebutton > GtkImage {
        padding: 2px; }
  .notebook.arrow {
    color: #939695; }
    .notebook.arrow:hover {
      color: #c0c2c0; }
    .notebook.arrow:active {
      color: #eeeeec; }
    .notebook.arrow:insensitive {
      color: rgba(147, 150, 149, 0.3); }
    .notebook.arrow:backdrop {
      color: rgba(201, 203, 201, 0.4); }
      .notebook.arrow:backdrop:insensitive {
        color: #5d6767; }

/**************
 * Scrollbars *
 **************/
.scrollbar {
  background-clip: padding-box;
  background-image: none;
  border-style: solid;
  -GtkRange-trough-border: 0;
  -GtkScrollbar-has-backward-stepper: false;
  -GtkScrollbar-has-forward-stepper: false;
  -GtkRange-slider-width: 13;
  -GtkScrollbar-min-slider-length: 42;
  -GtkRange-stepper-spacing: 0;
  -GtkRange-trough-under-steppers: 1; }
  .scrollbar .button, .scrollbar .header-bar .button.titlebutton, .header-bar .scrollbar .button.titlebutton,
  .scrollbar .titlebar .button.titlebutton,
  .titlebar .scrollbar .button.titlebutton,
  .scrollbar GtkCalendar.header .button.titlebutton,
  GtkCalendar.header .scrollbar .button.titlebutton {
    border: none; }
  .scrollbar.slider {
    border-radius: 20px;
    border: 3px solid transparent;
    background-color: #6f7372; }
    .scrollbar.slider:hover {
      background-color: #939695; }
    .scrollbar.slider:prelight:active {
      background-color: #215d9c; }
    .scrollbar.slider.fine-tune {
      border-width: 5px; }
      .scrollbar.slider.fine-tune:prelight:active {
        background-color: #215d9c; }
    .scrollbar.slider:backdrop, .scrollbar.slider:insensitive {
      background-color: #4b5050; }

.scrollbars-junction, .scrollbar.trough {
  border-color: transparent;
  background-color: #2d3232; }
  .scrollbars-junction:backdrop, .scrollbar.trough:backdrop {
    background-color: transparent; }

/**********
 * Switch *
 **********/
GtkSwitch {
  -GtkSwitch-slider-width: 45px;
  font-weight: bold;
  font-size: smaller;
  outline-offset: -4px;
  box-shadow: inset 0 1px rgba(0, 0, 0, 0.1), 0 1px rgba(238, 238, 236, 0.1); }
  GtkSwitch.trough {
    border: 1px solid #1c1f1f;
    border-radius: 3px;
    color: #eeeeec;
    background-image: linear-gradient(to bottom, #2d3232);
    text-shadow: 0 1px rgba(0, 0, 0, 0.1); }
    GtkSwitch.trough:active {
      background-image: linear-gradient(to bottom, #215d9c 2px, #266cb5);
      color: white;
      border-color: #0f2b48;
      box-shadow: 0 1px rgba(238, 238, 236, 0.1);
      text-shadow: 0 1px rgba(15, 43, 72, 0.5), 0 0 2px rgba(255, 255, 255, 0.6); }
    GtkSwitch.trough:insensitive {
      color: #939695;
      border-color: #1c1f1f;
      background-image: none;
      background-color: #323636;
      box-shadow: 0 1px rgba(238, 238, 236, 0.1);
      text-shadow: none; }
    GtkSwitch.trough:backdrop {
      color: #c9cbc9;
      border-color: #1e2222;
      background-image: linear-gradient(to bottom, #2f3434);
      box-shadow: none;
      text-shadow: none; }
      GtkSwitch.trough:backdrop:active {
        border-color: #0f2b48;
        background-image: linear-gradient(to bottom, #215d9c);
        box-shadow: none; }
      GtkSwitch.trough:backdrop:insensitive {
        color: #5d6767;
        border-color: #1e2222;
        background-image: none;
        background-color: #323636; }
  GtkSwitch.slider {
    border: 1px solid;
    border-radius: 3px;
    color: #eeeeec;
    outline-color: rgba(238, 238, 236, 0.3);
    border-color: #1c1f1f;
    background-image: linear-gradient(to bottom, #454c4c, #393f3f 40%, #2d3232);
    text-shadow: 0 -1px rgba(0, 0, 0, 0.81176);
    icon-shadow: 0 -1px rgba(0, 0, 0, 0.81176);
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.1), 0 1px rgba(238, 238, 236, 0.1);
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.15), inset 0 -2px rgba(57, 63, 63, 0.6), inset 0 -1px #2a2f2f; }
    GtkSwitch.slider:hover {
      color: #eeeeec;
      outline-color: rgba(238, 238, 236, 0.3);
      border-color: #1c1f1f;
      background-image: linear-gradient(to bottom, #5b6464, #434a4a 40%, #393f3f);
      text-shadow: 0 -1px rgba(0, 0, 0, 0.77976);
      icon-shadow: 0 -1px rgba(0, 0, 0, 0.77976);
      box-shadow: inset 0 1px rgba(255, 255, 255, 0.1), 0 1px rgba(238, 238, 236, 0.1);
      box-shadow: inset 0 1px rgba(255, 255, 255, 0.15), inset 0 -2px rgba(57, 63, 63, 0.6), inset 0 -1px #2a2f2f; }
    GtkSwitch.slider:active {
      border: 1px solid #0f2b48; }
    GtkSwitch.slider:insensitive {
      color: #939695;
      border-color: #1c1f1f;
      background-image: linear-gradient(to bottom, #323636);
      text-shadow: none;
      icon-shadow: none;
      box-shadow: inset 0 1px rgba(255, 255, 255, 0); }
      GtkSwitch.slider:insensitive > GtkLabel {
        color: inherit; }
    GtkSwitch.slider:backdrop {
      color: #c9cbc9;
      border-color: #1e2222;
      background-image: linear-gradient(to bottom, #393f3f);
      text-shadow: none;
      icon-shadow: none;
      box-shadow: inset 0 1px rgba(255, 255, 255, 0), 0 1px rgba(238, 238, 236, 0);
      box-shadow: none; }
      GtkSwitch.slider:backdrop:active {
        border-color: #0f2b48; }
      GtkSwitch.slider:backdrop:insensitive {
        color: #5d6767;
        border-color: #1e2222;
        background-image: linear-gradient(to bottom, #323636);
        text-shadow: none;
        icon-shadow: none;
        box-shadow: inset 0 1px rgba(255, 255, 255, 0), 0 1px rgba(238, 238, 236, 0);
        box-shadow: none; }
        GtkSwitch.slider:backdrop:insensitive > GtkLabel {
          color: inherit; }

/*************************
 * Check and Radio items *
 *************************/
.check {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-unchecked-dark.png"), url("assets/checkbox-unchecked-dark@2.png"));
  icon-shadow: 0 1px 0 rgba(238, 238, 236, 0.1); }
  .check.button.flat, .header-bar .check.titlebutton.button,
  .titlebar .check.titlebutton.button,
  GtkCalendar.header .check.titlebutton.button {
    icon-shadow: none; }

.check:hover {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-unchecked-hover-dark.png"), url("assets/checkbox-unchecked-hover-dark@2.png"));
  icon-shadow: 0 1px 0 rgba(238, 238, 236, 0.1); }
  .check:hover.button.flat, .header-bar .check.titlebutton.button:hover,
  .titlebar .check.titlebutton.button:hover,
  GtkCalendar.header .check.titlebutton.button:hover {
    icon-shadow: none; }

.check:active {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-unchecked-active-dark.png"), url("assets/checkbox-unchecked-active-dark@2.png"));
  icon-shadow: 0 1px 0 rgba(238, 238, 236, 0.1); }
  .check:active.button.flat, .header-bar .check.titlebutton.button:active,
  .titlebar .check.titlebutton.button:active,
  GtkCalendar.header .check.titlebutton.button:active {
    icon-shadow: none; }

.check:insensitive {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-unchecked-insensitive-dark.png"), url("assets/checkbox-unchecked-insensitive-dark@2.png"));
  icon-shadow: 0 1px 0 rgba(238, 238, 236, 0.1); }
  .check:insensitive.button.flat, .header-bar .check.titlebutton.button:insensitive,
  .titlebar .check.titlebutton.button:insensitive,
  GtkCalendar.header .check.titlebutton.button:insensitive {
    icon-shadow: none; }

.check:backdrop {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-unchecked-backdrop-dark.png"), url("assets/checkbox-unchecked-backdrop-dark@2.png"));
  icon-shadow: none; }
  .check:backdrop.button.flat, .header-bar .check.titlebutton.button:backdrop,
  .titlebar .check.titlebutton.button:backdrop,
  GtkCalendar.header .check.titlebutton.button:backdrop {
    icon-shadow: none; }

.check:backdrop:insensitive {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-unchecked-backdrop-insensitive-dark.png"), url("assets/checkbox-unchecked-backdrop-insensitive-dark@2.png"));
  icon-shadow: none; }
  .check:backdrop:insensitive.button.flat, .header-bar .check.titlebutton.button:backdrop:insensitive,
  .titlebar .check.titlebutton.button:backdrop:insensitive,
  GtkCalendar.header .check.titlebutton.button:backdrop:insensitive {
    icon-shadow: none; }

.check:inconsistent {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-mixed-dark.png"), url("assets/checkbox-mixed-dark@2.png"));
  icon-shadow: 0 1px 0 rgba(238, 238, 236, 0.1); }
  .check:inconsistent.button.flat, .header-bar .check.titlebutton.button:inconsistent,
  .titlebar .check.titlebutton.button:inconsistent,
  GtkCalendar.header .check.titlebutton.button:inconsistent {
    icon-shadow: none; }

.check:inconsistent:hover {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-mixed-hover-dark.png"), url("assets/checkbox-mixed-hover-dark@2.png"));
  icon-shadow: 0 1px 0 rgba(238, 238, 236, 0.1); }
  .check:inconsistent:hover.button.flat, .header-bar .check.titlebutton.button:inconsistent:hover,
  .titlebar .check.titlebutton.button:inconsistent:hover,
  GtkCalendar.header .check.titlebutton.button:inconsistent:hover {
    icon-shadow: none; }

.check:inconsistent:selected {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-mixed-active-dark.png"), url("assets/checkbox-mixed-active-dark@2.png"));
  icon-shadow: 0 1px 0 rgba(238, 238, 236, 0.1); }
  .check:inconsistent:selected.button.flat, .header-bar .check.titlebutton.button:inconsistent:selected,
  .titlebar .check.titlebutton.button:inconsistent:selected,
  GtkCalendar.header .check.titlebutton.button:inconsistent:selected {
    icon-shadow: none; }

.check:inconsistent:backdrop {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-mixed-backdrop-dark.png"), url("assets/checkbox-mixed-backdrop-dark@2.png"));
  icon-shadow: none; }
  .check:inconsistent:backdrop.button.flat, .header-bar .check.titlebutton.button:inconsistent:backdrop,
  .titlebar .check.titlebutton.button:inconsistent:backdrop,
  GtkCalendar.header .check.titlebutton.button:inconsistent:backdrop {
    icon-shadow: none; }

.check:inconsistent:insensitive {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-mixed-insensitive-dark.png"), url("assets/checkbox-mixed-insensitive-dark@2.png"));
  icon-shadow: 0 1px 0 rgba(238, 238, 236, 0.1); }
  .check:inconsistent:insensitive.button.flat, .header-bar .check.titlebutton.button:inconsistent:insensitive,
  .titlebar .check.titlebutton.button:inconsistent:insensitive,
  GtkCalendar.header .check.titlebutton.button:inconsistent:insensitive {
    icon-shadow: none; }

.check:inconsistent:insensitive:backdrop {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-mixed-backdrop-insensitive-dark.png"), url("assets/checkbox-mixed-backdrop-insensitive-dark@2.png"));
  icon-shadow: none; }
  .check:inconsistent:insensitive:backdrop.button.flat, .header-bar .check.titlebutton.button:inconsistent:insensitive:backdrop,
  .titlebar .check.titlebutton.button:inconsistent:insensitive:backdrop,
  GtkCalendar.header .check.titlebutton.button:inconsistent:insensitive:backdrop {
    icon-shadow: none; }

.check:checked {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-checked-dark.png"), url("assets/checkbox-checked-dark@2.png"));
  icon-shadow: 0 1px 0 rgba(238, 238, 236, 0.1); }
  .check:checked.button.flat, .header-bar .check.titlebutton.button:checked,
  .titlebar .check.titlebutton.button:checked,
  GtkCalendar.header .check.titlebutton.button:checked {
    icon-shadow: none; }

.check:checked:insensitive {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-checked-insensitive-dark.png"), url("assets/checkbox-checked-insensitive-dark@2.png"));
  icon-shadow: 0 1px 0 rgba(238, 238, 236, 0.1); }
  .check:checked:insensitive.button.flat, .header-bar .check.titlebutton.button:checked:insensitive,
  .titlebar .check.titlebutton.button:checked:insensitive,
  GtkCalendar.header .check.titlebutton.button:checked:insensitive {
    icon-shadow: none; }

.check:checked:hover {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-checked-hover-dark.png"), url("assets/checkbox-checked-hover-dark@2.png"));
  icon-shadow: 0 1px 0 rgba(238, 238, 236, 0.1); }
  .check:checked:hover.button.flat, .header-bar .check.titlebutton.button:checked:hover,
  .titlebar .check.titlebutton.button:checked:hover,
  GtkCalendar.header .check.titlebutton.button:checked:hover {
    icon-shadow: none; }

.check:checked:active {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-checked-active-dark.png"), url("assets/checkbox-checked-active-dark@2.png"));
  icon-shadow: 0 1px 0 rgba(238, 238, 236, 0.1); }
  .check:checked:active.button.flat, .header-bar .check.titlebutton.button:checked:active,
  .titlebar .check.titlebutton.button:checked:active,
  GtkCalendar.header .check.titlebutton.button:checked:active {
    icon-shadow: none; }

.check:backdrop:checked {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-checked-backdrop-dark.png"), url("assets/checkbox-checked-backdrop-dark@2.png"));
  icon-shadow: none; }
  .check:backdrop:checked.button.flat, .header-bar .check.titlebutton.button:backdrop:checked,
  .titlebar .check.titlebutton.button:backdrop:checked,
  GtkCalendar.header .check.titlebutton.button:backdrop:checked {
    icon-shadow: none; }

.check:backdrop:checked:insensitive {
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-checked-backdrop-insensitive-dark.png"), url("assets/checkbox-checked-backdrop-insensitive-dark@2.png"));
  icon-shadow: none; }
  .check:backdrop:checked:insensitive.button.flat, .header-bar .check.titlebutton.button:backdrop:checked:insensitive,
  .titlebar .check.titlebutton.button:backdrop:checked:insensitive,
  GtkCalendar.header .check.titlebutton.button:backdrop:checked:insensitive {
    icon-shadow: none; }

.menu .menuitem.check {
  -gtk-icon-source: -gtk-icontheme("checkbox-symbolic");
  color: #a5a8a6;
  icon-shadow: none; }
  .menu .menuitem.check:active, .menu .menuitem.check:checked {
    -gtk-icon-source: -gtk-icontheme("checkbox-checked-symbolic"); }
  .menu .menuitem.check:inconsistent {
    -gtk-icon-source: -gtk-icontheme("checkbox-mixed-symbolic"); }
  .menu .menuitem.check:hover {
    color: #ffffff; }
  .menu .menuitem.check:insensitive {
    color: #666a6a; }

.radio {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-unchecked-dark.png"), url("assets/radio-unchecked-dark@2.png"));
  icon-shadow: 0 1px 0 rgba(238, 238, 236, 0.1); }
  .radio.button.flat, .header-bar .radio.titlebutton.button,
  .titlebar .radio.titlebutton.button,
  GtkCalendar.header .radio.titlebutton.button {
    icon-shadow: none; }

.radio:hover {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-unchecked-hover-dark.png"), url("assets/radio-unchecked-hover-dark@2.png"));
  icon-shadow: 0 1px 0 rgba(238, 238, 236, 0.1); }
  .radio:hover.button.flat, .header-bar .radio.titlebutton.button:hover,
  .titlebar .radio.titlebutton.button:hover,
  GtkCalendar.header .radio.titlebutton.button:hover {
    icon-shadow: none; }

.radio:active {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-unchecked-active-dark.png"), url("assets/radio-unchecked-active-dark@2.png"));
  icon-shadow: 0 1px 0 rgba(238, 238, 236, 0.1); }
  .radio:active.button.flat, .header-bar .radio.titlebutton.button:active,
  .titlebar .radio.titlebutton.button:active,
  GtkCalendar.header .radio.titlebutton.button:active {
    icon-shadow: none; }

.radio:insensitive {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-unchecked-insensitive-dark.png"), url("assets/radio-unchecked-insensitive-dark@2.png"));
  icon-shadow: 0 1px 0 rgba(238, 238, 236, 0.1); }
  .radio:insensitive.button.flat, .header-bar .radio.titlebutton.button:insensitive,
  .titlebar .radio.titlebutton.button:insensitive,
  GtkCalendar.header .radio.titlebutton.button:insensitive {
    icon-shadow: none; }

.radio:backdrop {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-unchecked-backdrop-dark.png"), url("assets/radio-unchecked-backdrop-dark@2.png"));
  icon-shadow: none; }
  .radio:backdrop.button.flat, .header-bar .radio.titlebutton.button:backdrop,
  .titlebar .radio.titlebutton.button:backdrop,
  GtkCalendar.header .radio.titlebutton.button:backdrop {
    icon-shadow: none; }

.radio:backdrop:insensitive {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-unchecked-backdrop-insensitive-dark.png"), url("assets/radio-unchecked-backdrop-insensitive-dark@2.png"));
  icon-shadow: none; }
  .radio:backdrop:insensitive.button.flat, .header-bar .radio.titlebutton.button:backdrop:insensitive,
  .titlebar .radio.titlebutton.button:backdrop:insensitive,
  GtkCalendar.header .radio.titlebutton.button:backdrop:insensitive {
    icon-shadow: none; }

.radio:inconsistent {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-mixed-dark.png"), url("assets/radio-mixed-dark@2.png"));
  icon-shadow: 0 1px 0 rgba(238, 238, 236, 0.1); }
  .radio:inconsistent.button.flat, .header-bar .radio.titlebutton.button:inconsistent,
  .titlebar .radio.titlebutton.button:inconsistent,
  GtkCalendar.header .radio.titlebutton.button:inconsistent {
    icon-shadow: none; }

.radio:inconsistent:hover {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-mixed-hover-dark.png"), url("assets/radio-mixed-hover-dark@2.png"));
  icon-shadow: 0 1px 0 rgba(238, 238, 236, 0.1); }
  .radio:inconsistent:hover.button.flat, .header-bar .radio.titlebutton.button:inconsistent:hover,
  .titlebar .radio.titlebutton.button:inconsistent:hover,
  GtkCalendar.header .radio.titlebutton.button:inconsistent:hover {
    icon-shadow: none; }

.radio:inconsistent:selected {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-mixed-active-dark.png"), url("assets/radio-mixed-active-dark@2.png"));
  icon-shadow: 0 1px 0 rgba(238, 238, 236, 0.1); }
  .radio:inconsistent:selected.button.flat, .header-bar .radio.titlebutton.button:inconsistent:selected,
  .titlebar .radio.titlebutton.button:inconsistent:selected,
  GtkCalendar.header .radio.titlebutton.button:inconsistent:selected {
    icon-shadow: none; }

.radio:inconsistent:backdrop {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-mixed-backdrop-dark.png"), url("assets/radio-mixed-backdrop-dark@2.png"));
  icon-shadow: none; }
  .radio:inconsistent:backdrop.button.flat, .header-bar .radio.titlebutton.button:inconsistent:backdrop,
  .titlebar .radio.titlebutton.button:inconsistent:backdrop,
  GtkCalendar.header .radio.titlebutton.button:inconsistent:backdrop {
    icon-shadow: none; }

.radio:inconsistent:insensitive {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-mixed-insensitive-dark.png"), url("assets/radio-mixed-insensitive-dark@2.png"));
  icon-shadow: 0 1px 0 rgba(238, 238, 236, 0.1); }
  .radio:inconsistent:insensitive.button.flat, .header-bar .radio.titlebutton.button:inconsistent:insensitive,
  .titlebar .radio.titlebutton.button:inconsistent:insensitive,
  GtkCalendar.header .radio.titlebutton.button:inconsistent:insensitive {
    icon-shadow: none; }

.radio:inconsistent:insensitive:backdrop {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-mixed-backdrop-insensitive-dark.png"), url("assets/radio-mixed-backdrop-insensitive-dark@2.png"));
  icon-shadow: none; }
  .radio:inconsistent:insensitive:backdrop.button.flat, .header-bar .radio.titlebutton.button:inconsistent:insensitive:backdrop,
  .titlebar .radio.titlebutton.button:inconsistent:insensitive:backdrop,
  GtkCalendar.header .radio.titlebutton.button:inconsistent:insensitive:backdrop {
    icon-shadow: none; }

.radio:checked {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-checked-dark.png"), url("assets/radio-checked-dark@2.png"));
  icon-shadow: 0 1px 0 rgba(238, 238, 236, 0.1); }
  .radio:checked.button.flat, .header-bar .radio.titlebutton.button:checked,
  .titlebar .radio.titlebutton.button:checked,
  GtkCalendar.header .radio.titlebutton.button:checked {
    icon-shadow: none; }

.radio:checked:insensitive {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-checked-insensitive-dark.png"), url("assets/radio-checked-insensitive-dark@2.png"));
  icon-shadow: 0 1px 0 rgba(238, 238, 236, 0.1); }
  .radio:checked:insensitive.button.flat, .header-bar .radio.titlebutton.button:checked:insensitive,
  .titlebar .radio.titlebutton.button:checked:insensitive,
  GtkCalendar.header .radio.titlebutton.button:checked:insensitive {
    icon-shadow: none; }

.radio:checked:hover {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-checked-hover-dark.png"), url("assets/radio-checked-hover-dark@2.png"));
  icon-shadow: 0 1px 0 rgba(238, 238, 236, 0.1); }
  .radio:checked:hover.button.flat, .header-bar .radio.titlebutton.button:checked:hover,
  .titlebar .radio.titlebutton.button:checked:hover,
  GtkCalendar.header .radio.titlebutton.button:checked:hover {
    icon-shadow: none; }

.radio:checked:active {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-checked-active-dark.png"), url("assets/radio-checked-active-dark@2.png"));
  icon-shadow: 0 1px 0 rgba(238, 238, 236, 0.1); }
  .radio:checked:active.button.flat, .header-bar .radio.titlebutton.button:checked:active,
  .titlebar .radio.titlebutton.button:checked:active,
  GtkCalendar.header .radio.titlebutton.button:checked:active {
    icon-shadow: none; }

.radio:backdrop:checked {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-checked-backdrop-dark.png"), url("assets/radio-checked-backdrop-dark@2.png"));
  icon-shadow: none; }
  .radio:backdrop:checked.button.flat, .header-bar .radio.titlebutton.button:backdrop:checked,
  .titlebar .radio.titlebutton.button:backdrop:checked,
  GtkCalendar.header .radio.titlebutton.button:backdrop:checked {
    icon-shadow: none; }

.radio:backdrop:checked:insensitive {
  -gtk-icon-source: -gtk-scaled(url("assets/radio-checked-backdrop-insensitive-dark.png"), url("assets/radio-checked-backdrop-insensitive-dark@2.png"));
  icon-shadow: none; }
  .radio:backdrop:checked:insensitive.button.flat, .header-bar .radio.titlebutton.button:backdrop:checked:insensitive,
  .titlebar .radio.titlebutton.button:backdrop:checked:insensitive,
  GtkCalendar.header .radio.titlebutton.button:backdrop:checked:insensitive {
    icon-shadow: none; }

.menu .menuitem.radio {
  -gtk-icon-source: -gtk-icontheme("radio-symbolic");
  color: #a5a8a6;
  icon-shadow: none; }
  .menu .menuitem.radio:active, .menu .menuitem.radio:checked {
    -gtk-icon-source: -gtk-icontheme("radio-checked-symbolic"); }
  .menu .menuitem.radio:inconsistent {
    -gtk-icon-source: -gtk-icontheme("radio-mixed-symbolic"); }
  .menu .menuitem.radio:hover {
    color: #ffffff; }
  .menu .menuitem.radio:insensitive {
    color: #666a6a; }

GtkTreeView.view.check, GtkTreeView.view.radio,
.list-row .check, list-row .radio {
  icon-shadow: none; }
  GtkTreeView.view.check:selected, GtkTreeView.view.check:hover, GtkTreeView.view.radio:selected, GtkTreeView.view.radio:hover,
  .list-row .check:selected,
  .list-row .check:hover, list-row .radio:selected, list-row .radio:hover {
    icon-shadow: none; }

GtkIconView.view.check,
GtkFlowBox.view.check {
  icon-shadow: none;
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-selectionmode.png"), url("assets/checkbox-selectionmode@2.png"));
  background-color: transparent; }

GtkIconView.view.check:hover,
GtkFlowBox.view.check:hover {
  icon-shadow: none;
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-hover-selectionmode.png"), url("assets/checkbox-hover-selectionmode@2.png"));
  background-color: transparent; }

GtkIconView.view.check:active,
GtkFlowBox.view.check:active {
  icon-shadow: none;
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-active-selectionmode.png"), url("assets/checkbox-active-selectionmode@2.png"));
  background-color: transparent; }

GtkIconView.view.check:backdrop,
GtkFlowBox.view.check:backdrop {
  icon-shadow: none;
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-backdrop-selectionmode.png"), url("assets/checkbox-backdrop-selectionmode@2.png"));
  background-color: transparent; }

GtkIconView.view.check:checked,
GtkFlowBox.view.check:checked {
  icon-shadow: none;
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-checked-selectionmode.png"), url("assets/checkbox-checked-selectionmode@2.png"));
  background-color: transparent; }

GtkIconView.view.check:checked:hover,
GtkFlowBox.view.check:checked:hover {
  icon-shadow: none;
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-checked-hover-selectionmode.png"), url("assets/checkbox-checked-hover-selectionmode@2.png"));
  background-color: transparent; }

GtkIconView.view.check:checked:active,
GtkFlowBox.view.check:checked:active {
  icon-shadow: none;
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-checked-active-selectionmode.png"), url("assets/checkbox-checked-active-selectionmode@2.png"));
  background-color: transparent; }

GtkIconView.view.check:backdrop:checked,
GtkFlowBox.view.check:backdrop:checked {
  icon-shadow: none;
  -gtk-icon-source: -gtk-scaled(url("assets/checkbox-checked-backdrop-selectionmode.png"), url("assets/checkbox-checked-backdrop-selectionmode@2.png"));
  background-color: transparent; }

GtkCheckButton.text-button, GtkRadioButton.text-button {
  padding: 1px 2px 4px;
  outline-offset: 0; }
  GtkCheckButton.text-button:insensitive, GtkCheckButton.text-button:insensitive:active, GtkCheckButton.text-button:insensitive:inconsistent, GtkRadioButton.text-button:insensitive, GtkRadioButton.text-button:insensitive:active, GtkRadioButton.text-button:insensitive:inconsistent {
    color: #939695; }
    GtkCheckButton.text-button:insensitive:backdrop, GtkCheckButton.text-button:insensitive:active:backdrop, GtkCheckButton.text-button:insensitive:inconsistent:backdrop, GtkRadioButton.text-button:insensitive:backdrop, GtkRadioButton.text-button:insensitive:active:backdrop, GtkRadioButton.text-button:insensitive:inconsistent:backdrop {
      color: #5d6767; }

/************
 * GtkScale *
 ************/
.scale,
.scale.scale-has-marks-above.scale-has-marks-below,
.scale.vertical.scale-has-marks-above.scale-has-marks-below {
  -GtkScale-slider-length: 20;
  -GtkRange-slider-width: 20;
  -GtkRange-trough-border: 2;
  outline-offset: -9px;
  outline-radius: 4px;
  margin: 10px; }
  .scale.fine-tune,
  .scale.scale-has-marks-above.scale-has-marks-below.fine-tune,
  .scale.vertical.scale-has-marks-above.scale-has-marks-below.fine-tune {
    margin: 8px;
    outline-offset: -7px;
    outline-radius: 6px; }
    .scale.fine-tune.trough,
    .scale.scale-has-marks-above.scale-has-marks-below.fine-tune.trough,
    .scale.vertical.scale-has-marks-above.scale-has-marks-below.fine-tune.trough {
      border-radius: 4px; }
  .scale.slider,
  .scale.scale-has-marks-above.scale-has-marks-below.slider,
  .scale.vertical.scale-has-marks-above.scale-has-marks-below.slider {
    color: #eeeeec;
    outline-color: rgba(238, 238, 236, 0.3);
    border-color: #1c1f1f;
    background-image: linear-gradient(to bottom, #454c4c, #393f3f 40%, #2d3232);
    text-shadow: 0 -1px rgba(0, 0, 0, 0.81176);
    icon-shadow: 0 -1px rgba(0, 0, 0, 0.81176);
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.1), 0 1px rgba(238, 238, 236, 0.1);
    border: 1px solid;
    border-radius: 50%;
    border-color: #151717;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.15), inset 0 -2px #393f3f, inset 0 -1px #2a2f2f; }
    .scale.slider:hover,
    .scale.scale-has-marks-above.scale-has-marks-below.slider:hover,
    .scale.vertical.scale-has-marks-above.scale-has-marks-below.slider:hover {
      color: #eeeeec;
      outline-color: rgba(238, 238, 236, 0.3);
      border-color: #1c1f1f;
      background-image: linear-gradient(to bottom, #5b6464, #434a4a 40%, #393f3f);
      text-shadow: 0 -1px rgba(0, 0, 0, 0.77976);
      icon-shadow: 0 -1px rgba(0, 0, 0, 0.77976);
      box-shadow: inset 0 1px rgba(255, 255, 255, 0.1), 0 1px rgba(238, 238, 236, 0.1);
      border-color: #151717;
      border-radius: 50%;
      box-shadow: inset 0 1px rgba(255, 255, 255, 0.15), inset 0 -2px rgba(255, 255, 255, 0.14), inset 0 -1px #303535; }
    .scale.slider:insensitive,
    .scale.scale-has-marks-above.scale-has-marks-below.slider:insensitive,
    .scale.vertical.scale-has-marks-above.scale-has-marks-below.slider:insensitive {
      border-style: solid;
      border-radius: 50%;
      background-image: linear-gradient(to bottom, #323636);
      box-shadow: none; }
    .scale.slider:backdrop,
    .scale.scale-has-marks-above.scale-has-marks-below.slider:backdrop,
    .scale.vertical.scale-has-marks-above.scale-has-marks-below.slider:backdrop {
      border-style: solid;
      border-radius: 50%;
      border-color: #171a1a;
      background-image: linear-gradient(to bottom, #393f3f);
      box-shadow: none; }
    .scale.slider:backdrop:insensitive,
    .scale.scale-has-marks-above.scale-has-marks-below.slider:backdrop:insensitive,
    .scale.vertical.scale-has-marks-above.scale-has-marks-below.slider:backdrop:insensitive {
      color: #5d6767;
      border-color: #1e2222;
      background-image: linear-gradient(to bottom, #323636);
      text-shadow: none;
      icon-shadow: none;
      box-shadow: inset 0 1px rgba(255, 255, 255, 0), 0 1px rgba(238, 238, 236, 0); }
      .scale.slider:backdrop:insensitive > GtkLabel,
      .scale.scale-has-marks-above.scale-has-marks-below.slider:backdrop:insensitive > GtkLabel,
      .scale.vertical.scale-has-marks-above.scale-has-marks-below.slider:backdrop:insensitive > GtkLabel {
        color: inherit; }
    .scale.slider:active,
    .scale.scale-has-marks-above.scale-has-marks-below.slider:active,
    .scale.vertical.scale-has-marks-above.scale-has-marks-below.slider:active {
      border: 1px solid #14375d; }
    .osd .scale.slider, .osd
    .scale.scale-has-marks-above.scale-has-marks-below.slider, .osd
    .scale.vertical.scale-has-marks-above.scale-has-marks-below.slider {
      color: #eeeeec;
      outline-color: rgba(238, 238, 236, 0.2);
      background-color: transparent;
      background-clip: padding-box;
      background-image: linear-gradient(to bottom, rgba(46, 52, 54, 0.7));
      border-color: rgba(0, 0, 0, 0.7);
      box-shadow: inset 0 -1px rgba(0, 0, 0, 0.3), inset 0 1px rgba(255, 255, 255, 0.1);
      text-shadow: 0 1px black;
      icon-shadow: 0 1px black;
      background-color: #2e3436; }
      .osd .scale.slider:hover, .osd
      .scale.scale-has-marks-above.scale-has-marks-below.slider:hover, .osd
      .scale.vertical.scale-has-marks-above.scale-has-marks-below.slider:hover {
        color: white;
        border-color: rgba(0, 0, 0, 0.7);
        background-image: linear-gradient(to bottom, rgba(74, 84, 87, 0.7));
        box-shadow: inset 0 -1px rgba(0, 0, 0, 0.3), inset 0 1px rgba(255, 255, 255, 0.1);
        text-shadow: 0 1px black;
        icon-shadow: 0 1px black; }
      .osd .scale.slider:active, .osd
      .scale.scale-has-marks-above.scale-has-marks-below.slider:active, .osd
      .scale.vertical.scale-has-marks-above.scale-has-marks-below.slider:active {
        color: white;
        border-color: rgba(0, 0, 0, 0.7);
        background-image: linear-gradient(to bottom, rgba(0, 0, 0, 0.7));
        box-shadow: none;
        text-shadow: none;
        icon-shadow: none; }
      .osd .scale.slider:backdrop, .osd
      .scale.scale-has-marks-above.scale-has-marks-below.slider:backdrop, .osd
      .scale.vertical.scale-has-marks-above.scale-has-marks-below.slider:backdrop {
        color: #eeeeec;
        background-image: linear-gradient(to bottom, rgba(46, 52, 54, 0.7));
        background-clip: padding-box;
        box-shadow: none;
        text-shadow: none;
        icon-shadow: none; }
  .scale.trough,
  .scale.scale-has-marks-above.scale-has-marks-below.trough,
  .scale.vertical.scale-has-marks-above.scale-has-marks-below.trough {
    border: 1px solid #1c1f1f;
    border-radius: 3px;
    background-color: #2d3232;
    box-shadow: inset 1px 1px rgba(0, 0, 0, 0.1), 0 1px rgba(238, 238, 236, 0.1); }
    .scale.trough.highlight,
    .scale.scale-has-marks-above.scale-has-marks-below.trough.highlight,
    .scale.vertical.scale-has-marks-above.scale-has-marks-below.trough.highlight {
      background-image: linear-gradient(to bottom, #215d9c 2px, #266cb5);
      border-color: #0f2b48;
      box-shadow: 0 1px rgba(238, 238, 236, 0.1); }
      .scale.trough.highlight.vertical,
      .scale.scale-has-marks-above.scale-has-marks-below.trough.highlight.vertical,
      .scale.vertical.scale-has-marks-above.scale-has-marks-below.trough.highlight.vertical {
        background-image: linear-gradient(to right, #215d9c 2px, #266cb5); }
      .scale.trough.highlight:backdrop,
      .scale.scale-has-marks-above.scale-has-marks-below.trough.highlight:backdrop,
      .scale.vertical.scale-has-marks-above.scale-has-marks-below.trough.highlight:backdrop {
        border-color: #0f2b48;
        background-color: #215d9c;
        box-shadow: none; }
    .scale.trough:insensitive, .scale.trough.vertical:insensitive,
    .scale.scale-has-marks-above.scale-has-marks-below.trough:insensitive,
    .scale.scale-has-marks-above.scale-has-marks-below.trough.vertical:insensitive,
    .scale.vertical.scale-has-marks-above.scale-has-marks-below.trough:insensitive,
    .scale.vertical.scale-has-marks-above.scale-has-marks-below.trough.vertical:insensitive {
      border-color: #1c1f1f;
      background-image: none;
      background-color: #323636;
      box-shadow: 0 1px rgba(238, 238, 236, 0.1); }
    .scale.trough:backdrop,
    .scale.scale-has-marks-above.scale-has-marks-below.trough:backdrop,
    .scale.vertical.scale-has-marks-above.scale-has-marks-below.trough:backdrop {
      border-color: #1e2222;
      background-color: #2a2f2f;
      box-shadow: none; }
    .scale.trough:backdrop:insensitive, .scale.trough .highlight:backdrop:insensitive,
    .scale.scale-has-marks-above.scale-has-marks-below.trough:backdrop:insensitive,
    .scale.scale-has-marks-above.scale-has-marks-below.trough .highlight:backdrop:insensitive,
    .scale.vertical.scale-has-marks-above.scale-has-marks-below.trough:backdrop:insensitive,
    .scale.vertical.scale-has-marks-above.scale-has-marks-below.trough .highlight:backdrop:insensitive {
      border-color: #1e2222;
      background-color: #323636; }
    .osd .scale.trough, .osd
    .scale.scale-has-marks-above.scale-has-marks-below.trough, .osd
    .scale.vertical.scale-has-marks-above.scale-has-marks-below.trough {
      border-color: rgba(0, 0, 0, 0.7);
      box-shadow: none;
      margin: 9px;
      background-color: rgba(0, 0, 0, 0.5);
      outline-color: rgba(238, 238, 236, 0.2);
      outline-offset: -8px; }
      .osd .scale.trough.fine-tune, .osd
      .scale.scale-has-marks-above.scale-has-marks-below.trough.fine-tune, .osd
      .scale.vertical.scale-has-marks-above.scale-has-marks-below.trough.fine-tune {
        margin: 7px; }
      .osd .scale.trough.highlight, .osd
      .scale.scale-has-marks-above.scale-has-marks-below.trough.highlight, .osd
      .scale.vertical.scale-has-marks-above.scale-has-marks-below.trough.highlight {
        background-image: none;
        background-color: #215d9c; }
      .osd .scale.trough:insensitive, .osd .scale.trough:backdrop:insensitive, .osd
      .scale.scale-has-marks-above.scale-has-marks-below.trough:insensitive, .osd
      .scale.scale-has-marks-above.scale-has-marks-below.trough:backdrop:insensitive, .osd
      .scale.vertical.scale-has-marks-above.scale-has-marks-below.trough:insensitive, .osd
      .scale.vertical.scale-has-marks-above.scale-has-marks-below.trough:backdrop:insensitive {
        border-color: transparent;
        background-color: transparent; }
      .osd .scale.trough:backdrop, .osd
      .scale.scale-has-marks-above.scale-has-marks-below.trough:backdrop, .osd
      .scale.vertical.scale-has-marks-above.scale-has-marks-below.trough:backdrop {
        border-color: rgba(0, 0, 0, 0.7);
        background-image: none; }

.scale.scale-has-marks-below {
  -GtkScale-slider-length: 20;
  -GtkRange-slider-width: 24;
  -GtkRange-trough-border: 2; }
  .scale.scale-has-marks-below.slider {
    border-style: none;
    border-radius: 0;
    background-color: transparent;
    background-image: -gtk-scaled(url("assets/slider-horz-scale-has-marks-below-dark.png"), url("assets/slider-horz-scale-has-marks-below-dark@2.png"));
    background-repeat: no-repeat;
    background-position: center;
    box-shadow: none; }
  .scale.scale-has-marks-below.slider:hover {
    border-style: none;
    border-radius: 0;
    background-color: transparent;
    background-image: -gtk-scaled(url("assets/slider-horz-scale-has-marks-below-hover-dark.png"), url("assets/slider-horz-scale-has-marks-below-hover-dark@2.png"));
    background-repeat: no-repeat;
    background-position: center;
    box-shadow: none; }
  .scale.scale-has-marks-below.slider:active {
    border-style: none;
    border-radius: 0;
    background-color: transparent;
    background-image: -gtk-scaled(url("assets/slider-horz-scale-has-marks-below-active-dark.png"), url("assets/slider-horz-scale-has-marks-below-active-dark@2.png"));
    background-repeat: no-repeat;
    background-position: center;
    box-shadow: none; }
  .scale.scale-has-marks-below.slider:insensitive {
    border-style: none;
    border-radius: 0;
    background-color: transparent;
    background-image: -gtk-scaled(url("assets/slider-horz-scale-has-marks-below-insensitive-dark.png"), url("assets/slider-horz-scale-has-marks-below-insensitive-dark@2.png"));
    background-repeat: no-repeat;
    background-position: center;
    box-shadow: none; }
  .scale.scale-has-marks-below.slider:backdrop {
    border-style: none;
    border-radius: 0;
    background-color: transparent;
    background-image: -gtk-scaled(url("assets/slider-horz-scale-has-marks-below-backdrop-dark.png"), url("assets/slider-horz-scale-has-marks-below-backdrop-dark@2.png"));
    background-repeat: no-repeat;
    background-position: center;
    box-shadow: none; }
  .scale.scale-has-marks-below.slider:backdrop:insensitive {
    border-style: none;
    border-radius: 0;
    background-color: transparent;
    background-image: -gtk-scaled(url("assets/slider-horz-scale-has-marks-below-backdrop-insensitive-dark.png"), url("assets/slider-horz-scale-has-marks-below-backdrop-insensitive-dark@2.png"));
    background-repeat: no-repeat;
    background-position: center;
    box-shadow: none; }

.scale.scale-has-marks-above {
  -GtkScale-slider-length: 20;
  -GtkRange-slider-width: 24;
  -GtkRange-trough-border: 2; }
  .scale.scale-has-marks-above.slider {
    border-style: none;
    border-radius: 0;
    background-color: transparent;
    background-image: -gtk-scaled(url("assets/slider-horz-scale-has-marks-above-dark.png"), url("assets/slider-horz-scale-has-marks-above-dark@2.png"));
    background-repeat: no-repeat;
    background-position: center;
    box-shadow: none; }
  .scale.scale-has-marks-above.slider:hover {
    border-style: none;
    border-radius: 0;
    background-color: transparent;
    background-image: -gtk-scaled(url("assets/slider-horz-scale-has-marks-above-hover-dark.png"), url("assets/slider-horz-scale-has-marks-above-hover-dark@2.png"));
    background-repeat: no-repeat;
    background-position: center;
    box-shadow: none; }
  .scale.scale-has-marks-above.slider:active {
    border-style: none;
    border-radius: 0;
    background-color: transparent;
    background-image: -gtk-scaled(url("assets/slider-horz-scale-has-marks-above-active-dark.png"), url("assets/slider-horz-scale-has-marks-above-active-dark@2.png"));
    background-repeat: no-repeat;
    background-position: center;
    box-shadow: none; }
  .scale.scale-has-marks-above.slider:insensitive {
    border-style: none;
    border-radius: 0;
    background-color: transparent;
    background-image: -gtk-scaled(url("assets/slider-horz-scale-has-marks-above-insensitive-dark.png"), url("assets/slider-horz-scale-has-marks-above-insensitive-dark@2.png"));
    background-repeat: no-repeat;
    background-position: center;
    box-shadow: none; }
  .scale.scale-has-marks-above.slider:backdrop {
    border-style: none;
    border-radius: 0;
    background-color: transparent;
    background-image: -gtk-scaled(url("assets/slider-horz-scale-has-marks-above-backdrop-dark.png"), url("assets/slider-horz-scale-has-marks-above-backdrop-dark@2.png"));
    background-repeat: no-repeat;
    background-position: center;
    box-shadow: none; }
  .scale.scale-has-marks-above.slider:backdrop:insensitive {
    border-style: none;
    border-radius: 0;
    background-color: transparent;
    background-image: -gtk-scaled(url("assets/slider-horz-scale-has-marks-above-backdrop-insensitive-dark.png"), url("assets/slider-horz-scale-has-marks-above-backdrop-insensitive-dark@2.png"));
    background-repeat: no-repeat;
    background-position: center;
    box-shadow: none; }

.scale.vertical.scale-has-marks-below {
  -GtkScale-slider-length: 20;
  -GtkRange-slider-width: 24;
  -GtkRange-trough-border: 2; }
  .scale.vertical.scale-has-marks-below.slider {
    border-style: none;
    border-radius: 0;
    background-color: transparent;
    background-image: -gtk-scaled(url("assets/slider-vert-scale-has-marks-below-dark.png"), url("assets/slider-vert-scale-has-marks-below-dark@2.png"));
    background-repeat: no-repeat;
    background-position: center;
    box-shadow: none; }
  .scale.vertical.scale-has-marks-below.slider:hover {
    border-style: none;
    border-radius: 0;
    background-color: transparent;
    background-image: -gtk-scaled(url("assets/slider-vert-scale-has-marks-below-hover-dark.png"), url("assets/slider-vert-scale-has-marks-below-hover-dark@2.png"));
    background-repeat: no-repeat;
    background-position: center;
    box-shadow: none; }
  .scale.vertical.scale-has-marks-below.slider:active {
    border-style: none;
    border-radius: 0;
    background-color: transparent;
    background-image: -gtk-scaled(url("assets/slider-vert-scale-has-marks-below-active-dark.png"), url("assets/slider-vert-scale-has-marks-below-active-dark@2.png"));
    background-repeat: no-repeat;
    background-position: center;
    box-shadow: none; }
  .scale.vertical.scale-has-marks-below.slider:insensitive {
    border-style: none;
    border-radius: 0;
    background-color: transparent;
    background-image: -gtk-scaled(url("assets/slider-vert-scale-has-marks-below-insensitive-dark.png"), url("assets/slider-vert-scale-has-marks-below-insensitive-dark@2.png"));
    background-repeat: no-repeat;
    background-position: center;
    box-shadow: none; }
  .scale.vertical.scale-has-marks-below.slider:backdrop {
    border-style: none;
    border-radius: 0;
    background-color: transparent;
    background-image: -gtk-scaled(url("assets/slider-vert-scale-has-marks-below-backdrop-dark.png"), url("assets/slider-vert-scale-has-marks-below-backdrop-dark@2.png"));
    background-repeat: no-repeat;
    background-position: center;
    box-shadow: none; }
  .scale.vertical.scale-has-marks-below.slider:backdrop:insensitive {
    border-style: none;
    border-radius: 0;
    background-color: transparent;
    background-image: -gtk-scaled(url("assets/slider-vert-scale-has-marks-below-backdrop-insensitive-dark.png"), url("assets/slider-vert-scale-has-marks-below-backdrop-insensitive-dark@2.png"));
    background-repeat: no-repeat;
    background-position: center;
    box-shadow: none; }

.scale.vertical.scale-has-marks-above {
  -GtkScale-slider-length: 20;
  -GtkRange-slider-width: 24;
  -GtkRange-trough-border: 2; }
  .scale.vertical.scale-has-marks-above.slider {
    border-style: none;
    border-radius: 0;
    background-color: transparent;
    background-image: -gtk-scaled(url("assets/slider-vert-scale-has-marks-above-dark.png"), url("assets/slider-vert-scale-has-marks-above-dark@2.png"));
    background-repeat: no-repeat;
    background-position: center;
    box-shadow: none; }
  .scale.vertical.scale-has-marks-above.slider:hover {
    border-style: none;
    border-radius: 0;
    background-color: transparent;
    background-image: -gtk-scaled(url("assets/slider-vert-scale-has-marks-above-hover-dark.png"), url("assets/slider-vert-scale-has-marks-above-hover-dark@2.png"));
    background-repeat: no-repeat;
    background-position: center;
    box-shadow: none; }
  .scale.vertical.scale-has-marks-above.slider:active {
    border-style: none;
    border-radius: 0;
    background-color: transparent;
    background-image: -gtk-scaled(url("assets/slider-vert-scale-has-marks-above-active-dark.png"), url("assets/slider-vert-scale-has-marks-above-active-dark@2.png"));
    background-repeat: no-repeat;
    background-position: center;
    box-shadow: none; }
  .scale.vertical.scale-has-marks-above.slider:insensitive {
    border-style: none;
    border-radius: 0;
    background-color: transparent;
    background-image: -gtk-scaled(url("assets/slider-vert-scale-has-marks-above-insensitive-dark.png"), url("assets/slider-vert-scale-has-marks-above-insensitive-dark@2.png"));
    background-repeat: no-repeat;
    background-position: center;
    box-shadow: none; }
  .scale.vertical.scale-has-marks-above.slider:backdrop {
    border-style: none;
    border-radius: 0;
    background-color: transparent;
    background-image: -gtk-scaled(url("assets/slider-vert-scale-has-marks-above-backdrop-dark.png"), url("assets/slider-vert-scale-has-marks-above-backdrop-dark@2.png"));
    background-repeat: no-repeat;
    background-position: center;
    box-shadow: none; }
  .scale.vertical.scale-has-marks-above.slider:backdrop:insensitive {
    border-style: none;
    border-radius: 0;
    background-color: transparent;
    background-image: -gtk-scaled(url("assets/slider-vert-scale-has-marks-above-backdrop-insensitive-dark.png"), url("assets/slider-vert-scale-has-marks-above-backdrop-insensitive-dark@2.png"));
    background-repeat: no-repeat;
    background-position: center;
    box-shadow: none; }

.scale.scale-has-marks-above {
  margin: 14px 10px 10px; }
  .fine-tune.scale.scale-has-marks-above {
    margin: 12px 8px 8px; }

.scale.scale-has-marks-below {
  margin: 10px 10px 14px; }
  .fine-tune.scale.scale-has-marks-below {
    margin: 8px 8px 12px; }

.scale.vertical.scale-has-marks-above {
  margin: 10px 10px 10px 14px; }
  .fine-tune.scale.vertical.scale-has-marks-above {
    margin: 8px 8px 8px 12px; }

.scale.vertical.scale-has-marks-below {
  margin: 10px 14px 10px 10px; }
  .fine-tune.scale.vertical.scale-has-marks-below {
    margin: 8px 12px 8px 8px; }

/*****************
 * Progress bars *
 *****************/
GtkProgressBar {
  padding: 0;
  font-size: smaller;
  color: rgba(238, 238, 236, 0.4);
  box-shadow: inset 1px 1px rgba(0, 0, 0, 0.1), 0 1px rgba(238, 238, 236, 0.1); }
  GtkProgressBar:backdrop {
    color: #5d6767; }
  GtkProgressBar.osd {
    -GtkProgressBar-xspacing: 0;
    -GtkProgressBar-yspacing: 0;
    -GtkProgressBar-min-horizontal-bar-height: 3; }

.progressbar {
  background-image: linear-gradient(to bottom, #215d9c 2px, #266cb5);
  border: 1px solid #0f2b48;
  border-radius: 1.5px;
  box-shadow: none; }
  .progressbar.left {
    border-top-left-radius: 3px;
    border-bottom-left-radius: 3px; }
  .progressbar.right {
    border-top-right-radius: 3px;
    border-bottom-right-radius: 3px; }
  .progressbar.left.right {
    box-shadow: none; }
  .progressbar.vertical {
    background-image: linear-gradient(to right, #215d9c 2px, #266cb5); }
    .progressbar.vertical.bottom {
      border-bottom-left-radius: 3px;
      border-bottom-right-radius: 3px;
      box-shadow: none; }
    .progressbar.vertical.top {
      border-top-left-radius: 3px;
      border-top-right-radius: 3px; }
  .progressbar:backdrop {
    border-color: #0f2b48;
    background-image: none;
    background-color: #215d9c;
    box-shadow: none; }
  .progressbar.osd {
    background-image: none;
    background-color: #215d9c;
    border-style: none;
    border-radius: 0; }

GtkProgressBar.trough {
  border: 1px solid #1c1f1f;
  border-radius: 3px;
  background-color: #2e3333; }
  GtkProgressBar.trough:backdrop {
    border-color: #1e2222;
    background-color: #2f3434;
    box-shadow: 0 1px rgba(255, 255, 255, 0); }
  GtkProgressBar.trough.osd {
    border-style: none;
    background-color: transparent;
    box-shadow: none; }

/*************
 * Level Bar *
 *************/
GtkLevelBar {
  -GtkLevelBar-min-block-width: 34;
  -GtkLevelBar-min-block-height: 3;
  box-shadow: 0 1px rgba(238, 238, 236, 0.1); }

GtkLevelBar.vertical {
  -GtkLevelBar-min-block-width: 3;
  -GtkLevelBar-min-block-height: 34; }

.level-bar.trough {
  border: 1px solid;
  padding: 2px;
  border-radius: 3px;
  background-color: transparent;
  background-image: linear-gradient(to bottom, #212121, #292929 90%);
  border-color: #1c1f1f;
  box-shadow: inset 0 3px rgba(0, 0, 0, 0.02), inset 0 2px rgba(0, 0, 0, 0.03), inset 0 1px rgba(0, 0, 0, 0.08), inset 0 0 0 1px rgba(33, 93, 156, 0), 0 1px rgba(238, 238, 236, 0.1); }
  .level-bar.trough:backdrop {
    background-color: transparent;
    background-image: linear-gradient(to bottom, #212121, #292929 90%);
    color: #c9cbc9;
    border-color: #1e2222;
    background-image: linear-gradient(to bottom, #2c2c2c);
    box-shadow: inset 0 3px transparent, inset 0 2px transparent, inset 0 1px transparent, 0 1px rgba(238, 238, 236, 0); }
.level-bar.fill-block {
  border: 1px solid #1c5187;
  background-color: #215d9c;
  box-shadow: 0 1px rgba(0, 0, 0, 0.1);
  border-radius: 1px; }
  .level-bar.fill-block:backdrop {
    border-color: #215d9c;
    box-shadow: none; }
  .level-bar.fill-block.indicator-discrete.horizontal {
    margin: 0 1px; }
  .level-bar.fill-block.indicator-discrete.vertical {
    margin: 1px 0; }
  .level-bar.fill-block.level-high {
    border-color: #40760c;
    background-color: #5aa411; }
    .level-bar.fill-block.level-high:backdrop {
      border-color: #5aa411; }
  .level-bar.fill-block.level-low {
    border-color: #c26000;
    background-color: #f57900; }
    .level-bar.fill-block.level-low:backdrop {
      border-color: #f57900; }
  .level-bar.fill-block.empty-fill-block {
    background-color: transparent;
    border-color: rgba(238, 238, 236, 0.1);
    box-shadow: none; }
    .level-bar.fill-block.empty-fill-block:backdrop {
      border-color: rgba(201, 203, 201, 0.15); }

/**********
 * Frames *
 **********/
.frame {
  border: 1px solid #1c1f1f;
  padding: 0; }
  .frame.flat {
    border-style: none; }
  .frame:backdrop {
    border-color: #1e2222; }
  .frame.action-bar {
    padding: 6px;
    border-width: 1px 0 0; }

GtkScrolledWindow .frame {
  border-radius: 2px; }
GtkScrolledWindow GtkViewport.frame {
  border-style: none; }

.separator, .sidebar .separator:backdrop,
.sidebar .view .separator:backdrop {
  color: rgba(0, 0, 0, 0.1); }
  GtkFileChooserButton .separator, GtkFileChooserButton .sidebar .separator:backdrop, .sidebar GtkFileChooserButton .separator:backdrop,
  GtkFileChooserButton .sidebar .view .separator:backdrop,
  .sidebar .view GtkFileChooserButton .separator:backdrop, GtkFontButton .separator, GtkFontButton .sidebar .separator:backdrop, .sidebar GtkFontButton .separator:backdrop,
  GtkFontButton .sidebar .view .separator:backdrop,
  .sidebar .view GtkFontButton .separator:backdrop {
    -GtkWidget-wide-separators: true;
    -GtkWidget-horizontal-separator: 0;
    -GtkWidget-vertical-separator: 0; }

/*********
 * Lists *
 *********/
.list, .list-row {
  background-color: #292929;
  border-color: #1c1f1f; }
  .list:backdrop, .list-row:backdrop {
    background-color: #2c2c2c;
    border-color: #1e2222; }

.list-row,
.grid-child {
  padding: 2px; }

.list-row.button, .header-bar .list-row.button.titlebutton,
.titlebar .list-row.button.titlebutton,
GtkCalendar.header .list-row.button.titlebutton {
  background-color: rgba(41, 41, 41, 0);
  border-style: none;
  border-radius: 0;
  box-shadow: none; }
  .list-row.button:hover {
    background-color: #262626; }
  .list-row.button:active {
    box-shadow: inset 0 2px 2px -2px rgba(0, 0, 0, 0.2); }
  .list-row.button:selected:active {
    box-shadow: inset 0 2px 3px -1px rgba(0, 0, 0, 0.5); }
  .list-row.button:selected:hover {
    background-color: #1d538c; }
  .list-row.button:selected:backdrop {
    background-color: #215d9c; }

.list-row:selected .button {
  color: #eeeeec;
  outline-color: rgba(238, 238, 236, 0.3);
  border-color: #1c1f1f;
  background-image: linear-gradient(to bottom, #454c4c, #393f3f 40%, #2d3232);
  text-shadow: 0 -1px rgba(0, 0, 0, 0.81176);
  icon-shadow: 0 -1px rgba(0, 0, 0, 0.81176);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); }
  .list-row:selected .button.flat, .list-row:selected .header-bar .titlebutton.button, .header-bar .list-row:selected .titlebutton.button,
  .list-row:selected .titlebar .titlebutton.button,
  .titlebar .list-row:selected .titlebutton.button,
  .list-row:selected GtkCalendar.header .titlebutton.button,
  GtkCalendar.header .list-row:selected .titlebutton.button {
    border-color: transparent;
    background-color: transparent;
    background-image: none;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0);
    text-shadow: none;
    icon-shadow: none;
    color: #ffffff; }
  .list-row:selected .button:hover {
    color: #eeeeec;
    outline-color: rgba(238, 238, 236, 0.3);
    border-color: #1c1f1f;
    background-image: linear-gradient(to bottom, #5b6464, #434a4a 40%, #393f3f);
    text-shadow: 0 -1px rgba(0, 0, 0, 0.77976);
    icon-shadow: 0 -1px rgba(0, 0, 0, 0.77976);
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); }
  .list-row:selected .button:active, .list-row:selected .button:checked {
    color: #eeeeec;
    outline-color: rgba(238, 238, 236, 0.3);
    border-color: #1c1f1f;
    background-image: linear-gradient(to bottom, #232727, #2d3232);
    text-shadow: 0 -1px rgba(0, 0, 0, 0.89176);
    icon-shadow: 0 -1px rgba(0, 0, 0, 0.89176);
    box-shadow: inset 0 1px rgba(0, 0, 0, 0.07), inset 0 2px 1px -2px rgba(0, 0, 0, 0.6); }
  .list-row:selected .button:backdrop, .list-row:selected .button.flat:backdrop, .list-row:selected .header-bar .titlebutton.button:backdrop, .header-bar .list-row:selected .titlebutton.button:backdrop,
  .list-row:selected .titlebar .titlebutton.button:backdrop,
  .titlebar .list-row:selected .titlebutton.button:backdrop,
  .list-row:selected GtkCalendar.header .titlebutton.button:backdrop,
  GtkCalendar.header .list-row:selected .titlebutton.button:backdrop {
    color: #c9cbc9;
    border-color: #1e2222;
    background-image: linear-gradient(to bottom, #393f3f);
    text-shadow: none;
    icon-shadow: none;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0); }
    .list-row:selected .button:backdrop:active, .list-row:selected .button:backdrop:checked, .list-row:selected .button.flat:backdrop:active, .list-row:selected .header-bar .titlebutton.button:backdrop:active, .header-bar .list-row:selected .titlebutton.button:backdrop:active,
    .list-row:selected .titlebar .titlebutton.button:backdrop:active,
    .titlebar .list-row:selected .titlebutton.button:backdrop:active,
    .list-row:selected GtkCalendar.header .titlebutton.button:backdrop:active,
    GtkCalendar.header .list-row:selected .titlebutton.button:backdrop:active, .list-row:selected .button.flat:backdrop:checked, .list-row:selected .header-bar .titlebutton.button:backdrop:checked, .header-bar .list-row:selected .titlebutton.button:backdrop:checked,
    .list-row:selected .titlebar .titlebutton.button:backdrop:checked,
    .titlebar .list-row:selected .titlebutton.button:backdrop:checked,
    .list-row:selected GtkCalendar.header .titlebutton.button:backdrop:checked,
    GtkCalendar.header .list-row:selected .titlebutton.button:backdrop:checked {
      color: #c9cbc9;
      border-color: #1e2222;
      background-image: linear-gradient(to bottom, #2f3434);
      box-shadow: inset 0 1px rgba(255, 255, 255, 0); }
    .list-row:selected .button:backdrop:insensitive, .list-row:selected .button.flat:backdrop:insensitive, .list-row:selected .header-bar .titlebutton.button:backdrop:insensitive, .header-bar .list-row:selected .titlebutton.button:backdrop:insensitive,
    .list-row:selected .titlebar .titlebutton.button:backdrop:insensitive,
    .titlebar .list-row:selected .titlebutton.button:backdrop:insensitive,
    .list-row:selected GtkCalendar.header .titlebutton.button:backdrop:insensitive,
    GtkCalendar.header .list-row:selected .titlebutton.button:backdrop:insensitive {
      color: #5d6767;
      border-color: #1e2222;
      background-image: linear-gradient(to bottom, #323636);
      text-shadow: none;
      icon-shadow: none;
      box-shadow: inset 0 1px rgba(255, 255, 255, 0); }
      .list-row:selected .button:backdrop:insensitive > GtkLabel, .list-row:selected .button.flat:backdrop:insensitive > GtkLabel, .list-row:selected .header-bar .titlebutton.button:backdrop:insensitive > GtkLabel, .header-bar .list-row:selected .titlebutton.button:backdrop:insensitive > GtkLabel,
      .list-row:selected .titlebar .titlebutton.button:backdrop:insensitive > GtkLabel,
      .titlebar .list-row:selected .titlebutton.button:backdrop:insensitive > GtkLabel,
      .list-row:selected GtkCalendar.header .titlebutton.button:backdrop:insensitive > GtkLabel,
      GtkCalendar.header .list-row:selected .titlebutton.button:backdrop:insensitive > GtkLabel {
        color: inherit; }
      .list-row:selected .button:backdrop:insensitive:active, .list-row:selected .button:backdrop:insensitive:checked, .list-row:selected .button.flat:backdrop:insensitive:active, .list-row:selected .header-bar .titlebutton.button:backdrop:insensitive:active, .header-bar .list-row:selected .titlebutton.button:backdrop:insensitive:active,
      .list-row:selected .titlebar .titlebutton.button:backdrop:insensitive:active,
      .titlebar .list-row:selected .titlebutton.button:backdrop:insensitive:active,
      .list-row:selected GtkCalendar.header .titlebutton.button:backdrop:insensitive:active,
      GtkCalendar.header .list-row:selected .titlebutton.button:backdrop:insensitive:active, .list-row:selected .button.flat:backdrop:insensitive:checked, .list-row:selected .header-bar .titlebutton.button:backdrop:insensitive:checked, .header-bar .list-row:selected .titlebutton.button:backdrop:insensitive:checked,
      .list-row:selected .titlebar .titlebutton.button:backdrop:insensitive:checked,
      .titlebar .list-row:selected .titlebutton.button:backdrop:insensitive:checked,
      .list-row:selected GtkCalendar.header .titlebutton.button:backdrop:insensitive:checked,
      GtkCalendar.header .list-row:selected .titlebutton.button:backdrop:insensitive:checked {
        color: #5d6767;
        border-color: #1e2222;
        background-image: linear-gradient(to bottom, #262929);
        box-shadow: inset 0 1px rgba(255, 255, 255, 0); }
        .list-row:selected .button:backdrop:insensitive:active > GtkLabel, .list-row:selected .button:backdrop:insensitive:checked > GtkLabel, .list-row:selected .button.flat:backdrop:insensitive:active > GtkLabel, .list-row:selected .header-bar .titlebutton.button:backdrop:insensitive:active > GtkLabel, .header-bar .list-row:selected .titlebutton.button:backdrop:insensitive:active > GtkLabel,
        .list-row:selected .titlebar .titlebutton.button:backdrop:insensitive:active > GtkLabel,
        .titlebar .list-row:selected .titlebutton.button:backdrop:insensitive:active > GtkLabel,
        .list-row:selected GtkCalendar.header .titlebutton.button:backdrop:insensitive:active > GtkLabel,
        GtkCalendar.header .list-row:selected .titlebutton.button:backdrop:insensitive:active > GtkLabel, .list-row:selected .button.flat:backdrop:insensitive:checked > GtkLabel, .list-row:selected .header-bar .titlebutton.button:backdrop:insensitive:checked > GtkLabel, .header-bar .list-row:selected .titlebutton.button:backdrop:insensitive:checked > GtkLabel,
        .list-row:selected .titlebar .titlebutton.button:backdrop:insensitive:checked > GtkLabel,
        .titlebar .list-row:selected .titlebutton.button:backdrop:insensitive:checked > GtkLabel,
        .list-row:selected GtkCalendar.header .titlebutton.button:backdrop:insensitive:checked > GtkLabel,
        GtkCalendar.header .list-row:selected .titlebutton.button:backdrop:insensitive:checked > GtkLabel {
          color: inherit; }
  .list-row:selected .button.flat:backdrop, .list-row:selected .header-bar .titlebutton.button:backdrop, .header-bar .list-row:selected .titlebutton.button:backdrop,
  .list-row:selected .titlebar .titlebutton.button:backdrop,
  .titlebar .list-row:selected .titlebutton.button:backdrop,
  .list-row:selected GtkCalendar.header .titlebutton.button:backdrop,
  GtkCalendar.header .list-row:selected .titlebutton.button:backdrop {
    border-color: transparent;
    background-color: transparent;
    background-image: none;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0), 0 1px rgba(238, 238, 236, 0);
    text-shadow: none;
    icon-shadow: none;
    color: #c9cbc9; }
  .list-row:selected .button:insensitive {
    color: #939695;
    border-color: #1c1f1f;
    background-image: linear-gradient(to bottom, #323636);
    text-shadow: none;
    icon-shadow: none;
    box-shadow: inset 0 1px rgba(255, 255, 255, 0); }
    .list-row:selected .button:insensitive > GtkLabel {
      color: inherit; }
    .list-row:selected .button:insensitive:active, .list-row:selected .button:insensitive:checked {
      color: #939695;
      border-color: #1c1f1f;
      background-image: linear-gradient(to bottom, #2f3333, #323636);
      box-shadow: inset 0 1px rgba(255, 255, 255, 0); }
      .list-row:selected .button:insensitive:active > GtkLabel, .list-row:selected .button:insensitive:checked > GtkLabel {
        color: inherit; }

/*********************
 * App Notifications *
 *********************/
.app-notification,
.app-notification.frame {
  padding: 10px;
  border-width: 0 1px 1px;
  border-style: solid;
  border-color: rgba(255, 255, 255, 0.1);
  border-radius: 0 0 6px 6px;
  background-color: rgba(46, 52, 54, 0.7);
  background-image: linear-gradient(to bottom, rgba(0, 0, 0, 0.2), transparent 2px);
  background-clip: padding-box; }
  .app-notification:backdrop,
  .app-notification.frame:backdrop {
    background-image: none; }
  .app-notification .button, .app-notification .header-bar .button.titlebutton, .header-bar .app-notification .button.titlebutton,
  .app-notification .titlebar .button.titlebutton,
  .titlebar .app-notification .button.titlebutton,
  .app-notification GtkCalendar.header .button.titlebutton,
  GtkCalendar.header .app-notification .button.titlebutton,
  .app-notification.frame .button {
    border: 1px solid;
    color: #eeeeec;
    outline-color: rgba(238, 238, 236, 0.2);
    color: #eeeeec;
    outline-color: rgba(238, 238, 236, 0.2);
    background-color: transparent;
    background-clip: padding-box;
    background-image: linear-gradient(to bottom, rgba(46, 52, 54, 0.7));
    border-color: rgba(0, 0, 0, 0.7);
    box-shadow: inset 0 -1px rgba(0, 0, 0, 0.3), inset 0 1px rgba(255, 255, 255, 0.1);
    text-shadow: 0 1px black;
    icon-shadow: 0 1px black; }
    .app-notification .button.flat, .app-notification .header-bar .titlebutton.button, .header-bar .app-notification .titlebutton.button,
    .app-notification .titlebar .titlebutton.button,
    .titlebar .app-notification .titlebutton.button,
    .app-notification GtkCalendar.header .titlebutton.button,
    GtkCalendar.header .app-notification .titlebutton.button,
    .app-notification.frame .button.flat,
    .app-notification.frame .header-bar .titlebutton.button,
    .header-bar .app-notification.frame .titlebutton.button,
    .app-notification.frame .titlebar .titlebutton.button,
    .titlebar .app-notification.frame .titlebutton.button,
    .app-notification.frame GtkCalendar.header .titlebutton.button,
    GtkCalendar.header .app-notification.frame .titlebutton.button {
      icon-shadow: 0 1px black;
      text-shadow: 0 1px black; }
    .app-notification .button:hover,
    .app-notification.frame .button:hover {
      color: white;
      border-color: rgba(0, 0, 0, 0.7);
      background-image: linear-gradient(to bottom, rgba(74, 84, 87, 0.7));
      box-shadow: inset 0 -1px rgba(0, 0, 0, 0.3), inset 0 1px rgba(255, 255, 255, 0.1);
      text-shadow: 0 1px black;
      icon-shadow: 0 1px black; }
    .app-notification .button:active, .app-notification .button:checked, .app-notification .button:backdrop:active, .app-notification .button:backdrop:checked,
    .app-notification.frame .button:active,
    .app-notification.frame .button:checked,
    .app-notification.frame .button:backdrop:active,
    .app-notification.frame .button:backdrop:checked {
      color: white;
      border-color: rgba(0, 0, 0, 0.7);
      background-image: linear-gradient(to bottom, rgba(0, 0, 0, 0.7));
      box-shadow: none;
      text-shadow: none;
      icon-shadow: none; }
    .app-notification .button:insensitive, .app-notification .button:backdrop:insensitive,
    .app-notification.frame .button:insensitive,
    .app-notification.frame .button:backdrop:insensitive {
      color: #939695;
      border-color: rgba(0, 0, 0, 0.7);
      background-image: linear-gradient(to bottom, rgba(66, 71, 73, 0.7));
      box-shadow: none;
      text-shadow: none;
      icon-shadow: none; }
    .app-notification .button:backdrop,
    .app-notification.frame .button:backdrop {
      color: #eeeeec;
      background-image: linear-gradient(to bottom, rgba(46, 52, 54, 0.7));
      background-clip: padding-box;
      box-shadow: none;
      text-shadow: none;
      icon-shadow: none; }

/*************
 * Expanders *
 *************/
GtkExpander {
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic"); }
  GtkExpander:dir(rtl) {
    -gtk-icon-source: -gtk-icontheme("pan-end-symbolic-rtl"); }
  GtkExpander:hover {
    color: white; }
  GtkExpander:checked {
    -gtk-icon-source: -gtk-icontheme("pan-down-symbolic"); }

/************
 * Calendar *
 ***********/
GtkCalendar {
  border: 1px solid #1c1f1f; }
  GtkCalendar:selected {
    background-color: #215d9c;
    color: #ffffff;
    border-radius: 3px; }
    GtkCalendar:selected:backdrop {
      color: #c9cbc9; }
  GtkCalendar.header {
    box-shadow: inset 0 -1px #303535, inset 0px 1px rgba(238, 238, 236, 0.1), 0 1px 2px rgba(0, 0, 0, 0.1);
    border: 1px solid #1c1f1f;
    border-radius: 0; }
    GtkCalendar.header:backdrop {
      box-shadow: none; }
  GtkCalendar.button, .header-bar GtkCalendar.button.titlebutton,
  .titlebar GtkCalendar.button.titlebutton,
  GtkCalendar.header GtkCalendar.button.titlebutton {
    color: rgba(238, 238, 236, 0.45); }
    GtkCalendar.button:hover, .header-bar GtkCalendar.button.titlebutton:hover,
    .titlebar GtkCalendar.button.titlebutton:hover,
    GtkCalendar.header GtkCalendar.button.titlebutton:hover {
      color: #eeeeec; }
    GtkCalendar.button:backdrop, .header-bar GtkCalendar.button.titlebutton:backdrop,
    .titlebar GtkCalendar.button.titlebutton:backdrop,
    GtkCalendar.header GtkCalendar.button.titlebutton:backdrop {
      color: rgba(201, 203, 201, 0.45); }
  GtkCalendar.highlight {
    color: alpha(currentColor,0.55); }
  GtkCalendar:backdrop {
    border-color: #1e2222; }

/***********
 * Dialogs *
 ***********/
.message-dialog .dialog-action-area .button {
  padding: 8px; }

.message-dialog {
  -GtkDialog-button-spacing: 0; }
  .message-dialog .titlebar, .message-dialog GtkCalendar.header {
    border-style: none;
    box-shadow: inset 0 1px rgba(238, 238, 236, 0.1); }
  .message-dialog.csd.background {
    border-bottom-left-radius: 9px;
    border-bottom-right-radius: 9px; }
  .message-dialog.csd .dialog-action-area .button {
    padding: 12px;
    border-radius: 0;
    color: #eeeeec;
    outline-color: rgba(238, 238, 236, 0.3);
    border-color: #1c1f1f;
    background-image: linear-gradient(to bottom, #454c4c, #393f3f 40%, #2d3232);
    text-shadow: 0 -1px rgba(0, 0, 0, 0.81176);
    icon-shadow: 0 -1px rgba(0, 0, 0, 0.81176);
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); }
    .message-dialog.csd .dialog-action-area .button:hover {
      color: #eeeeec;
      outline-color: rgba(238, 238, 236, 0.3);
      border-color: #1c1f1f;
      background-image: linear-gradient(to bottom, #5b6464, #434a4a 40%, #393f3f);
      text-shadow: 0 -1px rgba(0, 0, 0, 0.77976);
      icon-shadow: 0 -1px rgba(0, 0, 0, 0.77976);
      box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); }
    .message-dialog.csd .dialog-action-area .button:active {
      color: #eeeeec;
      outline-color: rgba(238, 238, 236, 0.3);
      border-color: #1c1f1f;
      background-image: linear-gradient(to bottom, #232727, #2d3232);
      text-shadow: 0 -1px rgba(0, 0, 0, 0.89176);
      icon-shadow: 0 -1px rgba(0, 0, 0, 0.89176);
      box-shadow: inset 0 1px rgba(0, 0, 0, 0.07), inset 0 2px 1px -2px rgba(0, 0, 0, 0.6); }
    .message-dialog.csd .dialog-action-area .button:insensitive {
      color: #939695;
      border-color: #1c1f1f;
      background-image: linear-gradient(to bottom, #323636);
      text-shadow: none;
      icon-shadow: none;
      box-shadow: inset 0 1px rgba(255, 255, 255, 0); }
      .message-dialog.csd .dialog-action-area .button:insensitive > GtkLabel {
        color: inherit; }
    .message-dialog.csd .dialog-action-area .button:backdrop {
      color: #c9cbc9;
      border-color: #1e2222;
      background-image: linear-gradient(to bottom, #393f3f);
      text-shadow: none;
      icon-shadow: none;
      box-shadow: inset 0 1px rgba(255, 255, 255, 0); }
    .message-dialog.csd .dialog-action-area .button:backdrop:insensitive {
      color: #5d6767;
      border-color: #1e2222;
      background-image: linear-gradient(to bottom, #323636);
      text-shadow: none;
      icon-shadow: none;
      box-shadow: inset 0 1px rgba(255, 255, 255, 0); }
      .message-dialog.csd .dialog-action-area .button:backdrop:insensitive > GtkLabel {
        color: inherit; }
    .message-dialog.csd .dialog-action-area .button.suggested-action {
      color: white;
      outline-color: rgba(255, 255, 255, 0.3);
      border-color: #0b1e33;
      background-image: linear-gradient(to bottom, #256ab1, #215d9c 40%, #1c5187);
      text-shadow: 0 -1px rgba(0, 0, 0, 0.70353);
      icon-shadow: 0 -1px rgba(0, 0, 0, 0.70353);
      box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); }
      .message-dialog.csd .dialog-action-area .button.suggested-action:hover {
        color: white;
        outline-color: rgba(255, 255, 255, 0.3);
        border-color: #0b1e33;
        background-image: linear-gradient(to bottom, #3180d4, #2467ad 40%, #215d9c);
        text-shadow: 0 -1px rgba(0, 0, 0, 0.67153);
        icon-shadow: 0 -1px rgba(0, 0, 0, 0.67153);
        box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); }
      .message-dialog.csd .dialog-action-area .button.suggested-action:active {
        color: white;
        outline-color: rgba(255, 255, 255, 0.3);
        border-color: #0b1e33;
        background-image: linear-gradient(to bottom, #194776, #1c5187);
        text-shadow: 0 -1px rgba(0, 0, 0, 0.78353);
        icon-shadow: 0 -1px rgba(0, 0, 0, 0.78353);
        box-shadow: inset 0 1px rgba(0, 0, 0, 0.07), inset 0 2px 1px -2px rgba(0, 0, 0, 0.6); }
      .message-dialog.csd .dialog-action-area .button.suggested-action:backdrop {
        color: #d2deeb;
        border-color: #0b1e33;
        background-image: linear-gradient(to bottom, #215d9c);
        text-shadow: none;
        icon-shadow: none;
        box-shadow: inset 0 1px rgba(255, 255, 255, 0); }
        .message-dialog.csd .dialog-action-area .button.suggested-action:backdrop:insensitive {
          color: #5d6767;
          border-color: #1e2222;
          background-image: linear-gradient(to bottom, #323636);
          text-shadow: none;
          icon-shadow: none;
          box-shadow: inset 0 1px rgba(255, 255, 255, 0); }
          .message-dialog.csd .dialog-action-area .button.suggested-action:backdrop:insensitive > GtkLabel {
            color: inherit; }
      .message-dialog.csd .dialog-action-area .button.suggested-action:insensitive {
        color: #939695;
        border-color: #1c1f1f;
        background-image: linear-gradient(to bottom, #323636);
        text-shadow: none;
        icon-shadow: none;
        box-shadow: inset 0 1px rgba(255, 255, 255, 0); }
        .message-dialog.csd .dialog-action-area .button.suggested-action:insensitive > GtkLabel {
          color: inherit; }
    .message-dialog.csd .dialog-action-area .button.destructive-action {
      color: white;
      outline-color: rgba(255, 255, 255, 0.3);
      border-color: #5e0707;
      background-image: linear-gradient(to bottom, #ed1212, #d51010 40%, #bd0e0e);
      text-shadow: 0 -1px rgba(0, 0, 0, 0.64078);
      icon-shadow: 0 -1px rgba(0, 0, 0, 0.64078);
      box-shadow: inset 0 1px rgba(255, 255, 255, 0.3); }
      .message-dialog.csd .dialog-action-area .button.destructive-action:hover {
        color: white;
        outline-color: rgba(255, 255, 255, 0.3);
        border-color: #5e0707;
        background-image: linear-gradient(to bottom, #f03c3c, #e81111 40%, #d51010);
        text-shadow: 0 -1px rgba(0, 0, 0, 0.60878);
        icon-shadow: 0 -1px rgba(0, 0, 0, 0.60878);
        box-shadow: inset 0 1px rgba(255, 255, 255, 0.3); }
      .message-dialog.csd .dialog-action-area .button.destructive-action:active {
        color: white;
        outline-color: rgba(255, 255, 255, 0.3);
        border-color: #5e0707;
        background-image: linear-gradient(to bottom, #aa0d0d, #bd0e0e);
        text-shadow: 0 -1px rgba(0, 0, 0, 0.72078);
        icon-shadow: 0 -1px rgba(0, 0, 0, 0.72078);
        box-shadow: inset 0 1px rgba(0, 0, 0, 0.07), inset 0 2px 1px -2px rgba(0, 0, 0, 0.6); }
      .message-dialog.csd .dialog-action-area .button.destructive-action:backdrop {
        color: #f6cfcf;
        border-color: #5e0707;
        background-image: linear-gradient(to bottom, #d51010);
        text-shadow: none;
        icon-shadow: none;
        box-shadow: inset 0 1px rgba(255, 255, 255, 0); }
        .message-dialog.csd .dialog-action-area .button.destructive-action:backdrop:insensitive {
          color: #5d6767;
          border-color: #1e2222;
          background-image: linear-gradient(to bottom, #323636);
          text-shadow: none;
          icon-shadow: none;
          box-shadow: inset 0 1px rgba(255, 255, 255, 0); }
          .message-dialog.csd .dialog-action-area .button.destructive-action:backdrop:insensitive > GtkLabel {
            color: inherit; }
      .message-dialog.csd .dialog-action-area .button.destructive-action:insensitive {
        color: #939695;
        border-color: #1c1f1f;
        background-image: linear-gradient(to bottom, #323636);
        text-shadow: none;
        icon-shadow: none;
        box-shadow: inset 0 1px rgba(255, 255, 255, 0); }
        .message-dialog.csd .dialog-action-area .button.destructive-action:insensitive > GtkLabel {
          color: inherit; }
  .message-dialog.csd .dialog-action-area .button, .message-dialog.csd .dialog-action-area .button:hover, .message-dialog.csd .dialog-action-area .button:active, .message-dialog.csd .dialog-action-area .button:insensitive, .message-dialog.csd .dialog-action-area .button:backdrop, .message-dialog.csd .dialog-action-area .button:backdrop:insensitive, .message-dialog.csd .dialog-action-area .button.suggested-action, .message-dialog.csd .dialog-action-area .button.suggested-action:hover, .message-dialog.csd .dialog-action-area .button.suggested-action:active, .message-dialog.csd .dialog-action-area .button.suggested-action:backdrop, .message-dialog.csd .dialog-action-area .button.suggested-action:backdrop:insensitive, .message-dialog.csd .dialog-action-area .button.suggested-action:insensitive, .message-dialog.csd .dialog-action-area .button.destructive-action, .message-dialog.csd .dialog-action-area .button.destructive-action:hover, .message-dialog.csd .dialog-action-area .button.destructive-action:active, .message-dialog.csd .dialog-action-area .button.destructive-action:backdrop, .message-dialog.csd .dialog-action-area .button.destructive-action:backdrop:insensitive, .message-dialog.csd .dialog-action-area .button.destructive-action:insensitive {
    border-left-style: solid;
    border-right-style: none;
    border-bottom-style: none; }
  .message-dialog.csd .dialog-action-area .button:last-child {
    border-bottom-right-radius: 7px; }
  .message-dialog.csd .dialog-action-area .button:first-child {
    border-left-style: none;
    border-bottom-left-radius: 7px; }

GtkFileChooserDialog .search-bar {
  background-color: #292929;
  border-color: #393f3f;
  box-shadow: none; }
  GtkFileChooserDialog .search-bar:backdrop {
    background-color: #2c2c2c;
    border-color: #393f3f; }
GtkFileChooserDialog .dialog-action-box {
  border-top: 1px solid #1c1f1f; }
  GtkFileChooserDialog .dialog-action-box:backdrop {
    border-top-color: #1e2222; }

/***********
 * Sidebar *
 ***********/
.sidebar,
.sidebar .view {
  border: none;
  background-color: #454c4c; }
  .sidebar .scrollbar.trough,
  .sidebar .view .scrollbar.trough {
    background-color: #212424;
    border-radius: 6px;
    border-width: 2px;
    border-color: transparent; }
  .sidebar .scrollbar.slider,
  .sidebar .view .scrollbar.slider {
    background-color: #454c4c; }
    .sidebar .scrollbar.slider:hover,
    .sidebar .view .scrollbar.slider:hover {
      background-color: #515a5a; }
  .sidebar:backdrop,
  .sidebar .view:backdrop {
    background-color: #454c4c; }
  .sidebar:selected,
  .sidebar .view:selected {
    background-color: #215d9c; }

GtkPaned {
  margin: 0 8px 8px 0; }
  GtkPaned:dir(rtl) {
    margin-right: 0;
    margin-left: 8px; }

.pane-separator {
  background-image: linear-gradient(to bottom, #1c1f1f); }
  .pane-separator:backdrop {
    background-image: linear-gradient(to bottom, #1e2222); }

/**************
 * GtkInfoBar *
 **************/
GtkInfoBar {
  border-style: none; }

.info,
.question,
.warning,
.error {
  background-color: #215d9c;
  color: #ffffff;
  text-shadow: 0 1px #184472;
  border-color: #184472; }
  .info .button, .info .header-bar .button.titlebutton, .header-bar .info .button.titlebutton,
  .info .titlebar .button.titlebutton,
  .titlebar .info .button.titlebutton,
  .info GtkCalendar.header .button.titlebutton,
  GtkCalendar.header .info .button.titlebutton,
  .question .button,
  .question .header-bar .button.titlebutton,
  .header-bar .question .button.titlebutton,
  .question .titlebar .button.titlebutton,
  .titlebar .question .button.titlebutton,
  .question GtkCalendar.header .button.titlebutton,
  GtkCalendar.header .question .button.titlebutton,
  .warning .button,
  .warning .header-bar .button.titlebutton,
  .header-bar .warning .button.titlebutton,
  .warning .titlebar .button.titlebutton,
  .titlebar .warning .button.titlebutton,
  .warning GtkCalendar.header .button.titlebutton,
  GtkCalendar.header .warning .button.titlebutton,
  .error .button,
  .error .header-bar .button.titlebutton,
  .header-bar .error .button.titlebutton,
  .error .titlebar .button.titlebutton,
  .titlebar .error .button.titlebutton,
  .error GtkCalendar.header .button.titlebutton,
  GtkCalendar.header .error .button.titlebutton {
    color: #ffffff;
    outline-color: rgba(255, 255, 255, 0.3);
    border-color: #0b1e33;
    background-image: linear-gradient(to bottom, #256ab1, #215d9c 40%, #1c5187);
    text-shadow: 0 -1px rgba(0, 0, 0, 0.70353);
    icon-shadow: 0 -1px rgba(0, 0, 0, 0.70353);
    box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); }
    .info .button:hover,
    .question .button:hover,
    .warning .button:hover,
    .error .button:hover {
      color: #ffffff;
      outline-color: rgba(255, 255, 255, 0.3);
      border-color: #0b1e33;
      background-image: linear-gradient(to bottom, #3180d4, #2467ad 40%, #215d9c);
      text-shadow: 0 -1px rgba(0, 0, 0, 0.67153);
      icon-shadow: 0 -1px rgba(0, 0, 0, 0.67153);
      box-shadow: inset 0 1px rgba(255, 255, 255, 0.1); }
    .info .button:active,
    .question .button:active,
    .warning .button:active,
    .error .button:active {
      color: #ffffff;
      outline-color: rgba(255, 255, 255, 0.3);
      border-color: #0b1e33;
      background-image: linear-gradient(to bottom, #194776, #1c5187);
      text-shadow: 0 -1px rgba(0, 0, 0, 0.78353);
      icon-shadow: 0 -1px rgba(0, 0, 0, 0.78353);
      box-shadow: inset 0 1px rgba(0, 0, 0, 0.07), inset 0 2px 1px -2px rgba(0, 0, 0, 0.6); }
    .info .button:insensitive,
    .question .button:insensitive,
    .warning .button:insensitive,
    .error .button:insensitive {
      color: #90aac4;
      border-color: #0b1e33;
      background-image: linear-gradient(to bottom, #22558a);
      text-shadow: none;
      icon-shadow: none;
      box-shadow: inset 0 1px rgba(255, 255, 255, 0); }
      .info .button:insensitive > GtkLabel,
      .question .button:insensitive > GtkLabel,
      .warning .button:insensitive > GtkLabel,
      .error .button:insensitive > GtkLabel {
        color: inherit; }
    .info .button:backdrop,
    .question .button:backdrop,
    .warning .button:backdrop,
    .error .button:backdrop {
      color: #d2deeb;
      border-color: #0b1e33;
      background-image: linear-gradient(to bottom, #215d9c);
      text-shadow: none;
      icon-shadow: none;
      box-shadow: inset 0 1px rgba(255, 255, 255, 0);
      border-color: #0b1e33; }
      .info .button:backdrop:insensitive,
      .question .button:backdrop:insensitive,
      .warning .button:backdrop:insensitive,
      .error .button:backdrop:insensitive {
        color: #6f90b2;
        border-color: #0b1e33;
        background-image: linear-gradient(to bottom, #22558a);
        text-shadow: none;
        icon-shadow: none;
        box-shadow: inset 0 1px rgba(255, 255, 255, 0);
        border-color: #0b1e33; }
        .info .button:backdrop:insensitive > GtkLabel,
        .question .button:backdrop:insensitive > GtkLabel,
        .warning .button:backdrop:insensitive > GtkLabel,
        .error .button:backdrop:insensitive > GtkLabel {
          color: inherit; }

/************
 * Tooltips *
 ************/
.tooltip {
  color: white;
  padding: 4px;
  /* not working */
  border-radius: 5px;
  box-shadow: none;
  text-shadow: 0 1px black; }
  .tooltip.background {
    background-color: rgba(0, 0, 0, 0.8);
    background-clip: padding-box;
    border: 1px solid rgba(255, 255, 255, 0.1); }
  .tooltip.window-frame.csd {
    background-color: transparent; }

.tooltip * {
  padding: 4px;
  background-color: transparent;
  color: inherit; }

/*****************
 * Color Chooser *
 *****************/
GtkColorSwatch {
  border: 1px solid;
  border-color: #1c1f1f;
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.4); }
  GtkColorSwatch.color-light:hover {
    background-image: linear-gradient(to bottom, rgba(255, 255, 255, 0) 40%, rgba(255, 255, 255, 0.4)); }
    GtkColorSwatch.color-light:hover:backdrop {
      background-image: none; }
  GtkColorSwatch.color-dark:hover {
    background-image: linear-gradient(to bottom, rgba(255, 255, 255, 0) 40%, rgba(255, 255, 255, 0.2)); }
    GtkColorSwatch.color-dark:hover:backdrop {
      background-image: none; }
  GtkColorSwatch:hover {
    border-color: #1e2222; }
  GtkColorSwatch:backdrop {
    border-color: #1e2222;
    box-shadow: none; }
  GtkColorSwatch.top {
    border-top-left-radius: 5px;
    border-top-right-radius: 5px; }
  GtkColorSwatch.bottom {
    border-bottom-left-radius: 5px;
    border-bottom-right-radius: 5px; }
  GtkColorSwatch.left, GtkColorSwatch:first-child {
    border-top-left-radius: 5px;
    border-bottom-left-radius: 5px; }
  GtkColorSwatch.right, GtkColorSwatch:last-child {
    border-top-right-radius: 5px;
    border-bottom-right-radius: 5px; }
  GtkColorSwatch:only-child {
    border-radius: 5px; }
  GtkColorSwatch.color-active-badge {
    border-width: 2px; }
    GtkColorSwatch.color-active-badge:hover {
      background-image: none; }
    GtkColorSwatch.color-active-badge.color-light, GtkColorSwatch.color-active-badge.color-light:hover {
      color: rgba(0, 0, 0, 0.3);
      border-color: rgba(0, 0, 0, 0.3); }
    GtkColorSwatch.color-active-badge.color-dark, GtkColorSwatch.color-active-badge.color-dark:hover {
      color: rgba(255, 255, 255, 0.5);
      border-color: rgba(255, 255, 255, 0.5); }

GtkColorChooserWidget #add-color-button {
  border-color: #2a2f2f;
  background-color: #2a2f2f;
  color: #393f3f;
  box-shadow: none; }
  GtkColorChooserWidget #add-color-button:hover {
    border-color: #1c1f1f;
    background-color: #1c1f1f; }
  GtkColorChooserWidget #add-color-button:backdrop {
    border-color: #2b3030;
    background-color: #2b3030; }

/********
 * Misc *
 ********/
.scale-popup .button, .scale-popup .header-bar .button.titlebutton, .header-bar .scale-popup .button.titlebutton,
.scale-popup .titlebar .button.titlebutton,
.titlebar .scale-popup .button.titlebutton,
.scale-popup GtkCalendar.header .button.titlebutton,
GtkCalendar.header .scale-popup .button.titlebutton {
  padding: 6px; }
  .scale-popup .button:hover {
    background-color: rgba(238, 238, 236, 0.1);
    border-radius: 4px; }

GtkVolumeButton.button, .header-bar GtkVolumeButton.button.titlebutton,
.titlebar GtkVolumeButton.button.titlebutton,
GtkCalendar.header GtkVolumeButton.button.titlebutton {
  padding: 8px; }

/**********************
 * Window Decorations *
 *********************/
.window-frame {
  border-radius: 7px 7px 0 0;
  border-width: 0px;
  box-shadow: 0 3px 9px 1px rgba(0, 0, 0, 0.5), 0 0 0 1px rgba(28, 31, 31, 0.9);
  /* this is used for the resize cursor area */
  margin: 10px; }
  .window-frame:backdrop {
    box-shadow: 0 2px 6px 2px rgba(0, 0, 0, 0.2), 0 0 0 1px rgba(28, 31, 31, 0.9); }
  .window-frame.tiled {
    border-radius: 0; }
  .window-frame.csd.popup {
    border-radius: 0;
    box-shadow: 0 1px 2px rgba(0, 0, 0, 0.2), 0 0 0 1px rgba(28, 31, 31, 0.8); }
  .window-frame.csd.tooltip {
    border-radius: 5px;
    box-shadow: none; }
  .window-frame.csd.message-dialog {
    border-radius: 7px;
    box-shadow: 0 1px 2px rgba(0, 0, 0, 0.2), 0 0 0 1px rgba(28, 31, 31, 0.8); }

.header-bar .titlebutton.button,
.titlebar .titlebutton.button,
GtkCalendar.header .titlebutton.button {
  text-shadow: 0 -1px rgba(0, 0, 0, 0.81176);
  icon-shadow: 0 -1px rgba(0, 0, 0, 0.81176); }
  .header-bar .titlebutton.button:backdrop,
  .titlebar .titlebutton.button:backdrop,
  GtkCalendar.header .titlebutton.button:backdrop {
    icon-shadow: none; }

.header-bar.selection-mode .titlebutton.button,
.titlebar.selection-mode .titlebutton.button,
GtkCalendar.selection-mode.header .titlebutton.button {
  text-shadow: 0 -1px rgba(0, 0, 0, 0.70353);
  icon-shadow: 0 -1px rgba(0, 0, 0, 0.70353); }
  .header-bar.selection-mode .titlebutton.button:backdrop,
  .titlebar.selection-mode .titlebutton.button:backdrop,
  GtkCalendar.selection-mode.header .titlebutton.button:backdrop {
    icon-shadow: none; }

.view:selected, .view:selected:focus, .view:selected:hover, GtkLabel:selected, GtkLabel:selected:focus, GtkLabel:selected:hover, GtkFlowBox .grid-child:selected, .entry:selected, .entry:selected:focus, .menuitem.button.flat:selected, .header-bar .menuitem.titlebutton.button:selected,
.titlebar .menuitem.titlebutton.button:selected,
GtkCalendar.header .menuitem.titlebutton.button:selected, .list-row:selected {
  background-color: #215d9c;
  color: #ffffff; }
  .view:backdrop:selected, GtkLabel:backdrop:selected, GtkFlowBox .grid-child:backdrop:selected, .entry:backdrop:selected, .menuitem.button.flat:backdrop:selected, .header-bar .menuitem.titlebutton.button:backdrop:selected,
  .titlebar .menuitem.titlebutton.button:backdrop:selected,
  GtkCalendar.header .menuitem.titlebutton.button:backdrop:selected, .list-row:backdrop:selected {
    color: #c9cbc9; }

/* GTK NAMED COLORS */
@define-color theme_fg_color #eeeeec;
@define-color theme_bg_color #393f3f;
@define-color theme_base_color #292929;
@define-color theme_selected_bg_color #215d9c;
@define-color theme_selected_fg_color #ffffff;
@define-color insensitive_bg_color #323636;
@define-color insensitive_fg_color #939695;
@define-color insensitive_base_color #292929;
@define-color theme_unfocused_fg_color #c9cbc9;
@define-color theme_unfocused_bg_color #393f3f;
@define-color theme_unfocused_base_color #2c2c2c;
@define-color theme_unfocused_selected_bg_color #215d9c;
@define-color theme_unfocused_selected_fg_color #ffffff;
@define-color borders #1c1f1f;
@define-color unfocused_borders #1e2222;
@define-color warning_color #f57900;
@define-color error_color #cc0000;
@define-color success_color #5aa411;
@define-color wm_title shade(#eeeeec, 1.8);
@define-color wm_unfocused_title #c9cbc9;
@define-color wm_highlight transparent;
@define-color wm_borders_edge rgba(238, 238, 236, 0.1);
@define-color wm_bg_a shade(#393f3f, 1.2);
@define-color wm_bg_b #393f3f;
@define-color wm_shadow alpha(black, 0.35);
@define-color wm_border alpha(black, 0.18);
@define-color wm_button_hover_color_a shade(#393f3f, 1.3);
@define-color wm_button_hover_color_b #393f3f;
@define-color wm_button_active_color_a shade(#393f3f, 0.85);
@define-color wm_button_active_color_b shade(#393f3f, 0.89);
@define-color wm_button_active_color_c shade(#393f3f, 0.9);
@define-color content_view_bg #292929;
